(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57425,       1980]*)
(*NotebookOutlinePosition[     77215,       2581]*)
(*  CellTagsIndexPosition[     76458,       2547]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Appendix A", "ChapterLine",
  CellTags->"A.0"],

Cell[TextData[{
  "How ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Works"
}], "Title",
  CellTags->"A.0"],

Cell[TextData[{
  "In this appendix, we describe some of the underpinnings of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming language. Understanding how the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language works will enable you to better understand the programs \
presented in this book (illustrations of the use of all of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " built-in functions that are employed in this book are given in Appendix \
B). This is not meant as a complete overview of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". This material has been extensively ",
  StyleBox["field tested",
    FontSlant->"Italic"],
  " in courses presented in universities, professional conferences, and \
industry."
}], "Text",
  CellTags->"A.0"],

Cell[CellGroupData[{

Cell["A.1  Expressions", "Section",
  CellTags->"A.1"],

Cell[CellGroupData[{

Cell["A.1.1  Everything Is an Expression", "Subsection",
  CellTags->"A.1"],

Cell[TextData[{
  "Underlying every ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression. There are two parts to every ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression: the ",
  StyleBox["head",
    FontSlant->"Italic"],
  " and the ",
  StyleBox["arguments",
    FontSlant->"Italic"],
  ". The syntax for an expression is to follow the head with the arguments \
surrounded with square brackets."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{"arguments", 
    "", ""}, {"expressions", "", ""}, {"head of an expression", "", ""}}},
  CellTags->{"i:1", "A.1"}],

Cell[TextData[{
  StyleBox["head",
    FontSlant->"Italic"],
  "[ ",
  StyleBox["arg1, arg2, ....., argn",
    FontSlant->"Italic"],
  " ]"
}], "Input",
  TextAlignment->Center,
  CellTags->"A.1"],

Cell[TextData[{
  "The head is itself a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression, and the arguments consist of a sequence of zero or more \
expressions separated by commas. For certain heads, there are more familiar \
shorthands which may be used but, internally, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " keeps track of the head and arguments as if they were in the preceding \
form. For example, when adding number or symbols together you can use the \
familiar ",
  StyleBox["infix",
    FontSlant->"Italic"],
  " notation"
}], "Text",
  CellTags->"A.1"],

Cell["a + b + c", "Input",
  TextAlignment->Center,
  CellTags->"A.1"],

Cell[TextData[{
  "However, when you enter this, it is transformed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " into an expression with Plus as the head and the objects that are being \
added as arguments. One way to see this is by asking ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the full internal form of the expression"
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{"FullForm", 
    "", ""}}},
  CellTags->{"i:2", "A.1"}],

Cell[CellGroupData[{

Cell["FullForm[a + b + c]", "Input",
  CellTags->"A.1"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Plus[a, b, c]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True],
      FullForm]], "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.1.2  Noteworthy Expressions", "Subsection",
  CellTags->"A.1"],

Cell[TextData[{
  "Our previous description of expressions as anything of the form ",
  StyleBox["head",
    FontSlant->"Italic"],
  "[",
  StyleBox["arguments",
    FontSlant->"Italic"],
  "] where head and arguments are themselves expressions may seem circular \
because it is not complete. What's missing is a discussion of some special \
types of expressions that play an essential role in the evaluation of \
expressions and in the writing of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs."
}], "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{

Cell["Atoms", "Subsubsection",
  CellTags->"A.1"],

Cell["\<\
An atomic expression is an expression that cannot be broken down \
further into other expressions. There are several kinds of atomic expressions\
\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:3", "IndexEntries" -> {{"atoms", "", 
    ""}, {"expressions", "atomic", ""}}},
  CellTags->{"i:3", "A.1"}],

Cell[TextData[{
  "A ",
  StyleBox["number",
    FontSlant->"Italic"],
  ": the four types of numbers that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handles by default are integers, real numbers, complex numbers, and \
rational numbers."
}], "BulletListItem",
  CellTags->"A.1"],

Cell[TextData[{
  "A ",
  StyleBox["string",
    FontSlant->"Italic"],
  ": any sequence of characters enclosed in quotes, as in \"Simulating \
Society\"."
}], "BulletListItem",
  CellTags->"A.1"],

Cell[TextData[{
  "A ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  ": a letter followed by letters and/or numbers that are not enclosed in \
quotes. We show shortly how symbols can be used to store numbers, strings, or \
arbitrary expressions."
}], "BulletListItem",
  CellTags->"A.1"],

Cell["\<\
When you ask for the FullForm of an atomic expression, you will \
notice that the expression itself is returned.\
\>", "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{

Cell["\<\
{FullForm[Plus],
          FullForm[\"Simulating Society\"], FullForm[51]}\
\>", "Input",
  CellTags->"A.1"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["Plus",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True],
          FullForm], ",", 
        TagBox[
          StyleBox["\"\<Simulating Society\>\"",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True],
          FullForm], ",", 
        TagBox[
          StyleBox["51",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True],
          FullForm]}], "}"}]], "Output",
  CellTags->"A.1"]
}, Open  ]],

Cell["\<\
Furthermore, the head of an atomic expression describes what kind \
of atom it is.\
\>", "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{

Cell["{Head[Plus], Head[\"Simulating Society\"], Head[51]}", "Input",
  CellTags->"A.1"],

Cell[BoxData[
    \({Symbol, String, Integer}\)], "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompoundExpression", "Subsubsection",
  CellTags->"A.1"],

Cell[TextData[{
  "Another very important kind of expression is a CompoundExpression. A \
program written in any computer language usually consists not of a single \
command, but of many commands one following another. When the program is run, \
these commands are typically executed consecutively in the order in which \
they are written, and the final result of these executions is displayed on \
the computer screen, or perhaps sent   to a printer. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", this is done with a CompoundExpression. A CompoundExpression is a series \
of expressions separated by semicolons. When a CompoundExpression is \
evaluated, all of the expressions within it are evaluated successively, and \
the output from the last evaluation is returned (unless the last expression \
is followed by a semicolon, in which case nothing is returned). This is how \
all the programs in this book are constructed \[LongDash] as \
CompoundExpressions."
}], "Text",
  CellTags->{"i:4", "A.1"}],

Cell[TextData[{
  "In this example, all the expressions are evaluated in turn (the symbol ",
  StyleBox["a", "IT"],
  " is assigned a value equal to the sum of 5 and 8 and is then multiplied by \
7) but only the result of evaluating the final expression after which there \
is no semicolon returns visible output."
}], "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{

Cell["a = 5 + 8; 7 a", "Input",
  CellTags->"A.1"],

Cell[BoxData[
    \(91\)], "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2  Patterns", "Section",
  CellTags->"A.2"],

Cell[TextData[{
  "When working with expressions, it is often useful to be able to determine \
the general form or structure of an expression without worrying about the \
details of its content. For instance, pattern-matching is used to cause a \
function to perform one action when applied to a quantity having a certain \
form, say a number, and another action when applied to a quantity having a \
different form, say a symbol. In fact, all of the functions used in ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " both those that are a part of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " itself, known as ",
  StyleBox["built-in",
    FontSlant->"Italic"],
  " functions, and the ",
  StyleBox["user-defined",
    FontSlant->"Italic"],
  " functions that we create, which includes the programs we write, deal with \
patterns on some level, as pattern-matching is central to how evaluation \
takes place. We cover more of the details of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluation later in this appendix."
}], "Text",
  CellTags->{"i:5", "A.2"}],

Cell[TextData[{
  "To give a real-world analogue of pattern-matching in the English language, \
there are certain patterns of words that make up sentences. One such basic \
pattern might be ",
  StyleBox["noun-verb-noun",
    FontSlant->"Italic"],
  ", representing any sentence that consists of a noun followed by a verb \
followed by a noun. A sentence that matches this grammatical pattern is \
\"Suzanne reads books.\" A sentence that does not match this pattern is \
\"Carole writes.\" So too in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", a ",
  StyleBox["pattern",
    FontSlant->"Italic"],
  " is an expression that represents all expressions that share a particular \
syntactic structure. The syntactic structure of an expression is given by the \
FullForm representation of the expression, which we discussed earlier."
}], "Text",
  CellTags->"A.2"],

Cell[TextData[{
  "There are a number of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions that allow one to use patterns. One such important function is \
MatchQ, which determines whether a given expression matches a pattern."
}], "Text",
  CellTags->{"i:6", "A.2"}],

Cell[CellGroupData[{

Cell["?MatchQ", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \("MatchQ[expr, form] returns True if the pattern form matches expr, and \
returns False otherwise."\)], "Print",
  CellTags->"A.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.1  Matching Expressions", "Subsection",
  CellTags->"A.2"],

Cell[TextData[{
  "One of the simplest patterns matches any expression, and is represented in \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by a single underscore character (_). This pattern is known as a Blank",
  ". ",
  "Since a Blank matches any expression, if MatchQ is given any expression as \
its first argument and a Blank as its second argument, it will always return \
True."
}], "Text",
  CellTags->{"i:7", "A.2"}],

Cell[CellGroupData[{

Cell["MatchQ[a + b, _]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "One can also use a Blank to match expressions that lie within other \
expressions. Such expressions are called ",
  StyleBox["subexpressions",
    FontSlant->"Italic"],
  ". For example, the following input returns True because the first Blank \
matches the first 1, and the last Blank matches the 3",
  ". ",
  "The expressions 1 and 3 are simple subexpressions of the given \
expression."
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[_, 1, 1, 2, 2, _]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " There is an exception to the matching of Blank that is important to keep \
in mind. Although each of the individual subexpressions that reside within \
the sequence subexpression used in the previous example matches Blank, the \
sequence itself does not match Blank."
}], "Note",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[_]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(False\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "One can restrict the Blank to match only expressions with a specified head \
by giving that head to Blank as an argument. The shorthand form of Blank[",
  StyleBox["h", "IT"],
  "] is an underscore followed by the symbol ",
  StyleBox["h", "IT"],
  ", as in _",
  StyleBox["h", "IT"],
  ". For example, the pattern in the following matches any expression with \
head ",
  StyleBox["func",
    FontSlant->"Italic"],
  " and an integer argument."
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[36], func[_Integer]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "Another modification of Blank is to assign a name to a pattern. You can \
name a pattern by inserting a symbol before the underscore, with no \
intervening space. As a simple example, the pattern ",
  StyleBox["x", "IT"],
  "_ matches any expression and is named with the dummy variable ",
  StyleBox["x", "IT"],
  ". Providing the pattern with a name makes it easy to refer to the part of \
an expression that matches a part of a pattern. These sorts of references are \
indispensable for defining your own functions, where the names are used as ",
  StyleBox["dummy variables.",
    FontSlant->"Italic"],
  " We explain function writing later, but for purposes of illustrating the \
use of pattern labeling, the simple function definition ",
  StyleBox["g", "IT"],
  "[",
  StyleBox["x", "IT"],
  "_] := ",
  StyleBox["a", "IT"],
  " + ",
  StyleBox["x", "IT"],
  " can be used. If we first create the function definition using the labeled \
pattern ",
  StyleBox["x", "IT"],
  "_ on the left-hand side and then enter ",
  StyleBox["g", "IT"],
  "[7], the value of 7 is substituted for the symbol ",
  StyleBox["x", "IT"],
  " on the right-hand side of the function definition and the value 7 + ",
  StyleBox["a", "IT"],
  " is returned. "
}], "Text",
  CellTags->{"i:8", "A.2"}],

Cell[CellGroupData[{

Cell["g[x_] := a + x; g[7]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(7 + a\)], "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.2  Matching Sequences of Expressions", "Subsection",
  CellTags->"A.2"],

Cell["\<\
There are two extensions of Blank that are widely used: \
BlankSequence and BlankNullSequence. \
\>", "Text",
  CellTags->"A.2"],

Cell[TextData[{
  "BlankSequence is represented by two underscore characters in a row (__), \
and matches any sequence of one or more comma-separated ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expressions. To illustrate the use of BlankSequence, we can use func[1, \
1, 1, 2, 2, 3] which we saw earlier does not match func[_]."
}], "Text",
  CellTags->{"i:9", "A.2"}],

Cell[CellGroupData[{

Cell["\<\
{MatchQ[func[1, 1, 1, 2, 2, 3], func[_]],
 MatchQ[func[1, 1, 1, 2, 2, 3], func[__]]}\
\>", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \({False, True}\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "BlankNullSequence, represented by three underscore characters (___), \
matches any sequence of ",
  StyleBox["zero",
    FontSlant->"Italic"],
  " or more comma-separated ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expressions. To illustrate the use of BlankNullSequence, we can use func \
with no arguments. "
}], "Text",
  CellTags->{"i:10", "A.2"}],

Cell[CellGroupData[{

Cell["\<\
{MatchQ[func[], func[_]],
 MatchQ[func[], func[__]],
 MatchQ[func[], func[___]]}\
\>", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \({False, False, True}\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "Blank, BlankSequence, and BlankNullSequence are in order from most \
specific to most general. That is, every expression that matches _ will also \
match __ and ___. Furthermore, every expression that is a sequence of one or \
more expressions (and so matches __) is also a sequence of zero or more \
expressions (and so will match ___). As an example, we can look at the \
expression ",
  StyleBox["a", "IT"],
  " + ",
  StyleBox["b", "IT"],
  " which we saw earlier matches Blank. "
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["{MatchQ[a + b, _], MatchQ[a + b, __], MatchQ[a + b, ___]}", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \({True, True, True}\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
Choosing which of these patterns to use allows us to make fine \
distinctions between expressions which is very useful in creating function \
definitions that have the same name but give different results when applied \
to different arguments.\
\>", "Text",
  CellTags->"A.2"],

Cell["\<\
Here is an example where the __ matches a sequence of five \
expressions, and the ___ matches a sequence of zero expressions.\
\>", "Text",\

  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[__, 3, ___]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
If we switch the use of BlankSequence with BlankNullSequence, the \
match fails because there are no arguments after the 3 in the given \
expression.\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[___, 3, __]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(False\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
This pattern will match any application of the function func whose \
sequence of arguments begins with 1, contains 2, and ends with 3.\
\>", "Text",\

  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[1, ___, 2, ___, 3]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
As with Blank, the patterns BlankSequence and BlankNullSequence can \
be restricted to match sequences of expressions each of which has the same \
head.\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[exprs___Integer]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.3  Alternatives", "Subsection",
  CellTags->"A.2"],

Cell[TextData[{
  "Alternatives[",
  StyleBox["a1", "IT"],
  ", ",
  StyleBox["a2", "IT"],
  ", \[Ellipsis]] is a pattern that matches an expression when any one of the \
patterns ",
  StyleBox["a1", "IT"],
  ", ",
  StyleBox["a2", "IT"],
  " \[Ellipsis] matches it. The shorthand for Alternatives is a vertical bar \
( | ), so that Alternatives[",
  StyleBox["a", "IT"],
  ", ",
  StyleBox["b", "IT"],
  ", ",
  StyleBox["c", "IT"],
  "] can be rewritten ",
  StyleBox["a", "IT"],
  " | ",
  StyleBox["b", "IT"],
  " | ",
  StyleBox["c", "IT"],
  ". The Alternatives function can be thought of as a ",
  StyleBox["multiple-choice ",
    FontSlant->"Italic"],
  "pattern. Using Alternatives, we can provide a pattern that matches a more \
general set of expressions than each of the patterns alone."
}], "Text",
  CellTags->{"i:11", "A.2"}],

Cell["\<\
The pattern in the following example would match any expression \
with head func that has one or more arguments, and whose last argument was \
one of 1, 3, or 5.\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[__, 1 | 3 | 5]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "Continuing with the analogy to multiple-choice, an expression that returns \
False when compared to the Alternatives pattern is equivalent to the \
multiple-choice option ",
  StyleBox["none of the above",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["MatchQ[func[1, 1, 1, 2, 2, 3], func[___, 1 | 2 | 5]]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(False\)], "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.4  PatternTest", "Subsection",
  CellTags->"A.2"],

Cell[TextData[{
  "In addition to restricting a pattern so that it only matches expressions \
with a certain head, there are several other ways that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can restrict the set of expressions that match a given pattern. One \
simple way is through the PatternTest function. PatternTest[_, ",
  StyleBox["func", "IT"],
  "] matches an expression ",
  StyleBox["expr", "IT"],
  " when ",
  StyleBox["func", "IT"],
  "[",
  StyleBox["expr", "IT"],
  "] returns True. Functions that return True or False when applied to an \
expression are commonly called predicate functions. A shorthand for \
PatternTest is to follow an underscore (or two underscores or three \
underscores) with a question mark, and the name of the predicate function as \
in _?",
  StyleBox["func", "IT"],
  ". For example, the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Positive returns True when applied to a positive real number."
}], "Text",
  CellTags->{"i:12", "A.2"}],

Cell[CellGroupData[{

Cell["MatchQ[3, _?Positive]", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "We can combine the use of the head restriction with the use of PatternTest \
to narrow the pattern matching even further since if either of these \
restrictions is not met for a given expression, the pattern will fail to \
match. In general, the argument of Blank (or BlankSequence or \
BlankNullSequence) can be used with PatternTest to create a new pattern of \
the form PatternTest[_",
  StyleBox["head", "IT"],
  ", ",
  StyleBox["func", "IT"],
  "] or as it is commonly written",
  " ",
  "_",
  StyleBox["head", "IT"],
  "?",
  StyleBox["func", "IT"],
  ". For example, using _Integer which matches integers, with ?Positive which \
matches positive numbers creates a pattern that matches positive integers. "
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["\<\
{MatchQ[2.71, _Integer],
 MatchQ[2.71, _?Positive],
 MatchQ[2.71, _Integer?Positive]}\
\>", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \({False, True, False}\)], "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.5  Condition", "Subsection",
  CellTags->"A.2"],

Cell["\<\
The Pattern test function is applied to an entire expression. If we \
only want to pattern-match a part of an expression, we use the Condition \
function.\
\>", "Text",
  CellTags->{"i:13", "A.2"}],

Cell[TextData[{
  "Condition takes two arguments: the pattern and the condition. If the \
condition returns True, then we say that the condition is satisfied, and the \
pattern-match is successful. Condition[",
  StyleBox["p", "IT"],
  ", ",
  StyleBox["cond", "IT"],
  "] is usually written as ",
  StyleBox["p", "IT"],
  " /; ",
  StyleBox["cond", "IT"],
  ". For example, the following returns True because the first argument to ",
  StyleBox["func", "IT"],
  " is a positive number that is less than the last argument."
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell["\<\
MatchQ[func[1, 1, 1, 2, 2, 3],
                     func[x_?Positive, ___, z_] /; x < z]\
\>", "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
As this example shows, Condition contains labeled patterns in order \
to identify the part of the pattern that is being used in the \
pattern-matching restriction.\
\>", "Text",
  CellTags->"A.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.2.6  Rule, RuleDelayed, and ReplaceAll", "Subsection",
  CellTags->"A.2"],

Cell[TextData[{
  "Patterns can be used not only to determine if an expression is of a \
specified form, but also to transform the matching subexpressions into other \
expressions. In order to do this, we can specify a Rule called a ",
  StyleBox["replacement rule ",
    FontSlant->"Italic"],
  "or ",
  StyleBox["transformation rule",
    FontSlant->"Italic"],
  ", Rule[",
  StyleBox["p", "IT"],
  ", ",
  StyleBox["q", "IT"],
  "], which specifies a pattern ",
  StyleBox["p", "IT"],
  " and a value ",
  StyleBox["q", "IT"],
  " with which to replace the pattern. This is commonly written as",
  " ",
  StyleBox["p", "IT"],
  " \[Rule] ",
  StyleBox["q", "IT"],
  ". Another function, ReplaceAll, is usually used to apply the Rule function \
to an expression and carry out the replacement in the expression. \
ReplaceAll[",
  StyleBox["expr", "IT"],
  ", Rule[",
  StyleBox["p", "IT"],
  ", ",
  StyleBox["q", "IT"],
  "]] replaces ",
  StyleBox["p", "IT"],
  " in any subexpression of ",
  StyleBox["expr", "IT"],
  " with ",
  StyleBox["q", "IT"],
  ". This is usually written with the shorthand ",
  StyleBox["expr", "IT"],
  " /. ",
  StyleBox["p", "IT"],
  " \[Rule] ",
  StyleBox["q", "IT"],
  ". Here is an example."
}], "Text",
  CellTags->{"i:14", "A.2"}],

Cell[CellGroupData[{

Cell[TextData[
"func[-3, -2, -1, 0, 1, 2, 3] /. x_?Negative \[Rule] x^2"], "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(func[9, 4, 1, 0, 1, 2, 3]\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
Notice that without naming the pattern on the left-hand side of the \
replacement rule, there would be no way to refer to it on the right-hand \
side. If you also wanted to replace the positive numbers by their cubes, you \
could do it by specifying a list of replacement rules.\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell[TextData[
"func[-3, -2, -1, 0, 1, 2, 3] /.\n                   {x_?Negative \[Rule] \
x^2, x_?Positive \[Rule] x^3}"], "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(func[9, 4, 1, 0, 1, 8, 27]\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "A technical note about the evaluation of ReplaceAll: when an expression of \
the form ",
  StyleBox["expr", "IT"],
  " /. ",
  StyleBox["p", "IT"],
  " \[Rule] ",
  StyleBox["q", "IT"],
  " is entered, first ",
  StyleBox["expr", "IT"],
  " is evaluated, then ",
  StyleBox["p", "IT"],
  " is evaluated, then ",
  StyleBox["q", "IT"],
  " is evaluated, and finally the replacement is carried out. Although this \
is fine for many instances, there may be cases where you want the evaluation \
of ",
  StyleBox["q", "IT"],
  " to wait until after the replacement is actually carried out (in other \
words, so that the evaluated ",
  StyleBox["p", "IT"],
  " pattern in the evaluated ",
  StyleBox["expr", "IT"],
  " is replaced with the unevaluated ",
  StyleBox["q", "IT"],
  " value). The built-in function RuleDelayed does exactly this. Instead of \
an arrow, RuleDelayed is entered using the \"colon-arrow\" \[RuleDelayed] \
shorthand."
}], "Text",
  CellTags->{"i:15", "A.2"}],

Cell["\<\
To illustrate this, we use the built-in Random function which \
returns a random real number between zero and one. If we use a replacement \
rule that evaluates the random number first, we see that every integer in the \
following expression is replaced with the same number.\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell[TextData["func[1, 2, 3] /. x_Integer \[Rule] Random[]"], "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(func[0.810420550316719712`, 0.810420550316719712`, 
      0.810420550316719712`]\)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell[TextData[{
  "However, using RuleDelayed (\[RuleDelayed]), postpones the call to Random \
until the rule is used to replace each integer individually",
  ". ",
  "Thus, the result contains three distinct random numbers."
}], "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell[TextData["func[1, 2, 3] /. x_Integer \[RuleDelayed] Random[]"], "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(func[0.17474569768275634`, 0.493140193230945289`, 0.234172490961493373`]
      \)], "Output",
  CellTags->"A.2"]
}, Open  ]],

Cell["\<\
Finally, we can use Condition in conjunction with RuleDelayed (but \
not with Rule) to provide patterns that will only be used as replacement \
rules if some predicate is satisfied. For example, the following is a simple \
method to replace all integers with absolute value greater than 1 with their \
squares\
\>", "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{

Cell[TextData[
"func[-3, -2, -1, 0, 1, 2, 3] /.\n                           x_Integer \
\[RuleDelayed] x^2 /; Abs[x] > 1"], "Input",
  CellTags->"A.2"],

Cell[BoxData[
    \(func[9, 4, \(-1\), 0, 1, 4, 9]\)], "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.3  Functions", "Section",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["A.3.1  Built-In Functions", "Subsection",
  CellTags->"A.3"],

Cell[TextData[{
  "Before defining your own functions, it is a good idea to become familiar \
with what sorts of things ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can already do with the functions that are built into the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel, each of which has a particular syntax and usage. Although it is \
completely unnecessary to become familiar with all 1,500+ of them, writing \
your own simulations will be easier if you make an effort to understand all \
the built-in functions used in this book. You can find out more about a \
built-in function by asking ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for its ",
  StyleBox["usage message",
    FontSlant->"Italic"],
  ", which you can do by typing a question mark (?) and then the function \
name. For example, "
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["?Positive", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \("Positive[x] gives True if x is a positive number."\)], "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "You can get more information by looking up these functions in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book, or in the Built-in Functions section of the Help Browser in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " front end."
}], "Text",
  CellTags->"A.3"],

Cell[TextData[{
  "Many built-in functions have special formats that make entering and \
reading them easier",
  ". ",
  "A list of such special formats is available in the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "book. "
}], "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.3.2  User-Defined Functions", "Subsection",
  CellTags->"A.3"],

Cell[TextData[{
  "Using a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " or ",
  StyleBox["program",
    FontSlant->"Italic"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is simple, as we've already seen: you input the function name and a \
sequence of arguments, and the kernel returns a result (the details of how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluates the input are discussed later in this appendix). So to define a \
new function in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", you need to specify the name of the function (a symbol), the arguments \
to the function (a pattern or sequence of patterns, usually labeled), and \
then what the function does to those arguments. Here is an example of a \
function that squares its argument, and then adds one to the result."
}], "Text",
  CellTags->"A.3"],

Cell["func1[x_] := x^2 + 1", "Input",
  CellTags->"A.3"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " You may have noticed that built-in functions begin with a capital letter, \
and capitalize every complete word thereafter. To distinguish user-defined \
functions from built-in functions, we follow the convention of beginning our \
function definitions with a lowercase letter."
}], "Note",
  CellTags->"A.3"],

Cell[TextData[
"The \"colon-equal\" (:=) in the function definition looks very much like the \
\"colon-arrow\" (\[RuleDelayed]) from the previous section, in that we have a \
pattern on the left-hand side that is transformed to a different expression \
on the right-hand side. The difference between using := (or SetDelayed) and \
\[RuleDelayed] (RuleDelayed) is in how the replacement is applied. The \
replacement that occurs with RuleDelayed is restricted to the expression to \
which it is attached. With SetDelayed, the replacement occurs automatically \
for every expression you input that pattern-matches the left-hand side of the \
definition."], "Text",
  CellTags->{"i:16", "A.3"}],

Cell[CellGroupData[{

Cell["func1[5]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(26\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell["\<\
Functions can be applied one right after another without having to \
return intermediate results.\
\>", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["func1[func1[5]]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(677\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "Of course, unlike the built-in functions, user-defined functions do not \
persist once you quit ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " so if you want to use the function again in another ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, you must first re-enter the definition."
}], "Text",
  CellTags->"A.3"],

Cell[TextData[{
  "Along with function definitions, it is sometimes useful to assign your own \
values to a symbol, so that the symbol becomes a shorthand for the value. \
This can be done using the",
  " ",
  "= (Set) operator. For example, after making the following assignment, ",
  StyleBox["b", "IT"],
  " will be replaced by 23 wherever it appears. (Note the use of a semicolon, \
the CompoundExpression operator, to prevent the output from being given.)"
}], "Text",
  CellTags->{"i:17", "A.3"}],

Cell["b = 23;", "Input",
  CellTags->"A.3"],

Cell[TextData[{
  "Now this example will replace ",
  StyleBox["b", "IT"],
  " with its assigned value as it is evaluated."
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["func1[a] + b", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(24 + a\^2\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "A program is nothing more than a user-defined function. For example, ",
  StyleBox["func1", "IT"],
  " is a program. Of course, a program often looks complicated because the \
right-hand side of a program is usually a CompoundExpression. As an example, \
we can write a simple program that allows us to input any value of ",
  StyleBox["b", "IT"],
  " rather than use the value given outside the program."
}], "Text",
  CellTags->"A.3"],

Cell["func2[x_, y_] := (b = y + 1; x^2 + b)", "Input",
  CellTags->"A.3"],

Cell["\<\
One potential problem that can occur when user-defined functions \
are written this way is that values assigned to symbols outside the program \
are changed to the values used for these symbols in the program once it is \
run. For example, after entering\
\>", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["func2[a, 5]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(6 + a\^2\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "the value of ",
  StyleBox["b", "IT"],
  " that was previously assigned in the kernel to be 23 is now changed."
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["b", "Input",
  CellTags->"A.3"],

Cell["6", "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "The way to prevent this change in the values assigned to a symbol in the \
kernel is to use local variables. You can do this with Module, which allows \
you to declare variables as local. When you do this, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows that when you refer to an ",
  StyleBox["x", "IT"],
  " in a Module that has a local variable ",
  StyleBox["x", "IT"],
  ", you're talking about the local version of ",
  StyleBox["x", "IT"],
  ", and not any other version that might exist in the kernel (that also \
means that you won't be able to refer to your local value of ",
  StyleBox["x", "IT"],
  " outside the Module)."
}], "Text",
  CellTags->{"i:18", "A.3"}],

Cell[TextData[{
  "Of course, you need to tell Module which variables you wish to localize. \
The first argument to Module should be a list of such variables. The second \
argument is the expression (typically a CompoundExpression) to evaluate. For \
example we can rewrite ",
  StyleBox["func2", "IT"],
  " using Module"
}], "Text",
  CellTags->"A.3"],

Cell["func3[x_, y_] := Module[{b}, b = y + 1; x^2 + b]", "Input",
  CellTags->"A.3"],

Cell["\<\
All of the programs in this book are written using the Module \
construction.\
\>", "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.3.3  Ordering Functions", "Subsection",
  CellTags->"A.3"],

Cell["\<\
Just as there can be more than one transformation rule governing \
how different types of expressions should be altered, there can also be more \
than one function definition that uses the same head. Which definition \
applies to a particular set of arguments depends on which pattern the \
arguments match. This is the crux of most of the function definitions in this \
book.\
\>", "Text",
  CellTags->"A.3"],

Cell["\<\
For example, here is the definition of a function that returns True \
if its argument is 0, and False otherwise. \
\>", "Text",
  CellTags->"A.3"],

Cell["\<\
zeroQ[0] := True
zeroQ[_] := False\
\>", "Input",
  CellTags->"A.3"],

Cell["We see that this does what we want.", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["{zeroQ[20], zeroQ[0], zeroQ[4 - 5 + 1]}", "Input",
  CellTags->"A.3"],

Cell["{False, True, True}", "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "It is important to note that when you give multiple function definitions \
for the same symbol, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " attempts to put them in order from the most specific to the most general. \
When you then use the function, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " tries the definitions in that order until it finds one whose left-hand \
side matches the given arguments. If the arguments don't match any of the \
left-hand sides, the expression is returned unevaluated."
}], "Text",
  CellTags->"A.3"],

Cell[TextData[{
  "In the example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " first checks to see if the most specific rule applies \[LongDash] that \
is, if the argument to ",
  StyleBox["zeroQ", "IT"],
  " is a 0. If it is, True is returned. Otherwise, if the argument is not \
zero, it goes on to check if the second rule applies. The pattern for the \
second definition is very general, matching any expression and returning \
False in that case. So since the second definition only applies in cases \
where the argument is not zero, we don't need an explicit Condition requiring \
that it be nonzero. To make the second definition even more general, use \
BlankNullSequence to match not just any expression, but any sequence of zero \
or more expressions."
}], "Text",
  CellTags->"A.3"],

Cell[TextData[{
  "Thus, we can simplify function definitions by understanding the order in \
which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses them."
}], "Text",
  CellTags->"A.3"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will show you how it has ordered multiple function definitions if you use \
the syntax ? followed by the function name."
}], "Text",
  CellTags->{"i:19", "A.3"}],

Cell[CellGroupData[{

Cell["?zeroQ", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \("Global`zeroQ"\)], "Print",
  CellTags->"A.3"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(zeroQ[0]\  := \ \(True\n\ \nzeroQ[_]\  := \ False\)\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ zeroQ]],
      Editable->True,
      AutoDelete->True]], "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "It is always a good idea to periodically check ?",
  StyleBox["yourFunction", "IT"],
  " to see if ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has the definitions in the order in which you think they should be. More \
specific function definitions will automatically be put higher up on the \
list, but in those cases where ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot tell the difference between how specific two function definitions \
are, it will put them in the order you have given."
}], "Text",
  CellTags->"A.3"],

Cell["\<\
More complicated examples of this can be found on nearly every page \
of this book, but one rule set that appears over and over is the walk rules \
(which are explained in Chapter 1). Here are the first few walk rules.\
\>", 
  "Text",
  CellTags->"A.3"],

Cell["\<\
RND := Random[Integer, {1, 4}];
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a}
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a}
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a}
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0\
\>", "Input",
  CellTags->"A.3"],

Cell["\<\
The four preceding definitions specify how to transform expressions \
with head walk that have one as the first element of the first argument, and \
a zero as the second argument. Notice that the last definition is more \
general than the first three, therefore it won't apply unless all of the \
first three fail to apply.\
\>", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["\<\
{walk[{1, 3}, 0, 0, 0, 0, 0, 0, 0, {2}, 0, 0, 0, 0], 
 walk[{1, 3}, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
 walk[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]}\
\>", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \({{3, 3}, 0, walk[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]}\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "If there is no definition whose pattern matches the given arguments, then \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns the expression unevaluated, as in the preceding case of walk \
applied to 13 zeros. In the simulation programs in this book, a sequence of \
arguments that causes a function to return unevaluated is an oversight that \
needs to be fixed. This is something to keep an eye out for when writing your \
own simulations."
}], "Text",
  CellTags->"A.3"],

Cell["\<\
It is important to be careful in the labeling of patterns in \
function definitions. When the left-hand sides of two definitions are \
identical, having the same head and pattern labels, only the most recently \
entered definition will be kept in the kernel. But if the heads are the same \
and the pattern labels are different, then both defintions will be in the \
kernel which can result in the wrong definition being used.\
\>", "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.3.4  Clearing Functions", "Subsection",
  CellTags->"A.3"],

Cell[TextData[{
  "When you make function definitions or assignments to variables, those \
definitions remain in the kernel until you quit the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. This is not always desirable: sometimes you want to remove a \
definition you've already made so that you can define it to mean something \
else."
}], "Text",
  CellTags->{"i:20", "A.3"}],

Cell["\<\
There are many ways to deal with this; we mention one. You can use \
Clear[symbol] to remove any definitions or rules you have attached to the \
symbol. The following input removes all the function definitions associated \
with zeroQ.\
\>", "Text",
  CellTags->{"i:21", "A.3"}],

Cell[CellGroupData[{

Cell["?zeroQ ", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \("Global`zeroQ"\)], "Print",
  CellTags->"A.3"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(zeroQ[0]\  := \ \(True\n\ \nzeroQ[_]\  := \ False\)\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ zeroQ]],
      Editable->True,
      AutoDelete->True]], "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clear[zeroQ]; ?zeroQ", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \("Global`zeroQ"\)], "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell["\<\
Clearing variable names and function names is a good habit to get \
into when debugging your simulation programs. It is sometimes easy to \
overlook a definition that will cause your program to fail, even though you \
seem to be working on an entirely different function.\
\>", "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.3.5  Anonymous Functions", "Subsection",
  CellTags->"A.3"],

Cell[TextData[{
  "We've discussed ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ability to let users name their own functions. However, it is not \
always necessary to give user-defined functions a name. Functions without \
names are called ",
  StyleBox["anonymous functions",
    FontSlant->"Italic"],
  ". The usefulness of anonymous functions becomes apparent shortly."
}], "Text",
  CellTags->{"i:22", "A.3"}],

Cell[TextData[{
  "How does one construct a function with no name?",
  " ",
  "Recall the definition of ",
  StyleBox["func1", "IT"],
  ":"
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["?func1 ", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \("Global`func1"\)], "Print",
  CellTags->"A.3"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(func1[x_]\  := \ x^2\  + \ 1\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ func1]],
      Editable->True,
      AutoDelete->True]], "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "To write ",
  StyleBox["func1", "IT"],
  " without a name we need only rewrite the function using the built-in \
Function command. The first argument to Function is a list of the pattern \
labels used in the function definition and the second argument is the \
right-hand side of the function definition."
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["Function[{x}, x^2 + 1]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(Function[{x}, x\^2 + 1]\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "We can then use this function just as we would use ",
  StyleBox["func1", "IT"],
  ", applying it in exactly the same way."
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["Function[{x}, x^2 + 1][expr]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(1 + expr\^2\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "An even more common way to write anonymous functions leaves the arguments \
anonymous as well as the function name. In this case, the variables are \
replaced by # or #1 for the first argument, #2 for the second argument, and \
so on. Since there are no named variables, we no longer need the first \
argument to Function. The Function wrapper itself can be replaced by (\
\[Ellipsis])&",
  ". ",
  "So this same function can be rewritten again as"
}], "Text",
  CellTags->{"i:24", "A.3"}],

Cell["(#^2 + 1)&", "Input",
  CellTags->"A.3"],

Cell["\<\
Once more, the function is applied just as func was, with square \
brackets\
\>", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["(#^2 + 1)&[expr]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(1 + expr\^2\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[{
  "Care should be taken when applying anonymous functions to other anonymous \
functions, which is done throughout this book to combine successive function \
applications into a single command. When interpreting such functions, always \
read from the inside out, associating the # symbols with the nearest \
enclosing &. For instance, the following nested anonymous function first \
squares ",
  StyleBox["expr", "IT"],
  ", and then adds one to the result."
}], "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell["(# + 1)&[(#^2)&[expr]]", "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(1 + expr\^2\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell["\<\
When should you use an anonymous function and when should you use a \
named function? It depends heavily on what you wish to do. The difference \
between using a function definition and its anonymous function equivalent is \
that the latter does not go into the kernel. Hence, if you need to use a \
function in more than one place, you should probably name it so that the \
definition of the function need not be written more than once. On the other \
hand, anonymous functions can be convenient to use with functions such as \
PatternTest, that take a function as an argument.\
\>", "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{

Cell[TextData["532 /. x_?(# > 500&) \[Rule] x-1"], "Input",
  CellTags->"A.3"],

Cell[BoxData[
    \(531\)], "Output",
  CellTags->"A.3"]
}, Open  ]],

Cell[TextData[
"Notice that the anonymous predicate function is written slightly differently \
from other anonymous functions, with the right parenthesis moved to the right \
of the ampersand (\[Ellipsis]&)."], "Text",
  CellTags->"A.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.4  Evaluation", "Section",
  CellTags->"A.4"],

Cell[TextData[{
  "The following discussion is somewhat technical and can be skipped upon \
first reading this appendix. However, in order to fully master the use of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", it is important to understand how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " processes the inputs it receives."
}], "Text",
  CellTags->"A.4"],

Cell[CellGroupData[{

Cell["A.4.1  Evaluation of Expressions", "Subsection",
  CellTags->"A.4"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a term-rewriting system (TRS). Whenever an expression is entered, it \
is evaluated by term rewriting using rewrite rules. These rules consist of \
two parts: a pattern on the left-hand side (lhs) and a replacement text on \
the right-hand side (rhs). When the lhs of a rewrite rule is found to \
pattern-match part of the expression, that part is replaced by the rhs of the \
rule, after substituting values in the expression that match labeled blanks \
in the pattern into the rhs of the rule. Evaluation then proceeds by \
searching for further matching rules until no more are found."
}], "Text",
  CellTags->{"i:23", "A.4"}],

Cell[TextData[{
  "The evaluation process in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can be easily understood with the following analogy:",
  " ",
  "think of your experiences with using a handbook of mathematical formulas. \
In order to solve an integral, you consult the handbook which contains \
formulas consisting of a left-hand side (lhs) and a right-hand side (rhs), \
separated by an \"equals\" sign. You look for an integration formula in the \
handbook whose left-hand side has the same form as your integral."
}], "Text",
  CellTags->"A.4"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Athough no two formulas in the handbook have the identical lhs, there may \
be several whose lhs have the same form as your integral (eg., one lhs might \
have specific values in the integration limits or in the integrand, and \
another lhs",
  " ",
  "has unspecified (dummy) variables for these quantities). When this \
happens, you use the formula whose lhs gives the closest fit to your \
integral."
}], "Note",
  CellTags->"A.4"],

Cell["\<\
You then replace your integral with the right-hand side of the \
matching lhs and you substitute the specific values in your integral for the \
corresponding variable symbols in the rhs. Finally, you look through the \
handbook for formulas (e.g., trigonometric identities or algebraic \
manipulation) that can be used to change the answer further. \
\>", "Text",
  CellTags->"A.4"],

Cell[TextData[{
  "This depiction provides an excellent description of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluation process. However, the application of the term-rewriting \
process to a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression requires a bit more discussion because a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression consists of parts, a head and zero or more arguments which are \
themselves expressions."
}], "Text",
  CellTags->"A.4"],

Cell[TextData[{
  StyleBox["expr0",
    FontSlant->"Italic"],
  "[ e",
  StyleBox["xpr1, expr2, ....., exprn ",
    FontSlant->"Italic"],
  "]"
}], "Input",
  CellTags->"A.4"],

Cell["\<\
It is therefore necessary to understand the order in which the \
various parts of an expression are evaluated by term rewriting.\
\>", "Text",
  CellTags->"A.4"],

Cell["\<\
The implementation of the evaluation procedure is (with a few \
exceptions) straightforward.\
\>", "Text",
  CellTags->"A.4"],

Cell["If the expression is a number or a string, it isn't changed.", 
  "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
If the expression is a symbol, it is rewritten if there is an \
applicable rewrite rule in the global rule base; otherwise, it is \
unchanged.\
\>", "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
If the expression is not a number, string, or symbol, its parts are \
evaluated in a specific order. \
\>", "BulletListItem",
  CellTags->"A.4"],

Cell["The head of the expression is evaluated.", "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
The arguments of the expression are evaluated from left to right in \
order. An exception to this occurs when the head is a symbol with a Hold \
attribute (e.g., HoldFirst, HoldRest, or HoldAll), so that some of its \
arguments are left in their unevaluated forms (unless they, in turn, have the \
head Evaluate), for example, the Set or SetDelayed function.\
\>", 
  "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
After the head and arguments of an expression are each completely \
evaluated, the expression consisting of the evaluated head and arguments is \
rewritten, after making any necessary changes to the arguments based on the \
Attributes (such as Flat, Listable, Orderless) of the head, if there is an \
applicable rewrite rule in the global rule base.\
\>", "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
After carrying out the previous steps, the resulting expression is \
evaluated in the same way and then the result of that evaluation is \
evaluated, and so on until there are no more applicable rewrite rules.\
\>", 
  "BulletListItem",
  CellTags->"A.4"],

Cell["The details of the term-rewriting process are:", "Text",
  CellTags->"A.4"],

Cell["\<\
part of an expression is pattern-matched by the lhs of a rewrite \
rule;\
\>", "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
the values that match labeled blanks in the pattern are substituted \
into the rhs of the rewrite rule and evaluated; and\
\>", "BulletListItem",
  CellTags->"A.4"],

Cell["\<\
the pattern-matched part of the expression is replaced with the \
evaluated result.\
\>", "BulletListItem",
  CellTags->"A.4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", "Appendix A. How ", 
          StyleBox[ "Mathematica", FontSlant -> "Italic"], " Works"}], 
        "Header"], Inherited, Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 25, "IndexEntries" -> {{"i:1", 
  "arguments", "", ""}, {"i:1", "expressions", "", ""}, {"i:1", 
  "head of an expression", "", ""}, {"i:2", "FullForm", "", ""}, {"i:3", 
  "atoms", "", ""}, {"i:3", "expressions", "atomic", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@[cX0000000000064<01T1T00000000000
00000000003oo`@^VN3oo`02DE`00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "A.0"->{
    Cell[1731, 51, 52, 1, 92, "ChapterLine",
      CellTags->"A.0"],
    Cell[1786, 54, 120, 6, 156, "Title",
      CellTags->"A.0"],
    Cell[1909, 62, 821, 21, 116, "Text",
      CellTags->"A.0"]},
  "A.1"->{
    Cell[2755, 87, 54, 1, 40, "Section",
      CellTags->"A.1"],
    Cell[2834, 92, 75, 1, 40, "Subsection",
      CellTags->"A.1"],
    Cell[2912, 95, 700, 21, 70, "Text",
      CellTags->{"i:1", "A.1"}],
    Cell[3615, 118, 196, 9, 37, "Input",
      CellTags->"A.1"],
    Cell[3814, 129, 603, 16, 102, "Text",
      CellTags->"A.1"],
    Cell[4420, 147, 70, 2, 37, "Input",
      CellTags->"A.1"],
    Cell[4493, 151, 493, 12, 70, "Text",
      CellTags->{"i:2", "A.1"}],
    Cell[5011, 167, 55, 1, 37, "Input",
      CellTags->"A.1"],
    Cell[5069, 170, 181, 6, 38, "Output",
      CellTags->"A.1"],
    Cell[5299, 182, 70, 1, 40, "Subsection",
      CellTags->"A.1"],
    Cell[5372, 185, 548, 15, 86, "Text",
      CellTags->"A.1"],
    Cell[5945, 204, 49, 1, 30, "Subsubsection",
      CellTags->"A.1"],
    Cell[5997, 207, 319, 7, 38, "Text",
      CellTags->{"i:3", "A.1"}],
    Cell[6319, 216, 295, 10, 36, "BulletListItem",
      CellTags->"A.1"],
    Cell[6617, 228, 196, 7, 36, "BulletListItem",
      CellTags->"A.1"],
    Cell[6816, 237, 291, 8, 50, "BulletListItem",
      CellTags->"A.1"],
    Cell[7110, 247, 155, 4, 38, "Text",
      CellTags->"A.1"],
    Cell[7290, 255, 118, 4, 50, "Input",
      CellTags->"A.1"],
    Cell[7411, 261, 558, 18, 38, "Output",
      CellTags->"A.1"],
    Cell[7984, 282, 125, 4, 38, "Text",
      CellTags->"A.1"],
    Cell[8134, 290, 88, 1, 37, "Input",
      CellTags->"A.1"],
    Cell[8225, 293, 78, 2, 38, "Output",
      CellTags->"A.1"],
    Cell[8352, 301, 62, 1, 30, "Subsubsection",
      CellTags->"A.1"],
    Cell[8417, 304, 1019, 17, 180, "Text",
      CellTags->{"i:4", "A.1"}],
    Cell[9439, 323, 345, 7, 68, "Text",
      CellTags->"A.1"],
    Cell[9809, 334, 50, 1, 37, "Input",
      CellTags->"A.1"],
    Cell[9862, 337, 55, 2, 38, "Output",
      CellTags->"A.1"]},
  "i:1"->{
    Cell[2912, 95, 700, 21, 70, "Text",
      CellTags->{"i:1", "A.1"}]},
  "i:2"->{
    Cell[4493, 151, 493, 12, 70, "Text",
      CellTags->{"i:2", "A.1"}]},
  "i:3"->{
    Cell[5997, 207, 319, 7, 38, "Text",
      CellTags->{"i:3", "A.1"}]},
  "i:4"->{
    Cell[8417, 304, 1019, 17, 180, "Text",
      CellTags->{"i:4", "A.1"}]},
  "A.2"->{
    Cell[9990, 347, 51, 1, 40, "Section",
      CellTags->"A.2"],
    Cell[10044, 350, 1100, 25, 156, "Text",
      CellTags->{"i:5", "A.2"}],
    Cell[11147, 377, 875, 19, 140, "Text",
      CellTags->"A.2"],
    Cell[12025, 398, 286, 7, 54, "Text",
      CellTags->{"i:6", "A.2"}],
    Cell[12336, 409, 43, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[12382, 412, 150, 3, 53, "Print",
      CellTags->"A.2"],
    Cell[12569, 420, 68, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[12640, 423, 441, 11, 84, "Text",
      CellTags->{"i:7", "A.2"}],
    Cell[13106, 438, 52, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[13161, 441, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[13233, 446, 440, 11, 82, "Text",
      CellTags->"A.2"],
    Cell[13698, 461, 90, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[13791, 464, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[13863, 469, 363, 8, 68, "Note",
      CellTags->"A.2"],
    Cell[14251, 481, 75, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[14329, 484, 58, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[14402, 489, 494, 14, 72, "Text",
      CellTags->"A.2"],
    Cell[14921, 507, 68, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[14992, 510, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[15064, 515, 1300, 32, 192, "Text",
      CellTags->{"i:8", "A.2"}],
    Cell[16389, 551, 56, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[16448, 554, 58, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[16555, 562, 81, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[16639, 565, 138, 4, 38, "Text",
      CellTags->"A.2"],
    Cell[16780, 571, 383, 8, 68, "Text",
      CellTags->{"i:9", "A.2"}],
    Cell[17188, 583, 128, 4, 50, "Input",
      CellTags->"A.2"],
    Cell[17319, 589, 66, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[17400, 594, 385, 11, 54, "Text",
      CellTags->{"i:10", "A.2"}],
    Cell[17810, 609, 124, 5, 63, "Input",
      CellTags->"A.2"],
    Cell[17937, 616, 73, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[18025, 621, 534, 12, 96, "Text",
      CellTags->"A.2"],
    Cell[18584, 637, 93, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[18680, 640, 71, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[18766, 645, 286, 6, 66, "Text",
      CellTags->"A.2"],
    Cell[19055, 653, 170, 5, 38, "Text",
      CellTags->"A.2"],
    Cell[19250, 662, 84, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[19337, 665, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[19409, 670, 192, 5, 38, "Text",
      CellTags->"A.2"],
    Cell[19626, 679, 84, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[19713, 682, 58, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[19786, 687, 179, 5, 38, "Text",
      CellTags->"A.2"],
    Cell[19990, 696, 91, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[20084, 699, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[20156, 704, 195, 5, 38, "Text",
      CellTags->"A.2"],
    Cell[20376, 713, 89, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[20468, 716, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[20574, 724, 60, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[20637, 727, 840, 29, 102, "Text",
      CellTags->{"i:11", "A.2"}],
    Cell[21480, 758, 204, 5, 52, "Text",
      CellTags->"A.2"],
    Cell[21709, 767, 87, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[21799, 770, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[21871, 775, 288, 8, 54, "Text",
      CellTags->"A.2"],
    Cell[22184, 787, 88, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[22275, 790, 58, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[22382, 798, 59, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[22444, 801, 1019, 25, 158, "Text",
      CellTags->{"i:12", "A.2"}],
    Cell[23488, 830, 57, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[23548, 833, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[23620, 838, 764, 19, 126, "Text",
      CellTags->"A.2"],
    Cell[24409, 861, 129, 5, 63, "Input",
      CellTags->"A.2"],
    Cell[24541, 868, 73, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[24663, 876, 57, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[24723, 879, 207, 5, 38, "Text",
      CellTags->{"i:13", "A.2"}],
    Cell[24933, 886, 554, 15, 84, "Text",
      CellTags->"A.2"],
    Cell[25512, 905, 132, 4, 50, "Input",
      CellTags->"A.2"],
    Cell[25647, 911, 57, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[25719, 916, 206, 5, 38, "Text",
      CellTags->"A.2"],
    Cell[25962, 926, 81, 1, 40, "Subsection",
      CellTags->"A.2"],
    Cell[26046, 929, 1269, 44, 148, "Text",
      CellTags->{"i:14", "A.2"}],
    Cell[27340, 977, 102, 2, 37, "Input",
      CellTags->"A.2"],
    Cell[27445, 981, 78, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[27538, 986, 321, 6, 66, "Text",
      CellTags->"A.2"],
    Cell[27884, 996, 151, 3, 50, "Input",
      CellTags->"A.2"],
    Cell[28038, 1001, 79, 2, 38, "Output",
      CellTags->"A.2"],
    Cell[28132, 1006, 998, 29, 128, "Text",
      CellTags->{"i:15", "A.2"}],
    Cell[29133, 1037, 318, 6, 66, "Text",
      CellTags->"A.2"],
    Cell[29476, 1047, 89, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[29568, 1050, 133, 3, 38, "Output",
      CellTags->"A.2"],
    Cell[29716, 1056, 256, 6, 52, "Text",
      CellTags->"A.2"],
    Cell[29997, 1066, 96, 1, 37, "Input",
      CellTags->"A.2"],
    Cell[30096, 1069, 132, 3, 38, "Output",
      CellTags->"A.2"],
    Cell[30243, 1075, 352, 7, 66, "Text",
      CellTags->"A.2"],
    Cell[30620, 1086, 151, 3, 50, "Input",
      CellTags->"A.2"],
    Cell[30774, 1091, 83, 2, 38, "Output",
      CellTags->"A.2"]},
  "i:5"->{
    Cell[10044, 350, 1100, 25, 156, "Text",
      CellTags->{"i:5", "A.2"}]},
  "i:6"->{
    Cell[12025, 398, 286, 7, 54, "Text",
      CellTags->{"i:6", "A.2"}]},
  "i:7"->{
    Cell[12640, 423, 441, 11, 84, "Text",
      CellTags->{"i:7", "A.2"}]},
  "i:8"->{
    Cell[15064, 515, 1300, 32, 192, "Text",
      CellTags->{"i:8", "A.2"}]},
  "i:9"->{
    Cell[16780, 571, 383, 8, 68, "Text",
      CellTags->{"i:9", "A.2"}]},
  "i:10"->{
    Cell[17400, 594, 385, 11, 54, "Text",
      CellTags->{"i:10", "A.2"}]},
  "i:11"->{
    Cell[20637, 727, 840, 29, 102, "Text",
      CellTags->{"i:11", "A.2"}]},
  "i:12"->{
    Cell[22444, 801, 1019, 25, 158, "Text",
      CellTags->{"i:12", "A.2"}]},
  "i:13"->{
    Cell[24723, 879, 207, 5, 38, "Text",
      CellTags->{"i:13", "A.2"}]},
  "i:14"->{
    Cell[26046, 929, 1269, 44, 148, "Text",
      CellTags->{"i:14", "A.2"}]},
  "i:15"->{
    Cell[28132, 1006, 998, 29, 128, "Text",
      CellTags->{"i:15", "A.2"}]},
  "A.3"->{
    Cell[30918, 1100, 52, 1, 40, "Section",
      CellTags->"A.3"],
    Cell[30995, 1105, 66, 1, 40, "Subsection",
      CellTags->"A.3"],
    Cell[31064, 1108, 878, 21, 144, "Text",
      CellTags->"A.3"],
    Cell[31967, 1133, 45, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[32015, 1136, 103, 2, 38, "Print",
      CellTags->"A.3"],
    Cell[32133, 1141, 315, 9, 58, "Text",
      CellTags->"A.3"],
    Cell[32451, 1152, 270, 9, 54, "Text",
      CellTags->"A.3"],
    Cell[32758, 1166, 70, 1, 40, "Subsection",
      CellTags->"A.3"],
    Cell[32831, 1169, 882, 23, 128, "Text",
      CellTags->"A.3"],
    Cell[33716, 1194, 56, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[33775, 1197, 374, 8, 68, "Note",
      CellTags->"A.3"],
    Cell[34152, 1207, 691, 10, 122, "Text",
      CellTags->{"i:16", "A.3"}],
    Cell[34868, 1221, 44, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[34915, 1224, 55, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[34985, 1229, 140, 4, 38, "Text",
      CellTags->"A.3"],
    Cell[35150, 1237, 51, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[35204, 1240, 56, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[35275, 1245, 366, 10, 56, "Text",
      CellTags->"A.3"],
    Cell[35644, 1257, 502, 10, 96, "Text",
      CellTags->{"i:17", "A.3"}],
    Cell[36149, 1269, 43, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[36195, 1272, 154, 5, 26, "Text",
      CellTags->"A.3"],
    Cell[36374, 1281, 48, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[36425, 1284, 62, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[36502, 1289, 455, 9, 84, "Text",
      CellTags->"A.3"],
    Cell[36960, 1300, 73, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[37036, 1303, 297, 6, 66, "Text",
      CellTags->"A.3"],
    Cell[37358, 1313, 47, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[37408, 1316, 61, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[37484, 1321, 161, 5, 40, "Text",
      CellTags->"A.3"],
    Cell[37670, 1330, 37, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[37710, 1333, 38, 1, 38, "Output",
      CellTags->"A.3"],
    Cell[37763, 1337, 711, 17, 116, "Text",
      CellTags->{"i:18", "A.3"}],
    Cell[38477, 1356, 352, 8, 68, "Text",
      CellTags->"A.3"],
    Cell[38832, 1366, 84, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[38919, 1369, 120, 4, 24, "Text",
      CellTags->"A.3"],
    Cell[39076, 1378, 66, 1, 40, "Subsection",
      CellTags->"A.3"],
    Cell[39145, 1381, 419, 8, 80, "Text",
      CellTags->"A.3"],
    Cell[39567, 1391, 156, 4, 38, "Text",
      CellTags->"A.3"],
    Cell[39726, 1397, 78, 4, 50, "Input",
      CellTags->"A.3"],
    Cell[39807, 1403, 70, 1, 24, "Text",
      CellTags->"A.3"],
    Cell[39902, 1408, 75, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[39980, 1411, 56, 1, 38, "Output",
      CellTags->"A.3"],
    Cell[40051, 1415, 578, 13, 98, "Text",
      CellTags->"A.3"],
    Cell[40632, 1430, 808, 16, 140, "Text",
      CellTags->"A.3"],
    Cell[41443, 1448, 201, 7, 42, "Text",
      CellTags->"A.3"],
    Cell[41647, 1457, 233, 6, 40, "Text",
      CellTags->{"i:19", "A.3"}],
    Cell[41905, 1467, 42, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[41950, 1470, 66, 2, 38, "Print",
      CellTags->"A.3"],
    Cell[42019, 1474, 295, 9, 68, "Print",
      CellTags->"A.3"],
    Cell[42329, 1486, 574, 14, 100, "Text",
      CellTags->"A.3"],
    Cell[42906, 1502, 264, 6, 52, "Text",
      CellTags->"A.3"],
    Cell[43173, 1510, 287, 7, 89, "Input",
      CellTags->"A.3"],
    Cell[43463, 1519, 366, 7, 66, "Text",
      CellTags->"A.3"],
    Cell[43854, 1530, 194, 5, 63, "Input",
      CellTags->"A.3"],
    Cell[44051, 1537, 109, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[44175, 1542, 509, 11, 98, "Text",
      CellTags->"A.3"],
    Cell[44687, 1555, 469, 8, 94, "Text",
      CellTags->"A.3"],
    Cell[45193, 1568, 66, 1, 40, "Subsection",
      CellTags->"A.3"],
    Cell[45262, 1571, 406, 9, 68, "Text",
      CellTags->{"i:20", "A.3"}],
    Cell[45671, 1582, 287, 6, 66, "Text",
      CellTags->{"i:21", "A.3"}],
    Cell[45983, 1592, 43, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[46029, 1595, 66, 2, 38, "Print",
      CellTags->"A.3"],
    Cell[46098, 1599, 295, 9, 68, "Print",
      CellTags->"A.3"],
    Cell[46430, 1613, 56, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[46489, 1616, 66, 2, 38, "Print",
      CellTags->"A.3"],
    Cell[46570, 1621, 314, 6, 66, "Text",
      CellTags->"A.3"],
    Cell[46921, 1632, 67, 1, 40, "Subsection",
      CellTags->"A.3"],
    Cell[46991, 1635, 430, 11, 70, "Text",
      CellTags->{"i:22", "A.3"}],
    Cell[47424, 1648, 170, 7, 26, "Text",
      CellTags->"A.3"],
    Cell[47619, 1659, 43, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[47665, 1662, 66, 2, 38, "Print",
      CellTags->"A.3"],
    Cell[47734, 1666, 272, 9, 38, "Print",
      CellTags->"A.3"],
    Cell[48021, 1678, 355, 8, 68, "Text",
      CellTags->"A.3"],
    Cell[48401, 1690, 58, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[48462, 1693, 76, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[48553, 1698, 173, 5, 40, "Text",
      CellTags->"A.3"],
    Cell[48751, 1707, 64, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[48818, 1710, 64, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[48897, 1715, 508, 10, 94, "Text",
      CellTags->{"i:24", "A.3"}],
    Cell[49408, 1727, 46, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[49457, 1730, 118, 4, 24, "Text",
      CellTags->"A.3"],
    Cell[49600, 1738, 52, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[49655, 1741, 64, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[49734, 1746, 505, 10, 96, "Text",
      CellTags->"A.3"],
    Cell[50264, 1760, 58, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[50325, 1763, 64, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[50404, 1768, 621, 10, 122, "Text",
      CellTags->"A.3"],
    Cell[51050, 1782, 78, 1, 37, "Input",
      CellTags->"A.3"],
    Cell[51131, 1785, 56, 2, 38, "Output",
      CellTags->"A.3"],
    Cell[51202, 1790, 237, 4, 52, "Text",
      CellTags->"A.3"]},
  "i:16"->{
    Cell[34152, 1207, 691, 10, 122, "Text",
      CellTags->{"i:16", "A.3"}]},
  "i:17"->{
    Cell[35644, 1257, 502, 10, 96, "Text",
      CellTags->{"i:17", "A.3"}]},
  "i:18"->{
    Cell[37763, 1337, 711, 17, 116, "Text",
      CellTags->{"i:18", "A.3"}]},
  "i:19"->{
    Cell[41647, 1457, 233, 6, 40, "Text",
      CellTags->{"i:19", "A.3"}]},
  "i:20"->{
    Cell[45262, 1571, 406, 9, 68, "Text",
      CellTags->{"i:20", "A.3"}]},
  "i:21"->{
    Cell[45671, 1582, 287, 6, 66, "Text",
      CellTags->{"i:21", "A.3"}]},
  "i:22"->{
    Cell[46991, 1635, 430, 11, 70, "Text",
      CellTags->{"i:22", "A.3"}]},
  "i:24"->{
    Cell[48897, 1715, 508, 10, 94, "Text",
      CellTags->{"i:24", "A.3"}]},
  "A.4"->{
    Cell[51488, 1800, 53, 1, 40, "Section",
      CellTags->"A.4"],
    Cell[51544, 1803, 384, 10, 70, "Text",
      CellTags->"A.4"],
    Cell[51953, 1817, 73, 1, 40, "Subsection",
      CellTags->"A.4"],
    Cell[52029, 1820, 704, 12, 124, "Text",
      CellTags->{"i:23", "A.4"}],
    Cell[52736, 1834, 570, 12, 96, "Text",
      CellTags->"A.4"],
    Cell[53309, 1848, 499, 12, 82, "Note",
      CellTags->"A.4"],
    Cell[53811, 1862, 392, 7, 80, "Text",
      CellTags->"A.4"],
    Cell[54206, 1871, 517, 14, 86, "Text",
      CellTags->"A.4"],
    Cell[54726, 1887, 175, 8, 37, "Input",
      CellTags->"A.4"],
    Cell[54904, 1897, 171, 4, 38, "Text",
      CellTags->"A.4"],
    Cell[55078, 1903, 135, 4, 38, "Text",
      CellTags->"A.4"],
    Cell[55216, 1909, 108, 2, 20, "BulletListItem",
      CellTags->"A.4"],
    Cell[55327, 1913, 195, 5, 34, "BulletListItem",
      CellTags->"A.4"],
    Cell[55525, 1920, 154, 4, 34, "BulletListItem",
      CellTags->"A.4"],
    Cell[55682, 1926, 85, 1, 20, "BulletListItem",
      CellTags->"A.4"],
    Cell[55770, 1929, 414, 8, 76, "BulletListItem",
      CellTags->"A.4"],
    Cell[56187, 1939, 402, 7, 76, "BulletListItem",
      CellTags->"A.4"],
    Cell[56592, 1948, 265, 6, 48, "BulletListItem",
      CellTags->"A.4"],
    Cell[56860, 1956, 81, 1, 24, "Text",
      CellTags->"A.4"],
    Cell[56944, 1959, 125, 4, 20, "BulletListItem",
      CellTags->"A.4"],
    Cell[57072, 1965, 174, 4, 34, "BulletListItem",
      CellTags->"A.4"],
    Cell[57249, 1971, 136, 4, 34, "BulletListItem",
      CellTags->"A.4"]},
  "i:23"->{
    Cell[52029, 1820, 704, 12, 124, "Text",
      CellTags->{"i:23", "A.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"A.0", 58892, 2014},
  {"A.1", 59103, 2021},
  {"i:1", 60952, 2076},
  {"i:2", 61037, 2079},
  {"i:3", 61123, 2082},
  {"i:4", 61208, 2085},
  {"A.2", 61296, 2088},
  {"i:5", 66973, 2257},
  {"i:6", 67062, 2260},
  {"i:7", 67148, 2263},
  {"i:8", 67235, 2266},
  {"i:9", 67324, 2269},
  {"i:10", 67411, 2272},
  {"i:11", 67500, 2275},
  {"i:12", 67590, 2278},
  {"i:13", 67681, 2281},
  {"i:14", 67769, 2284},
  {"i:15", 67860, 2287},
  {"A.3", 67950, 2290},
  {"i:16", 74049, 2471},
  {"i:17", 74140, 2474},
  {"i:18", 74230, 2477},
  {"i:19", 74321, 2480},
  {"i:20", 74410, 2483},
  {"i:21", 74499, 2486},
  {"i:22", 74588, 2489},
  {"i:24", 74678, 2492},
  {"A.4", 74767, 2495},
  {"i:23", 76354, 2540}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 52, 1, 92, "ChapterLine",
  CellTags->"A.0"],
Cell[1786, 54, 120, 6, 156, "Title",
  CellTags->"A.0"],
Cell[1909, 62, 821, 21, 116, "Text",
  CellTags->"A.0"],

Cell[CellGroupData[{
Cell[2755, 87, 54, 1, 40, "Section",
  CellTags->"A.1"],

Cell[CellGroupData[{
Cell[2834, 92, 75, 1, 40, "Subsection",
  CellTags->"A.1"],
Cell[2912, 95, 700, 21, 70, "Text",
  CellTags->{"i:1", "A.1"}],
Cell[3615, 118, 196, 9, 37, "Input",
  CellTags->"A.1"],
Cell[3814, 129, 603, 16, 102, "Text",
  CellTags->"A.1"],
Cell[4420, 147, 70, 2, 37, "Input",
  CellTags->"A.1"],
Cell[4493, 151, 493, 12, 70, "Text",
  CellTags->{"i:2", "A.1"}],

Cell[CellGroupData[{
Cell[5011, 167, 55, 1, 37, "Input",
  CellTags->"A.1"],
Cell[5069, 170, 181, 6, 38, "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5299, 182, 70, 1, 40, "Subsection",
  CellTags->"A.1"],
Cell[5372, 185, 548, 15, 86, "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{
Cell[5945, 204, 49, 1, 30, "Subsubsection",
  CellTags->"A.1"],
Cell[5997, 207, 319, 7, 38, "Text",
  CellTags->{"i:3", "A.1"}],
Cell[6319, 216, 295, 10, 36, "BulletListItem",
  CellTags->"A.1"],
Cell[6617, 228, 196, 7, 36, "BulletListItem",
  CellTags->"A.1"],
Cell[6816, 237, 291, 8, 50, "BulletListItem",
  CellTags->"A.1"],
Cell[7110, 247, 155, 4, 38, "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{
Cell[7290, 255, 118, 4, 50, "Input",
  CellTags->"A.1"],
Cell[7411, 261, 558, 18, 38, "Output",
  CellTags->"A.1"]
}, Open  ]],
Cell[7984, 282, 125, 4, 38, "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{
Cell[8134, 290, 88, 1, 37, "Input",
  CellTags->"A.1"],
Cell[8225, 293, 78, 2, 38, "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8352, 301, 62, 1, 30, "Subsubsection",
  CellTags->"A.1"],
Cell[8417, 304, 1019, 17, 180, "Text",
  CellTags->{"i:4", "A.1"}],
Cell[9439, 323, 345, 7, 68, "Text",
  CellTags->"A.1"],

Cell[CellGroupData[{
Cell[9809, 334, 50, 1, 37, "Input",
  CellTags->"A.1"],
Cell[9862, 337, 55, 2, 38, "Output",
  CellTags->"A.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9990, 347, 51, 1, 40, "Section",
  CellTags->"A.2"],
Cell[10044, 350, 1100, 25, 156, "Text",
  CellTags->{"i:5", "A.2"}],
Cell[11147, 377, 875, 19, 140, "Text",
  CellTags->"A.2"],
Cell[12025, 398, 286, 7, 54, "Text",
  CellTags->{"i:6", "A.2"}],

Cell[CellGroupData[{
Cell[12336, 409, 43, 1, 37, "Input",
  CellTags->"A.2"],
Cell[12382, 412, 150, 3, 53, "Print",
  CellTags->"A.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12569, 420, 68, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[12640, 423, 441, 11, 84, "Text",
  CellTags->{"i:7", "A.2"}],

Cell[CellGroupData[{
Cell[13106, 438, 52, 1, 37, "Input",
  CellTags->"A.2"],
Cell[13161, 441, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[13233, 446, 440, 11, 82, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[13698, 461, 90, 1, 37, "Input",
  CellTags->"A.2"],
Cell[13791, 464, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[13863, 469, 363, 8, 68, "Note",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[14251, 481, 75, 1, 37, "Input",
  CellTags->"A.2"],
Cell[14329, 484, 58, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[14402, 489, 494, 14, 72, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[14921, 507, 68, 1, 37, "Input",
  CellTags->"A.2"],
Cell[14992, 510, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[15064, 515, 1300, 32, 192, "Text",
  CellTags->{"i:8", "A.2"}],

Cell[CellGroupData[{
Cell[16389, 551, 56, 1, 37, "Input",
  CellTags->"A.2"],
Cell[16448, 554, 58, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16555, 562, 81, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[16639, 565, 138, 4, 38, "Text",
  CellTags->"A.2"],
Cell[16780, 571, 383, 8, 68, "Text",
  CellTags->{"i:9", "A.2"}],

Cell[CellGroupData[{
Cell[17188, 583, 128, 4, 50, "Input",
  CellTags->"A.2"],
Cell[17319, 589, 66, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[17400, 594, 385, 11, 54, "Text",
  CellTags->{"i:10", "A.2"}],

Cell[CellGroupData[{
Cell[17810, 609, 124, 5, 63, "Input",
  CellTags->"A.2"],
Cell[17937, 616, 73, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[18025, 621, 534, 12, 96, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[18584, 637, 93, 1, 37, "Input",
  CellTags->"A.2"],
Cell[18680, 640, 71, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[18766, 645, 286, 6, 66, "Text",
  CellTags->"A.2"],
Cell[19055, 653, 170, 5, 38, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[19250, 662, 84, 1, 37, "Input",
  CellTags->"A.2"],
Cell[19337, 665, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[19409, 670, 192, 5, 38, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[19626, 679, 84, 1, 37, "Input",
  CellTags->"A.2"],
Cell[19713, 682, 58, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[19786, 687, 179, 5, 38, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[19990, 696, 91, 1, 37, "Input",
  CellTags->"A.2"],
Cell[20084, 699, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[20156, 704, 195, 5, 38, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[20376, 713, 89, 1, 37, "Input",
  CellTags->"A.2"],
Cell[20468, 716, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20574, 724, 60, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[20637, 727, 840, 29, 102, "Text",
  CellTags->{"i:11", "A.2"}],
Cell[21480, 758, 204, 5, 52, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[21709, 767, 87, 1, 37, "Input",
  CellTags->"A.2"],
Cell[21799, 770, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[21871, 775, 288, 8, 54, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[22184, 787, 88, 1, 37, "Input",
  CellTags->"A.2"],
Cell[22275, 790, 58, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22382, 798, 59, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[22444, 801, 1019, 25, 158, "Text",
  CellTags->{"i:12", "A.2"}],

Cell[CellGroupData[{
Cell[23488, 830, 57, 1, 37, "Input",
  CellTags->"A.2"],
Cell[23548, 833, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[23620, 838, 764, 19, 126, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[24409, 861, 129, 5, 63, "Input",
  CellTags->"A.2"],
Cell[24541, 868, 73, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24663, 876, 57, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[24723, 879, 207, 5, 38, "Text",
  CellTags->{"i:13", "A.2"}],
Cell[24933, 886, 554, 15, 84, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[25512, 905, 132, 4, 50, "Input",
  CellTags->"A.2"],
Cell[25647, 911, 57, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[25719, 916, 206, 5, 38, "Text",
  CellTags->"A.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25962, 926, 81, 1, 40, "Subsection",
  CellTags->"A.2"],
Cell[26046, 929, 1269, 44, 148, "Text",
  CellTags->{"i:14", "A.2"}],

Cell[CellGroupData[{
Cell[27340, 977, 102, 2, 37, "Input",
  CellTags->"A.2"],
Cell[27445, 981, 78, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[27538, 986, 321, 6, 66, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[27884, 996, 151, 3, 50, "Input",
  CellTags->"A.2"],
Cell[28038, 1001, 79, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[28132, 1006, 998, 29, 128, "Text",
  CellTags->{"i:15", "A.2"}],
Cell[29133, 1037, 318, 6, 66, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[29476, 1047, 89, 1, 37, "Input",
  CellTags->"A.2"],
Cell[29568, 1050, 133, 3, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[29716, 1056, 256, 6, 52, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[29997, 1066, 96, 1, 37, "Input",
  CellTags->"A.2"],
Cell[30096, 1069, 132, 3, 38, "Output",
  CellTags->"A.2"]
}, Open  ]],
Cell[30243, 1075, 352, 7, 66, "Text",
  CellTags->"A.2"],

Cell[CellGroupData[{
Cell[30620, 1086, 151, 3, 50, "Input",
  CellTags->"A.2"],
Cell[30774, 1091, 83, 2, 38, "Output",
  CellTags->"A.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30918, 1100, 52, 1, 40, "Section",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[30995, 1105, 66, 1, 40, "Subsection",
  CellTags->"A.3"],
Cell[31064, 1108, 878, 21, 144, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[31967, 1133, 45, 1, 37, "Input",
  CellTags->"A.3"],
Cell[32015, 1136, 103, 2, 38, "Print",
  CellTags->"A.3"]
}, Open  ]],
Cell[32133, 1141, 315, 9, 58, "Text",
  CellTags->"A.3"],
Cell[32451, 1152, 270, 9, 54, "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32758, 1166, 70, 1, 40, "Subsection",
  CellTags->"A.3"],
Cell[32831, 1169, 882, 23, 128, "Text",
  CellTags->"A.3"],
Cell[33716, 1194, 56, 1, 37, "Input",
  CellTags->"A.3"],
Cell[33775, 1197, 374, 8, 68, "Note",
  CellTags->"A.3"],
Cell[34152, 1207, 691, 10, 122, "Text",
  CellTags->{"i:16", "A.3"}],

Cell[CellGroupData[{
Cell[34868, 1221, 44, 1, 37, "Input",
  CellTags->"A.3"],
Cell[34915, 1224, 55, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[34985, 1229, 140, 4, 38, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[35150, 1237, 51, 1, 37, "Input",
  CellTags->"A.3"],
Cell[35204, 1240, 56, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[35275, 1245, 366, 10, 56, "Text",
  CellTags->"A.3"],
Cell[35644, 1257, 502, 10, 96, "Text",
  CellTags->{"i:17", "A.3"}],
Cell[36149, 1269, 43, 1, 37, "Input",
  CellTags->"A.3"],
Cell[36195, 1272, 154, 5, 26, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[36374, 1281, 48, 1, 37, "Input",
  CellTags->"A.3"],
Cell[36425, 1284, 62, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[36502, 1289, 455, 9, 84, "Text",
  CellTags->"A.3"],
Cell[36960, 1300, 73, 1, 37, "Input",
  CellTags->"A.3"],
Cell[37036, 1303, 297, 6, 66, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[37358, 1313, 47, 1, 37, "Input",
  CellTags->"A.3"],
Cell[37408, 1316, 61, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[37484, 1321, 161, 5, 40, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[37670, 1330, 37, 1, 37, "Input",
  CellTags->"A.3"],
Cell[37710, 1333, 38, 1, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[37763, 1337, 711, 17, 116, "Text",
  CellTags->{"i:18", "A.3"}],
Cell[38477, 1356, 352, 8, 68, "Text",
  CellTags->"A.3"],
Cell[38832, 1366, 84, 1, 37, "Input",
  CellTags->"A.3"],
Cell[38919, 1369, 120, 4, 24, "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39076, 1378, 66, 1, 40, "Subsection",
  CellTags->"A.3"],
Cell[39145, 1381, 419, 8, 80, "Text",
  CellTags->"A.3"],
Cell[39567, 1391, 156, 4, 38, "Text",
  CellTags->"A.3"],
Cell[39726, 1397, 78, 4, 50, "Input",
  CellTags->"A.3"],
Cell[39807, 1403, 70, 1, 24, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[39902, 1408, 75, 1, 37, "Input",
  CellTags->"A.3"],
Cell[39980, 1411, 56, 1, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[40051, 1415, 578, 13, 98, "Text",
  CellTags->"A.3"],
Cell[40632, 1430, 808, 16, 140, "Text",
  CellTags->"A.3"],
Cell[41443, 1448, 201, 7, 42, "Text",
  CellTags->"A.3"],
Cell[41647, 1457, 233, 6, 40, "Text",
  CellTags->{"i:19", "A.3"}],

Cell[CellGroupData[{
Cell[41905, 1467, 42, 1, 37, "Input",
  CellTags->"A.3"],
Cell[41950, 1470, 66, 2, 38, "Print",
  CellTags->"A.3"],
Cell[42019, 1474, 295, 9, 68, "Print",
  CellTags->"A.3"]
}, Open  ]],
Cell[42329, 1486, 574, 14, 100, "Text",
  CellTags->"A.3"],
Cell[42906, 1502, 264, 6, 52, "Text",
  CellTags->"A.3"],
Cell[43173, 1510, 287, 7, 89, "Input",
  CellTags->"A.3"],
Cell[43463, 1519, 366, 7, 66, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[43854, 1530, 194, 5, 63, "Input",
  CellTags->"A.3"],
Cell[44051, 1537, 109, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[44175, 1542, 509, 11, 98, "Text",
  CellTags->"A.3"],
Cell[44687, 1555, 469, 8, 94, "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45193, 1568, 66, 1, 40, "Subsection",
  CellTags->"A.3"],
Cell[45262, 1571, 406, 9, 68, "Text",
  CellTags->{"i:20", "A.3"}],
Cell[45671, 1582, 287, 6, 66, "Text",
  CellTags->{"i:21", "A.3"}],

Cell[CellGroupData[{
Cell[45983, 1592, 43, 1, 37, "Input",
  CellTags->"A.3"],
Cell[46029, 1595, 66, 2, 38, "Print",
  CellTags->"A.3"],
Cell[46098, 1599, 295, 9, 68, "Print",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46430, 1613, 56, 1, 37, "Input",
  CellTags->"A.3"],
Cell[46489, 1616, 66, 2, 38, "Print",
  CellTags->"A.3"]
}, Open  ]],
Cell[46570, 1621, 314, 6, 66, "Text",
  CellTags->"A.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46921, 1632, 67, 1, 40, "Subsection",
  CellTags->"A.3"],
Cell[46991, 1635, 430, 11, 70, "Text",
  CellTags->{"i:22", "A.3"}],
Cell[47424, 1648, 170, 7, 26, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[47619, 1659, 43, 1, 37, "Input",
  CellTags->"A.3"],
Cell[47665, 1662, 66, 2, 38, "Print",
  CellTags->"A.3"],
Cell[47734, 1666, 272, 9, 38, "Print",
  CellTags->"A.3"]
}, Open  ]],
Cell[48021, 1678, 355, 8, 68, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[48401, 1690, 58, 1, 37, "Input",
  CellTags->"A.3"],
Cell[48462, 1693, 76, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[48553, 1698, 173, 5, 40, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[48751, 1707, 64, 1, 37, "Input",
  CellTags->"A.3"],
Cell[48818, 1710, 64, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[48897, 1715, 508, 10, 94, "Text",
  CellTags->{"i:24", "A.3"}],
Cell[49408, 1727, 46, 1, 37, "Input",
  CellTags->"A.3"],
Cell[49457, 1730, 118, 4, 24, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[49600, 1738, 52, 1, 37, "Input",
  CellTags->"A.3"],
Cell[49655, 1741, 64, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[49734, 1746, 505, 10, 96, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[50264, 1760, 58, 1, 37, "Input",
  CellTags->"A.3"],
Cell[50325, 1763, 64, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[50404, 1768, 621, 10, 122, "Text",
  CellTags->"A.3"],

Cell[CellGroupData[{
Cell[51050, 1782, 78, 1, 37, "Input",
  CellTags->"A.3"],
Cell[51131, 1785, 56, 2, 38, "Output",
  CellTags->"A.3"]
}, Open  ]],
Cell[51202, 1790, 237, 4, 52, "Text",
  CellTags->"A.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51488, 1800, 53, 1, 40, "Section",
  CellTags->"A.4"],
Cell[51544, 1803, 384, 10, 70, "Text",
  CellTags->"A.4"],

Cell[CellGroupData[{
Cell[51953, 1817, 73, 1, 40, "Subsection",
  CellTags->"A.4"],
Cell[52029, 1820, 704, 12, 124, "Text",
  CellTags->{"i:23", "A.4"}],
Cell[52736, 1834, 570, 12, 96, "Text",
  CellTags->"A.4"],
Cell[53309, 1848, 499, 12, 82, "Note",
  CellTags->"A.4"],
Cell[53811, 1862, 392, 7, 80, "Text",
  CellTags->"A.4"],
Cell[54206, 1871, 517, 14, 86, "Text",
  CellTags->"A.4"],
Cell[54726, 1887, 175, 8, 37, "Input",
  CellTags->"A.4"],
Cell[54904, 1897, 171, 4, 38, "Text",
  CellTags->"A.4"],
Cell[55078, 1903, 135, 4, 38, "Text",
  CellTags->"A.4"],
Cell[55216, 1909, 108, 2, 20, "BulletListItem",
  CellTags->"A.4"],
Cell[55327, 1913, 195, 5, 34, "BulletListItem",
  CellTags->"A.4"],
Cell[55525, 1920, 154, 4, 34, "BulletListItem",
  CellTags->"A.4"],
Cell[55682, 1926, 85, 1, 20, "BulletListItem",
  CellTags->"A.4"],
Cell[55770, 1929, 414, 8, 76, "BulletListItem",
  CellTags->"A.4"],
Cell[56187, 1939, 402, 7, 76, "BulletListItem",
  CellTags->"A.4"],
Cell[56592, 1948, 265, 6, 48, "BulletListItem",
  CellTags->"A.4"],
Cell[56860, 1956, 81, 1, 24, "Text",
  CellTags->"A.4"],
Cell[56944, 1959, 125, 4, 20, "BulletListItem",
  CellTags->"A.4"],
Cell[57072, 1965, 174, 4, 34, "BulletListItem",
  CellTags->"A.4"],
Cell[57249, 1971, 136, 4, 34, "BulletListItem",
  CellTags->"A.4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

