(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23127,        900]*)
(*NotebookOutlinePosition[     23966,        927]*)
(*  CellTagsIndexPosition[     23922,        923]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->5,
  FontSize->12,
  PrivateFontOptions->{"FontType"->"Bitmap"}],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            StyleBox[ 
              CounterBox[ "Page"], "PageNumber"], "     ", 
            StyleBox[ "Simulating Society", FontSlant -> "Italic"]}], 
          "Header"], None, None}, {None, None, Cell[ 
          TextData[ {
            StyleBox[ "Simulating Society", FontSlant -> "Italic"], "     ", 
            StyleBox[ 
              CounterBox[ "Page"], "PageNumber"]}], "Header"]}},
  PageFooters->{{
    None, Cell[ 
        "\[Copyright] 1998 Springer-Verlag. All rights reserved.", "Footer"], 
        None}, {None, Cell[ 
        "\[Copyright] 1998 Springer-Verlag. All rights reserved.", "Footer"], 
        None}},
  PageHeaderLines->{True, True},
  PageFooterLines->{False, False},
  PrintingOptions->{"PrintingMargins"->{{99, 99}, {180, 59}},
  "FirstPageHeader"->False,
  "FirstPageFooter"->False,
  "FacingPages"->True},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{2, 2}, {96, 30}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  TextAlignment->Left,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Plain"],

Cell[StyleData["Title", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{2, 10}, {12, 8}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Subtitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{2, 10}, {12, 8}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{2, 2}, {0, 22}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->Automatic,
  TextAlignment->Left,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  ShowGroupOpenCloseIcon->False,
  FontSize->14,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellMargins->{{74, 0}, {0, 22}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->Automatic,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["Subsection", "Printout"],
  ShowGroupOpenCloseIcon->False,
  FontSize->12,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{74, 0}, {0, 14}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["Subsubsection", "Printout"],
  ShowGroupOpenCloseIcon->False,
  FontSize->11,
  FontWeight->"Plain"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{74, 0}, {5, 5}},
  PageBreakWithin->Automatic,
  LineSpacing->{1, 2},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{2, 2}, {5, 5}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{12, 0}, {4, 4}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->True,
  GroupPageBreakWithin->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontFamily->"Courier",
  FontSize->10,
  FontWeight->"Bold",
  Background->GrayLevel[0.900008]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{85, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontWeight->"Plain",
  Background->None]
}, Open  ]],

Cell[StyleData["InputOnly"],
  CellMargins->{{12, Inherited}, {Inherited, Inherited}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontSize->12,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{12, 0}, {6, 3}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->True,
  GroupPageBreakWithin->True,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Left,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  FontSize->10,
  Background->RGBColor[1, 0.966155, 0.710002]],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{85, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontSlant->"Italic",
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{12, 0}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->10,
  FontColor->GrayLevel[0],
  Background->RGBColor[1, 0.966155, 0.710002]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{85, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{12, 0}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  FontSize->10,
  Background->RGBColor[1, 0.966155, 0.710002]],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{85, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontSlant->"Italic",
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{12, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Center,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["Graphics", "Printout"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  CellMargins->{{12, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  CellMargins->{{7, Inherited}, {Inherited, Inherited}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{2, 0}, {6, 6}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True],

Cell[StyleData["InlineFormula", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Plain"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->Primary,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Times"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["Other Book Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Note"],
  CellMargins->{{74, 0}, {5, 5}},
  PageBreakWithin->True,
  LineSpacing->{1, 2},
  CounterIncrements->"Text",
  StyleMenuListing->None],

Cell[StyleData["Note", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Project"],
  CellMargins->{{74, 2}, {5, 5}},
  PageBreakWithin->True,
  LineSpacing->{1, 2},
  CounterIncrements->"Project",
  CounterBoxOptions->{CounterFunction:>Identity},
  StyleMenuListing->None],

Cell[StyleData["Project", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ListItem"],
  CellMargins->{{80, 2}, {3, 3}},
  PageBreakWithin->True,
  LineSpacing->{1, 2},
  ParagraphIndent->-20,
  CounterIncrements->"ListItem",
  StyleMenuListing->None],

Cell[StyleData["ListItem", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BulletListItem"],
  CellDingbat->"\[Bullet]",
  CellMargins->{{88, 2}, {3, 3}},
  PageBreakWithin->True,
  LineSpacing->{1, 2},
  CounterIncrements->"BulletListItem",
  StyleMenuListing->None],

Cell[StyleData["BulletListItem", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{80, 2}, {4, 4}},
  LineSpacing->{1, 2},
  ParagraphIndent->-20,
  CounterIncrements->"Reference",
  StyleMenuListing->None],

Cell[StyleData["Reference", "Printout"],
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Quote"],
  CellMargins->{{74, 2}, {2, 6}},
  TextAlignment->Left,
  TextJustification->1,
  LineSpacing->{1, 2},
  CounterIncrements->"Quote",
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["Quote", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["QuoteAttribution"],
  CellMargins->{{74, 2}, {6, 2}},
  TextAlignment->Right,
  TextJustification->1,
  LineSpacing->{1, 2},
  CounterIncrements->"Quote",
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["QuoteAttribution", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["IT", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChapterLine"],
  CellFrame->{{0, 0}, {1, 0}},
  CellMargins->{{Inherited, Inherited}, {50, 6}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  TextAlignment->Left,
  CounterIncrements->"ChapterLine",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Plain"],

Cell[StyleData["ChapterLine", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ReferenceNote"],
  CellMargins->{{100, 0}, {5, 5}},
  PageBreakWithin->Automatic,
  LineSpacing->{1, 2},
  CounterIncrements->"Text",
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["ReferenceNote", "Printout"],
  TextJustification->1,
  FontSize->9]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowSize->{520, 509},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 62, "Subtitle"],
Cell[1771, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 42, 0, 50, "Section"],
Cell[2034, 63, 139, 4, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2176, 69, 124, 3, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2337, 77, 35, 0, 30, "Section"],
Cell[2375, 79, 101, 3, 30, "Text"],
Cell[2479, 84, 971, 24, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3487, 113, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[3550, 117, 362, 10, 167, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[3915, 129, 36, 0, 121, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3988, 134, 328, 9, 48, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[4319, 145, 39, 0, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4395, 150, 333, 9, 48, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4731, 161, 42, 0, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4810, 166, 320, 9, 36, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[5133, 177, 110, 3, 52, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5280, 185, 307, 9, 36, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[5590, 196, 113, 3, 51, 41, 0, "StyleData", "Subsection", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5740, 204, 264, 8, 44, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[6007, 214, 116, 3, 41, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6172, 223, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[6236, 227, 139, 4, 38, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[6378, 233, 75, 2, 37, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6490, 240, 160, 5, 35, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[6653, 247, 40, 0, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6742, 253, 42, 0, 30, "Section"],
Cell[6787, 255, 364, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[7176, 265, 507, 16, 51, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[7686, 283, 152, 4, 34, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],
Cell[7853, 290, 384, 12, 36, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[8262, 306, 537, 16, 52, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[8802, 324, 153, 4, 35, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8992, 333, 551, 16, 51, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[9546, 351, 131, 3, 34, 38, 0, "StyleData", "Message", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9714, 359, 520, 15, 51, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[10237, 376, 152, 4, 34, 36, 0, "StyleData", "Print", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10426, 385, 481, 14, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[10910, 401, 39, 0, 36, 39, 0, "StyleData", "Graphics", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10986, 406, 186, 5, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[11175, 413, 97, 1, 34, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11321, 420, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[11389, 424, 145, 4, 70, 32, 0, "StyleData", "InlineFormula", "All"],
Cell[11537, 430, 44, 0, 70, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11618, 435, 272, 6, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[11893, 443, 45, 0, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11987, 449, 49, 0, 30, "Section"],
Cell[12039, 451, 149, 5, 32, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[12191, 458, 149, 5, 26, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[12343, 465, 154, 5, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[12534, 475, 33, 0, 30, "Section"],
Cell[12570, 477, 121, 3, 70, "Text"],
Cell[12694, 482, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[12923, 489, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[13221, 498, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[13624, 509, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[14014, 520, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[14452, 534, 35, 0, 30, "Section"],
Cell[14490, 536, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[14699, 544, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[15004, 554, 107, 2, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[15126, 559, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[15255, 566, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[15574, 576, 110, 2, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15721, 583, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16061, 594, 107, 2, 70, 40, 0, "StyleData", "AddOnLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16205, 601, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16553, 612, 110, 2, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16700, 619, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17031, 629, 116, 2, 70, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17184, 636, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17519, 646, 118, 2, 70, 51, 0, "StyleData", "OtherInformationLink", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17686, 654, 37, 0, 30, "Section"],
Cell[17726, 656, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[17866, 663, 145, 5, 70, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[18014, 670, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18093, 675, 182, 6, 70, 39, 0, "StyleData", "SelectionPlaceholder", 
"All",
  StyleMenuListing->None],
Cell[18278, 683, 51, 0, 70, 51, 0, "StyleData", "SelectionPlaceholder", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18378, 689, 36, 0, 30, "Section"],
Cell[18417, 691, 305, 5, 62, "Text"],
Cell[18725, 698, 314, 10, 36, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[19042, 710, 81, 2, 36, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[19126, 714, 149, 5, 36, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[19278, 721, 108, 3, 36, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[19389, 726, 179, 5, 36, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[19571, 733, 115, 3, 30, "Text"],
Cell[19689, 738, 96, 3, 36, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[19788, 743, 104, 2, 52, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[19929, 750, 36, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[19990, 754, 160, 5, 38, 23, 0, "StyleData", "Note", "All",
  CounterIncrements->"Text",
  StyleMenuListing->None],
Cell[20153, 761, 75, 2, 70, 35, 0, "StyleData", "Note", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20265, 768, 216, 6, 37, 26, 0, "StyleData", "Project", "All",
  CounterIncrements->"Project",
  StyleMenuListing->None],
Cell[20484, 776, 78, 2, 70, 38, 0, "StyleData", "Project", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20599, 783, 192, 6, 35, 27, 0, "StyleData", "ListItem", "All",
  CounterIncrements->"ListItem",
  StyleMenuListing->None],
Cell[20794, 791, 79, 2, 33, 39, 0, "StyleData", "ListItem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20910, 798, 208, 6, 35, 33, 0, "StyleData", "BulletListItem", "All",
  CounterIncrements->"BulletListItem",
  StyleMenuListing->None],
Cell[21121, 806, 85, 2, 33, 45, 0, "StyleData", "BulletListItem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21243, 813, 169, 5, 36, 28, 0, "StyleData", "Reference", "All",
  CounterIncrements->"Reference",
  StyleMenuListing->None],
Cell[21415, 820, 80, 2, 70, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21532, 827, 200, 7, 34, 24, 0, "StyleData", "Quote", "All",
  CounterIncrements->"Quote",
  StyleMenuListing->None],
Cell[21735, 836, 52, 1, 35, 36, 0, "StyleData", "Quote", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21824, 842, 212, 7, 38, 35, 0, "StyleData", "QuoteAttribution", "All",
  CounterIncrements->"Quote",
  StyleMenuListing->None],
Cell[22039, 851, 63, 1, 35, 47, 0, "StyleData", "QuoteAttribution", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22139, 857, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[22212, 861, 33, 0, 38, 33, 0, "StyleData", "IT", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22282, 866, 446, 12, 104, 30, 0, "StyleData", "ChapterLine", "All",
  CounterIncrements->"ChapterLine",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  StyleMenuListing->None],
Cell[22731, 880, 42, 0, 106, 42, 0, "StyleData", "ChapterLine", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22810, 885, 191, 6, 36, 32, 0, "StyleData", "ReferenceNote", "All",
  CounterIncrements->"Text",
  StyleMenuListing->None],
Cell[23004, 893, 83, 2, 36, 44, 0, "StyleData", "ReferenceNote", "Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

