(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14388,        364]*)
(*NotebookOutlinePosition[     17900,        474]*)
(*  CellTagsIndexPosition[     17692,        462]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1", "ChapterLine",
  CellTags->"1.1"],

Cell["Modeling a Society of Mobile Heterogeneous Individuals", "Title",
  CellTags->"1.1"],

Cell["\<\
\"We don't go anywhere. Going somewhere is for squares. We just go.\
\"\
\>", "Quote",
  CellTags->"1.1"],

Cell[TextData[{
  "\[LongDash]Marlon Brando in ",
  StyleBox["The Wild One",
    FontSlant->"Italic"],
  " (1954)"
}], "QuoteAttribution",
  CellTags->"1.1"],

Cell[CellGroupData[{

Cell["1.1  Introduction", "Section",
  CellTags->"1.1"],

Cell[TextData[{
  StyleBox[
  "This chapter describes a model of individuals moving about on a lattice. \
The system is ", "Text"],
  StyleBox["decentralized", "Text",
    FontSlant->"Italic"],
  StyleBox[
  " in that there is no central authority deciding which individuals will \
remain where they are, which individuals will move, and to where they will \
move. Instead, on each time step, every individual on the lattice attempts to \
move at the same time (this is known as synchronous updating) and the \
movement is local in the sense that an individual can only move from his \
current lattice site location to an adjacent site and not to a site farther \
away. We want to avoid having individuals bumping into one another in the \
process of moving and since there is no traffic controller to coordinate the \
movements of people, two requirements are imposed on each individual that \
must be met in order for him to make a move, as opposed to remaining in \
place: the adjacent site that the individual is attempting to move to must \
not already be occupied by another individual and the move must not cause a \
collision with another individual trying to move onto the same site. As we \
show, we are able to express the rules governing movement subject to these \
conditions in a set of 28 rules, each having a very simple form. In \
subsequent chapters (except in the final chapter where nonlocal movement to \
faraway sites is allowed), these rules are used to incorporate the movement \
of individuals into other models of socioeconomic behavior since the mobility \
of individuals is a central feature in many human activities.", "Text"]
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{
    "decentralization", "", ""}, {"mobility", "", ""}}},
  CellTags->{"i:1", "1.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2  Milling About", "Section",
  CellTags->"1.2"],

Cell[TextData[{
  "A system consisting of interacting individuals, each with his own \
characteristics (e.g., cultural values, race, resources), can be simulated \
using a ",
  StyleBox["discrete dynamical system ",
    FontSlant->"Italic"],
  "where space, time, and the states of the system are all discrete and have \
the following properties."
}], "Text",
  CellTags->"1.2"],

Cell["Space is represented by a regular two-dimensional lattice.", 
  "BulletListItem",
  CellTags->"1.2"],

Cell[TextData[{
  "Each site, or ",
  StyleBox["cell",
    FontSlant->"Italic"],
  ", in the lattice is in a given state at a given instant of time. The \
states of lattice sites can be integers, reals, symbols, or strings, as well \
as tuplets (lists) with elements of any type."
}], "BulletListItem",
  CellTags->"1.2"],

Cell[TextData[{
  "The system ",
  StyleBox["evolves",
    FontSlant->"Italic"],
  " over a succession of ",
  StyleBox["time steps",
    FontSlant->"Italic"],
  ". The values of all of the sites in the lattice are ",
  StyleBox["updated",
    FontSlant->"Italic"],
  " synchronously in each time step."
}], "BulletListItem",
  CellTags->"1.2"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Although the values of all of the sites are updated in each time step, \
the value of a site need not change in a given time step. "
}], "Note",
  CellTags->"1.2"],

Cell[TextData[{
  "A site's value is updated using a set of rules (known as a ",
  StyleBox["lookup table",
    FontSlant->"Italic"],
  ") which takes the values of the site and other sites into account. "
}], "BulletListItem",
  CellTags->"1.2"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Several rule sets (which need not take the values of the same set of \
sites into account) may be applied successively, one after the other, to the \
lattice during a given time step."
}], "Note",
  CellTags->"1.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3  Computer Simulation Projects", "Section",
  CellTags->"1.3"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  "  Create a lattice configuration in which all of the sites occupied by \
individuals are initially clustered together in the middle of the lattice. \
Use this lattice configuration for society in the randomWalkers model, run \
the resulting program and observe the dispersion of people from the initial \
cluster into the surrounding areas."
}], "Project",
  CellTags->"1.3"],

Cell[TextData[{
  StyleBox["2",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  "  In the course of moving around the lattice, individuals will encounter \
other individuals face-to-face on adjacent sites. In many of the models in \
the following chapters, there bilateral interactions such as economic \
transactions, information sharing, or cultural exchanges between these \
individuals. The randomWalkers program can be easily modified to allow \
individuals to keep track of the number of individuals they encounter in the \
course of their travels. This can be done by adding an element to the list of \
attributes of an individual to serve as a counter of the number of \
face-to-face encounters that he has over time. The initial value of this \
element should be zero and the value should increase by one every time the \
individual finds himself face-to-face with another individual. The counting \
process can be carried out in either of two ways: by adding four rules to the \
walk rule set to cover the face-to-face situation, or by writing five \
personToPersonInteract rules, four to cover the four situations in which an \
individual encounters another person face-to-face and one to cover all other \
possible situations. The first method has the benefit of producing more \
concise code that runs somewhat faster whereas the second method has the \
benefit of making the code easier to understand. Implement both of these \
counting methods in variants of the randomWalkers program and then run these \
programs. Calculate the average number of encounters that an individual has \
as a function of time. "
}], "Project",
  CellTags->"1.3"],

Cell[TextData[{
  StyleBox["3",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  "  We can allow an individual to keep a record of whom he encounters and \
how often he encounters them. This will be useful for some of the phenomena \
we discuss in the chapters that follow. This can be done by using as an \
additional element in an individual's attribute list, a list that is \
initially empty and to which a person's name is added whenever the individual \
encounters that person face-to-face. Modify the code you wrote in the \
previous project to allow this to be done. Run a program with these modified \
rules and calculate the average number of multiple encounters an individual \
has with other individuals as a function of time. "
}], "Project",
  CellTags->"1.3"],

Cell[TextData[{
  StyleBox["4",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  "  Using the program you developed in the previous project, determine the \
average number of new people who are encountered over time by an individual \
as a function of the population density. This can be done by eliminating \
duplicates in the encounter lists in the previous project. Look to see if \
this quantity passes through a maximum as a function of population density \
and explain why there is or is not a maximum."
}], "Project",
  CellTags->"1.3"],

Cell[TextData[{
  StyleBox["5",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  "  It is important to know if the results obtained in the simulations in \
the previous three projects are sensitive to the configuration of the system \
at the start of the run. The easiest way to check this would be to run the \
randomWalkers program several times using a different SeedRandom value (the \
SeedRandom function is explained in Appendix B) for each run. The problem \
with this method is that it's too ",
  StyleBox["shotgun",
    FontSlant->"Italic"],
  " in nature, resulting in a large number of the people in the system having \
different starting locations and orientations. An alternative, more delicate, \
method would be to modify the program so that after everyone has been placed \
on the lattice a small number of them are altered in some way (e.g., by \
changing their orientation or by exchanging their locations). Then the \
original and altered programs can be run with the same SeedRandom value and \
the results can be compared. The code modification can be done using one or \
more simple transformation rule (the Rule and ReplaceAll functions are \
explained in Appendix A) placed immediately after the society definition. \
Implement this and check to see if there is an initial condition sensitivity \
and if there is, how long it persists during the course of a simulation run."
}], "Project",
  CellTags->"1.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4  References", "Section",
  CellTags->"1.4"],

Cell[TextData[{
  "Gaylord, R.J. and K. Nishidate. 1996. \"Cellular Automaton Model for \
Random Walkers.\" ",
  StyleBox["Physical Review Letters",
    FontSlant->"Italic"],
  " 77: 1675\[Dash]1678.",
  "\n",
  StyleBox["Gaylord, R. J. and K. Nishidate. 1996. ",
    FontWeight->"Plain"],
  StyleBox[
  "MODELING NATURE: Cellular Automata Simulations Using Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". New York: TELOS/Springer-Verlag. Japanese edition, 1997.",
    FontWeight->"Plain"]
}], "Reference",
  CellTags->"1.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5  Programs in the Chapter", "Section",
  CellTags->"1.5"],

Cell[CellGroupData[{

Cell["1.5.1  randomWalkers", "Subsection",
  CellTags->"1.5"],

Cell[TextData[{
  "randomWalkers[n_, p_, g_, m_, s_, r_, t_] := \nModule[{society, RND, k, \
walk, GN},\n  RND:= Random[Integer, {1, 4}];\n  k = 0;\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \[RuleDelayed] {RND, ++k, \
Floor[g + Random[]], \n       Table[Random[Integer, {1, m}], {s}],\n       \
Random[Integer, {0, r}]};\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := \
{RND,a};\n  walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n ",
  " walk[",
  "0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  GN[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, \
0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk, #]&, \
society, t]]"
}], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{
    "randomWalkers", "", ""}}},
  CellTags->{"i:11", "1.5"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "1. Modeling a Mobile Society"}], "Header"], Inherited, 
      Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 13, "IndexEntries" -> {{"i:1", 
  "decentralization", "", ""}, {"i:1", "mobility", "", ""}, {"i:11", 
  "randomWalkers", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@YY:000000000006T<01T1T00000000000
00000000003oo`@YoM3oo`02DE`00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"1.1"],
    Cell[1777, 54, 90, 1, 180, "Title",
      CellTags->"1.1"],
    Cell[1870, 57, 115, 4, 22, "Quote",
      CellTags->"1.1"],
    Cell[1988, 63, 157, 6, 24, "QuoteAttribution",
      CellTags->"1.1"],
    Cell[2170, 73, 55, 1, 40, "Section",
      CellTags->"1.1"],
    Cell[2228, 76, 1818, 29, 292, "Text",
      CellTags->{"i:1", "1.1"}]},
  "i:1"->{
    Cell[2228, 76, 1818, 29, 292, "Text",
      CellTags->{"i:1", "1.1"}]},
  "1.2"->{
    Cell[4083, 110, 56, 1, 40, "Section",
      CellTags->"1.2"],
    Cell[4142, 113, 378, 9, 70, "Text",
      CellTags->"1.2"],
    Cell[4523, 124, 106, 2, 20, "BulletListItem",
      CellTags->"1.2"],
    Cell[4632, 128, 321, 8, 50, "BulletListItem",
      CellTags->"1.2"],
    Cell[4956, 138, 344, 12, 38, "BulletListItem",
      CellTags->"1.2"],
    Cell[5303, 152, 228, 6, 40, "Note",
      CellTags->"1.2"],
    Cell[5534, 160, 246, 6, 36, "BulletListItem",
      CellTags->"1.2"],
    Cell[5783, 168, 280, 7, 54, "Note",
      CellTags->"1.2"]},
  "1.3"->{
    Cell[6100, 180, 71, 1, 40, "Section",
      CellTags->"1.3"],
    Cell[6174, 183, 476, 11, 82, "Project",
      CellTags->"1.3"],
    Cell[6653, 196, 1677, 27, 292, "Project",
      CellTags->"1.3"],
    Cell[8333, 225, 792, 15, 138, "Project",
      CellTags->"1.3"],
    Cell[9128, 242, 562, 12, 96, "Project",
      CellTags->"1.3"],
    Cell[9693, 256, 1451, 25, 238, "Project",
      CellTags->"1.3"]},
  "1.4"->{
    Cell[11181, 286, 53, 1, 40, "Section",
      CellTags->"1.4"],
    Cell[11237, 289, 556, 16, 84, "Reference",
      CellTags->"1.4"]},
  "1.5"->{
    Cell[11830, 310, 66, 1, 40, "Section",
      CellTags->"1.5"],
    Cell[11921, 315, 61, 1, 40, "Subsection",
      CellTags->"1.5"],
    Cell[11985, 318, 2363, 41, 570, "Input",
      CellTags->{"i:11", "1.5"}]},
  "i:11"->{
    Cell[11985, 318, 2363, 41, 570, "Input",
      CellTags->{"i:11", "1.5"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.1", 15707, 397},
  {"i:1", 16131, 410},
  {"1.2", 16218, 413},
  {"1.3", 16785, 430},
  {"1.4", 17208, 443},
  {"1.5", 17358, 448},
  {"i:11", 17587, 455}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"1.1"],
Cell[1777, 54, 90, 1, 180, "Title",
  CellTags->"1.1"],
Cell[1870, 57, 115, 4, 22, "Quote",
  CellTags->"1.1"],
Cell[1988, 63, 157, 6, 24, "QuoteAttribution",
  CellTags->"1.1"],

Cell[CellGroupData[{
Cell[2170, 73, 55, 1, 40, "Section",
  CellTags->"1.1"],
Cell[2228, 76, 1818, 29, 292, "Text",
  CellTags->{"i:1", "1.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4083, 110, 56, 1, 40, "Section",
  CellTags->"1.2"],
Cell[4142, 113, 378, 9, 70, "Text",
  CellTags->"1.2"],
Cell[4523, 124, 106, 2, 20, "BulletListItem",
  CellTags->"1.2"],
Cell[4632, 128, 321, 8, 50, "BulletListItem",
  CellTags->"1.2"],
Cell[4956, 138, 344, 12, 38, "BulletListItem",
  CellTags->"1.2"],
Cell[5303, 152, 228, 6, 40, "Note",
  CellTags->"1.2"],
Cell[5534, 160, 246, 6, 36, "BulletListItem",
  CellTags->"1.2"],
Cell[5783, 168, 280, 7, 54, "Note",
  CellTags->"1.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6100, 180, 71, 1, 40, "Section",
  CellTags->"1.3"],
Cell[6174, 183, 476, 11, 82, "Project",
  CellTags->"1.3"],
Cell[6653, 196, 1677, 27, 292, "Project",
  CellTags->"1.3"],
Cell[8333, 225, 792, 15, 138, "Project",
  CellTags->"1.3"],
Cell[9128, 242, 562, 12, 96, "Project",
  CellTags->"1.3"],
Cell[9693, 256, 1451, 25, 238, "Project",
  CellTags->"1.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11181, 286, 53, 1, 40, "Section",
  CellTags->"1.4"],
Cell[11237, 289, 556, 16, 84, "Reference",
  CellTags->"1.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11830, 310, 66, 1, 40, "Section",
  CellTags->"1.5"],

Cell[CellGroupData[{
Cell[11921, 315, 61, 1, 40, "Subsection",
  CellTags->"1.5"],
Cell[11985, 318, 2363, 41, 570, "Input",
  CellTags->{"i:11", "1.5"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

