(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27378,        635]*)
(*NotebookOutlinePosition[     34090,        839]*)
(*  CellTagsIndexPosition[     33647,        817]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2", "ChapterLine",
  CellTags->"2.1"],

Cell["Transmitting Culture", "Title",
  CellTags->"2.1"],

Cell["\"Role models are important.\"", "Quote",
  CellMargins->{{137, 65}, {Inherited, Inherited}},
  CellTags->"2.1"],

Cell[TextData[{
  "\[LongDash]Peter Weller in ",
  StyleBox["Robocop",
    FontSlant->"Italic"]
}], "QuoteAttribution",
  CellMargins->{{137, 65}, {Inherited, Inherited}},
  CellTags->"2.1"],

Cell[CellGroupData[{

Cell["2.1  Introduction", "Section",
  CellTags->"2.1"],

Cell[TextData[{
  "How do people come to have shared values based on ideas, beliefs, likes \
and dislikes, or attitudes? One possible mechanism for the spreading of \
values through a population is through a sort of contagious process, \
occurring as individuals come into contact with one another and interact. \
This interaction results in a form of imitative behavior sometimes referred \
to as ",
  StyleBox["cultural transmission ",
    FontSlant->"Italic"],
  "or ",
  StyleBox["social learning. ",
    FontSlant->"Italic"],
  "In this chapter, we look at several models of the change of values in a \
mobile society. In later chapters, we",
  " ",
  "use some of the ideas employed in these cultural transmission models to \
examine various other socioeconomic behaviors."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{
    "contagious processes", "", ""}, {"cultural transmission", "", ""}, {
    "social learning", "", ""}}},
  CellTags->{"i:1", "2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2  The More Alike We Are, the More Alike We Become", "Section",
  CellTags->"2.2"],

Cell[TextData[{
  "Axelrod [1997] has proposed a model for the transmission of culture.",
  " ",
  "Using a square lattice, each lattice site is occupied by an ",
  StyleBox["agent",
    FontSlant->"Italic"],
  " (known as a homogeneous village) and the lattice has absorbing boundaries \
so villages on the interior of the lattice have four nearest neighbors (to \
the north, east, south, and west), villages on the edge of the lattice have \
three nearest neighbors, and corner villages have two nearest neighbors. A \
village is characterized by having five attributes (called ",
  StyleBox["features",
    FontSlant->"Italic"],
  "), each of which has an integer value (called a ",
  StyleBox["trait",
    FontSlant->"Italic"],
  ") ranging from 1 to 10. The system evolves over a number of time steps. "
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{"Axelrod", 
    "cultural exchange model", ""}}},
  CellTags->{"i:2", "2.2"}],

Cell[TextData[{
  "At each time step, one village (called the active village) is randomly \
chosen. This active village randomly selects a village on a nearest neighbor \
site. The active village interacts with the selected village as follows: a \
comparison is made between the traits of corresponding features of the two \
villages. If the traits of each corresponding feature are the same (e.g., {5, \
9, 1, 3, 2} and {5, 9, 1, 3, 2}), nothing happens. If any of the traits of \
the features of the active village differ from the trait of the corresponding \
feature of the selected village, then a ",
  StyleBox["cultural interaction",
    FontSlant->"Italic"],
  " occurs with a probability equal to the fraction of features that share \
the same trait, that is, to their degree of ",
  StyleBox["cultural similarity",
    FontSlant->"Italic"],
  ". For example, if the traits of the active village's features are {3, 2, \
1, 7, 5} and the traits of the selected village's features are {4, 8, 1, 2, \
5}, then there is 40% probability that the villages will interact culturally \
because the traits of the third and fifth features of the two villages are \
identical. If a cultural interaction does occur, it is carried out by \
randomly choosing one of the features of the active village which has a \
different trait from the trait of the corresponding feature of the selected \
village and changing the active village's feature trait to that of the trait \
of the selected village's corresponding feature. Thus, if the active village \
having features {3, 2, 1, 7, 5} does interact with the selected village \
having features {4, 8, 1, 2, 5}, the interaction will be carried out by \
randomly choosing the first, second, or fourth feature of the active village \
and changing its trait to the trait of the corresponding feature of the \
selected village, so that if, for example, the second feature is chosen, the \
active village ends up with feature traits of {3, 8, 1, 7, 5}. This process \
continues until the system becomes invariant. "
}], "Text",
  CellTags->"2.2"],

Cell["\<\
The Axelrod model is quite elegant in its simplicity (a fundamental \
rule of scientific model building is to follow the dictums of both the \
military, \"keep it simple, stupid\" (the KISS principle), and Albert \
Einstein, \"a [model] should be as simple as possible, but no simpler\"). We \
can make two modifications to the model that will extend its usefulness, \
while maintaining its essential simplicity.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:3", "IndexEntries" -> {{
    "KISS principle", "", ""}}},
  CellTags->{"i:3", "2.2"}],

Cell["Incorporating mobility.", "BulletListItem",
  CellTags->"2.2"],

Cell["\<\
Axelrod states that \"since there is no movement in the model, the \
sites themselves can be thought of as homogenous villages.\" If some of the \
lattice sites were empty and other sites were occupied by individuals, the \
model could be applied to a mobile society using the walk rules developed in \
Chapter 1.\
\>", "Text",
  CellTags->"2.2"],

Cell["Incorporating bilateral cultural exchange.", "BulletListItem",
  CellTags->"2.2"],

Cell["\<\
The pair-wise interaction between villages in the Axelrod model is \
one-way or unilateral in that a randomly chosen active village changes the \
trait of its features as a result of its interaction with a selected nearest \
neighbor village and the selected village is left unchanged.\
\>", "Text",
  CellTags->"2.2"],

Cell["\<\
In our variant of the Axelrod model, individuals roam around a \
lattice, carrying with them cultural attributes, and altering these \
attributes as they engage in bilateral interactions with individuals they \
encounter along the way.\
\>", "Text",
  CellTags->"2.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3  The Closer We Agree, the Closer Our Agreement Becomes", "Section",
  CellTags->"2.3"],

Cell["\<\
Another model of cultural transmission ignores how many meme values \
are shared between two facing individuals and instead randomly chooses a meme \
value to change and bases the change on how similar the chosen meme value is \
for the two individuals.\
\>", "Text",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4  Social Status and Role Models", "Section",
  CellTags->"2.4"],

Cell["\<\
When two people of unequal social status interact culturally, it is \
more likely that the individual with the lower status will adopt a meme value \
of the individual with a higher social status while the meme value of the \
higher social status person will remain unchanged. This is most evident \
amongst young people who often adopt the attitude(s) of a so-called role \
model (hence, the famous advertising phrase \"be like Mike\"). In Chapter 5, \
we show how role models affect the spread of fads and fashions. We can model \
this effect using a simpler version of the previous two models because of the \
one-way nature of the cultural interaction. The necessary code changes \
follow.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:12", "IndexEntries" -> {{
    "role model", "", ""}, {"social status", "", ""}}},
  CellTags->{"i:12", "2.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.5  Computer Simulation Projects", "Section",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Compare the results obtained from the progam for cultural transmission \
based on the closeness of a randomly chosen meme value and the program for \
cultural transmission based on the number of identical meme values. "
}], "Project",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["2.",
    FontWeight->"Bold"],
  " In our model of the transmission of culture between people of differing \
social status, the social status is set for each individual at the start of \
the simulation and remains fixed thereafter. An interesting variation of this \
model would be to make social status endogenous. For example, the social \
status of a person could increase each time he interacts with a person of \
higher social status. Write several different variants of the charlesBarkley \
program, each with a different way in which the social status of an \
individual changes as he interacts with another person and compare the \
results obtained from running these simulations. "
}], "Project",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["3.",
    FontWeight->"Bold"],
  " A number of interesting questions arise about localization and \
homogenization effects in contagious culture spreading: "
}], "Project",
  CellTags->"2.5"],

Cell[TextData[{
  "Is there a tendency for spatial clusters of ",
  StyleBox["like-minded",
    FontSlant->"Italic"],
  " individuals to form?"
}], "BulletListItem",
  CellTags->"2.5"],

Cell["\<\
If regional clustering occurs, do these clusters eventually \
disappear at sufficiently long times or are they persistent?\
\>", 
  "BulletListItem",
  CellTags->"2.5"],

Cell["\<\
If clusters persist, do the values of individuals in different \
clusters eventually grow less alike, resulting in regional differences, or \
more alike, finally resulting in a single global meme set? \
\>", 
  "BulletListItem",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " To answer these questions, it would be useful to be able to identify \
clusters of individuals with shared values, where a cluster is a set of \
contiguous lattice sites that are populated by individuals whose meme lists \
are identical. We can easily determine the number and location of these \
clusters as follows."
}], "Note",
  TaggingRules:>{"IndexingCellTag" -> "i:16", "IndexEntries" -> {{
    "clustering", "identification of", ""}}},
  CellTags->{"i:16", "2.5"}],

Cell[TextData[{
  "We first assign to each individual (each occupied site) on the lattice, a \
unique number that represents the individual's ",
  StyleBox["cluster number",
    FontSlant->"Italic"],
  ". This number is appended to the individual's attribute list using"
}], "Text",
  CellTags->"2.5"],

Cell[TextData[
"k = 0;\nlatCluster = lattice /. {a_, memes_List} \[RuleDelayed] {a, memes, \
++k}"], "Input",
  CellTags->"2.5"],

Cell["\<\
We now apply the following transformation to the lattice: each \
individual's cluster number is changed to equal the maximum cluster number \
among those of his five nearest neighbors (including himself) who have the \
same meme list as he has. This can be done with the following rewrite \
rules.\
\>", "Text",
  CellTags->"2.5"],

Cell[TextData[
"renumber[0, __] := 0\nrenumber[{a_, memes_List, c_}, res__] := \n       {a, \
memes, Max[c, Cases[{res}, {_, memes, d_} \[RuleDelayed] d]]}"], "Input",
  CellTags->"2.5"],

Cell["The renumber rules are applied to the lattice using", "Text",
  CellTags->"2.5"],

Cell["vonNeumann[renumber, latCluster]", "Input",
  CellTags->"2.5"],

Cell["where", "Text",
  CellTags->"2.5"],

Cell["\<\
vonNeumann[func_, lat_] := 
  MapThread[func, Map[RotateRight[lat, #]&,
          {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1}}], 2]\
\>", "Input",
  CellTags->"2.5"],

Cell["\<\
If we perform this relabeling of cluster numbers repeatedly until \
the lattice configuration no longer changes, each individual in a cluster of \
individuals with the same meme list will then have the same cluster number as \
the highest numbered individual in that cluster. This can be done by \
employing the built-in function FixedPoint.\
\>", "Text",
  CellTags->"2.5"],

Cell["FixedPoint[vonNeumann[renumber, #]&, latCluster]", "Input",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " The clusters are not numbered consecutively (1, 2, 3, \[Ellipsis]) by \
this procedure, although it is very simple to create a set of transformation \
rules to produce consecutive cluster numbers if that is desirable."
}], "Note",
  CellTags->"2.5"],

Cell["\<\
Combining these code fragments, we can create the folowing cluster \
identification function.\
\>", "Text",
  CellTags->"2.5"],

Cell[TextData[
"clusterNumbering[lattice_] :=\nModule[{k, latCluster, renumber, vonNeumann},\
\n  k = 0;\n  latCluster = lattice /. {a_, memes_List} \[RuleDelayed] {a, \
memes, ++k};\n  \n  renumber[0, __] := 0;\n  renumber[{a_, memes_List, c_}, \
res__] :=\n      {a, memes, Max[c, Cases[{res}, {_, memes, d_} \[RuleDelayed] \
d]]};\n\n  vonNeumann[func_, lat_] := \n    MapThread[func, \
Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1}}], 2];\n  \n  FixedPoint[vonNeumann[renumber, #]&, latCluster]]"], "Input",\

  TaggingRules:>{"IndexingCellTag" -> "i:17", "IndexEntries" -> {{
    "clusterNumbering", "", ""}}},
  CellTags->{"i:17", "2.5"}],

Cell[TextData[{
  StyleBox["4.",
    FontWeight->"Bold"],
  " How does the population density affect the results you obtained in the \
previous project? "
}], "Project",
  CellTags->"2.5"],

Cell[TextData[{
  StyleBox["5.",
    FontWeight->"Bold"],
  " Another variation of the cultural transmission model would incorporate \
the spread of a cultural value via a mass medium, such as television, so that \
each individual in the system, regardless of his location, either adopts a \
new value immediately upon being exposed to it, or adopts it with a \
probabilty proportional to the number of times he has been exposed to it. \
Implement both of these in cultural transmission models and compare the \
results you obtain from running both simulations. "
}], "Project",
  CellTags->"2.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.6  References", "Section",
  CellTags->"2.6"],

Cell[TextData[{
  "Axelrod, Robert. 1997. ",
  StyleBox[
  "The Complexity of Cooperation: Agent-Based Models of Competition and \
Cooperation",
    FontSlant->"Italic"],
  ". Princeton, NJ: Princeton University Press.",
  "\n",
  "Epstein, Joshua M. and Robert Axtell. 1996. ",
  StyleBox["Growing Artificial Societies",
    FontSlant->"Italic"],
  ". Cambridge, MA: Brookings Institute Press/MIT Press."
}], "Reference",
  TaggingRules:>{"IndexingCellTag" -> "i:18", "IndexEntries" -> {{"Axelrod", 
    "", ""}}},
  CellTags->{"i:18", "2.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.7  Programs in the Chapter", "Section",
  CellTags->"2.7"],

Cell[CellGroupData[{

Cell["2.7.1  cultureSpreadingShared", "Subsection",
  CellTags->"2.7"],

Cell[TextData[
"cultureSpreadingShared[n_, p_, s_, m_, t_] :=\nModule[{society, RND, decide, \
exchange,\n                                    walk, vonNeumann, GN},\n  \
RND:= Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], {n}, \
{n}] /. \n           1 \[RuleDelayed] {RND, Table[Random[Integer, {1, m}], \
{s}]};\n  decide[{3, y_}, _, _, {1, y_}, _] := {3, y};\n  decide[{2, y_}, _, \
{4, y_}, _, _] := {2, y};\n  decide[{3, y_}, _, _, {1, z_}, _] := Module[\n   \
 {diffs = Flatten[Position[Abs[y - z], _?Positive]]},\n    {3, y, \
Random[Integer, {y[[#]], z[[#]]}], #}&[\n         diffs[[Random[Integer, {1, \
Length[diffs]}]]]] /;\n                 Random[Integer, {1,s}] > \
Length[diffs]];\n  decide[{2, y_}, _, {4, z_}, _, _] := Module[\n    {diffs = \
Flatten[Position[Abs[y - z], _?Positive]]},\n    {2, y, Random[Integer, \
{y[[#]], z[[#]]}], #}&[\n         diffs[[Random[Integer, {1, \
Length[diffs]}]]]] /;\n                 Random[Integer, {1,s}] > \
Length[diffs]];\n  decide[a_, _, _, _, _] := a;\n  exchange[{3, y_, c_, d_}, \
_, _, _, _] :=\n                               {3, ReplacePart[y, c, d]};\n  \
exchange[{2, y_, c_, d_}, _, _, _, _] :=\n                               {2, \
ReplacePart[y, c, d]};\n  exchange[{1, z_}, {3, y_, c_, d_}, _, _, _] :=\n    \
                           {1, ReplacePart[z, c, d]};\n  exchange[{4, z_}, _, \
_, _, {2, y_, c_, d_}] :=\n                               {4, ReplacePart[z, \
c, d]};\n  exchange[a_, _, _, _, _] := a;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0; \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk, vonNeumann[exchange,\n   \
                 vonNeumann[decide, #]]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:8", "IndexEntries" -> {{
    "cultureSpreadingShared", "", ""}}},
  CellTags->{"i:8", "2.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.7.2  cultureSpreadingCloseness", "Subsection",
  CellTags->"2.7"],

Cell[TextData[
"cultureSpreadingCloseness[n_, p_, s_, m_, t_] :=\nModule[{society, RND, \
decide, exchange,\n                                    walk, vonNeumann, GN},\
\n  RND:= Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], \
{n}, {n}] /. \n           1 \[RuleDelayed] {RND, Table[Random[Integer, {1, \
m}], {s}]};\n  decide[{3, y_}, _, _, {1, y_}, _] := {3, y};\n  decide[{2, \
y_}, _, {4, y_}, _, _] := {2, y};\n  decide[{2, y_}, _, {4, z_}, _, _] := \n  \
  Module[{r = Random[Integer, {1, s}]},\n          {2, y, Random[Integer, \
{y[[r]], z[[r]]}], r} /;\n          Random[Integer,{1, m}] > Abs[y[[r]] - \
z[[r]]]];\n  decide[{3, y_}, _, _, {1, z_}, _] := \n    Module[{r = \
Random[Integer, {1, s}]},\n          {3, y, Random[Integer, {y[[r]], \
z[[r]]}], r} /;\n          Random[Integer,{1, m}] > Abs[y[[r]] - z[[r]]]];\n  \
decide[a_, _, _, _, _] := a;\n  exchange[{3, y_, c_, d_}, _, _, _, _] :=\n    \
                           {3, ReplacePart[y, c, d]};\n  exchange[{2, y_, c_, \
d_}, _, _, _, _] :=\n                               {2, ReplacePart[y, c, \
d]};\n  exchange[{1, z_}, {3, y_, c_, d_}, _, _, _] :=\n                      \
         {1, ReplacePart[z, c, d]};\n  exchange[{4, z_}, _, _, _, {2, y_, c_, \
d_}] :=\n                               {4, ReplacePart[z, c, d]};\n  \
exchange[a_, _, _, _, _] := a;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0; \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk, vonNeumann[exchange,\n   \
                 vonNeumann[decide, #]]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{
    "cultureSpreadingCloseness", "", ""}}},
  CellTags->{"i:11", "2.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.7.3  charlesBarkley", "Subsection",
  CellTags->"2.7"],

Cell[TextData[
"charlesBarkley[n_, p_, s_, m_, t_] :=\nModule[{society, RND, exchange, walk, \
vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /. 1 \[RuleDelayed] \n     {RND, \
Random[], Table[Random[Integer, {1, m}], {s}]};\n  exchange[{1, a_, u_}, {3, \
b_, v_}, _, _, _] := \n    {1, a, ReplacePart[u, v[[#]], #]&[\n               \
       Random[Integer, {1, s}]]} /; a < b;\n  exchange[{2, a_, u_}, _, {4, \
b_, v_}, _, _] :=\n    {2, a, ReplacePart[u, v[[#]], #]&[\n                   \
   Random[Integer, {1, s}]]} /; a < b;\n  exchange[{3, a_, u_}, _, _, {1, b_, \
v_}, _] :=\n    {3, a, ReplacePart[u, v[[#]], #]&[\n                      \
Random[Integer, {1, s}]]} /; a < b;\n  exchange[{4, a_, u_}, _, _, _, {2, b_, \
v_}] :=\n    {4, a, ReplacePart[u, v[[#]], #]&[\n                      \
Random[Integer, {1, s}]]} /; a < b;\n  exchange[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;     \n  vonNeumann[func_, lat_] := \n   \
 MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk, vonNeumann[exchange, \
#]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:15", "IndexEntries" -> {{
    "charlesBarkley", "", ""}}},
  CellTags->{"i:15", "2.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "2. Transmitting Culture"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 22, "IndexEntries" -> {{"i:1", 
  "contagious processes", "", ""}, {"i:1", "cultural transmission", "", ""}, {
  "i:1", "social learning", "", ""}, {"i:2", "Axelrod", 
  "cultural exchange model", ""}, {"i:3", "KISS principle", "", ""}, {"i:12", 
  "role model", "", ""}, {"i:12", "social status", "", ""}, {"i:16", 
  "clustering", "identification of", ""}, {"i:17", "clusterNumbering", "", 
  ""}, {"i:18", "Axelrod", "", ""}, {"i:8", "cultureSpreadingShared", "", 
  ""}, {"i:11", "cultureSpreadingCloseness", "", ""}, {"i:15", 
  "charlesBarkley", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@2PR000000000006T<01T1T00000000000
00000000003oo`@2Wb3oo`000iL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "2.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"2.1"],
    Cell[1777, 54, 56, 1, 153, "Title",
      CellTags->"2.1"],
    Cell[1836, 57, 118, 2, 22, "Quote",
      CellTags->"2.1"],
    Cell[1957, 61, 190, 6, 24, "QuoteAttribution",
      CellTags->"2.1"],
    Cell[2172, 71, 55, 1, 40, "Section",
      CellTags->"2.1"],
    Cell[2230, 74, 993, 21, 140, "Text",
      CellTags->{"i:1", "2.1"}]},
  "i:1"->{
    Cell[2230, 74, 993, 21, 140, "Text",
      CellTags->{"i:1", "2.1"}]},
  "2.2"->{
    Cell[3260, 100, 90, 1, 40, "Section",
      CellTags->"2.2"],
    Cell[3353, 103, 963, 20, 128, "Text",
      CellTags->{"i:2", "2.2"}],
    Cell[4319, 125, 2080, 32, 338, "Text",
      CellTags->"2.2"],
    Cell[6402, 159, 563, 10, 80, "Text",
      CellTags->{"i:3", "2.2"}],
    Cell[6968, 171, 68, 1, 20, "BulletListItem",
      CellTags->"2.2"],
    Cell[7039, 174, 356, 7, 66, "Text",
      CellTags->"2.2"],
    Cell[7398, 183, 87, 1, 20, "BulletListItem",
      CellTags->"2.2"],
    Cell[7488, 186, 328, 6, 66, "Text",
      CellTags->"2.2"],
    Cell[7819, 194, 278, 6, 52, "Text",
      CellTags->"2.2"]},
  "i:2"->{
    Cell[3353, 103, 963, 20, 128, "Text",
      CellTags->{"i:2", "2.2"}]},
  "i:3"->{
    Cell[6402, 159, 563, 10, 80, "Text",
      CellTags->{"i:3", "2.2"}]},
  "2.3"->{
    Cell[8134, 205, 96, 1, 58, "Section",
      CellTags->"2.3"],
    Cell[8233, 208, 296, 6, 66, "Text",
      CellTags->"2.3"]},
  "2.4"->{
    Cell[8566, 219, 72, 1, 40, "Section",
      CellTags->"2.4"],
    Cell[8641, 222, 869, 14, 136, "Text",
      CellTags->{"i:12", "2.4"}]},
  "i:12"->{
    Cell[8641, 222, 869, 14, 136, "Text",
      CellTags->{"i:12", "2.4"}]},
  "2.5"->{
    Cell[9547, 241, 71, 1, 40, "Section",
      CellTags->"2.5"],
    Cell[9621, 244, 355, 9, 54, "Project",
      CellTags->"2.5"],
    Cell[9979, 255, 751, 13, 124, "Project",
      CellTags->"2.5"],
    Cell[10733, 270, 218, 6, 40, "Project",
      CellTags->"2.5"],
    Cell[10954, 278, 184, 6, 22, "BulletListItem",
      CellTags->"2.5"],
    Cell[11141, 286, 178, 5, 34, "BulletListItem",
      CellTags->"2.5"],
    Cell[11322, 293, 257, 6, 48, "BulletListItem",
      CellTags->"2.5"],
    Cell[11582, 301, 537, 11, 68, "Note",
      CellTags->{"i:16", "2.5"}],
    Cell[12122, 314, 301, 7, 54, "Text",
      CellTags->"2.5"],
    Cell[12426, 323, 128, 3, 50, "Input",
      CellTags->"2.5"],
    Cell[12557, 328, 340, 7, 66, "Text",
      CellTags->"2.5"],
    Cell[12900, 337, 186, 3, 63, "Input",
      CellTags->"2.5"],
    Cell[13089, 342, 86, 1, 24, "Text",
      CellTags->"2.5"],
    Cell[13178, 345, 68, 1, 37, "Input",
      CellTags->"2.5"],
    Cell[13249, 348, 40, 1, 24, "Text",
      CellTags->"2.5"],
    Cell[13292, 351, 173, 5, 63, "Input",
      CellTags->"2.5"],
    Cell[13468, 358, 384, 7, 80, "Text",
      CellTags->"2.5"],
    Cell[13855, 367, 84, 1, 37, "Input",
      CellTags->"2.5"],
    Cell[13942, 370, 314, 7, 54, "Note",
      CellTags->"2.5"],
    Cell[14259, 379, 136, 4, 38, "Text",
      CellTags->"2.5"],
    Cell[14398, 385, 679, 11, 206, "Input",
      CellTags->{"i:17", "2.5"}],
    Cell[15080, 398, 188, 6, 40, "Project",
      CellTags->"2.5"],
    Cell[15271, 406, 597, 11, 110, "Project",
      CellTags->"2.5"]},
  "i:16"->{
    Cell[11582, 301, 537, 11, 68, "Note",
      CellTags->{"i:16", "2.5"}]},
  "i:17"->{
    Cell[14398, 385, 679, 11, 206, "Input",
      CellTags->{"i:17", "2.5"}]},
  "2.6"->{
    Cell[15905, 422, 53, 1, 40, "Section",
      CellTags->"2.6"],
    Cell[15961, 425, 544, 15, 84, "Reference",
      CellTags->{"i:18", "2.6"}]},
  "i:18"->{
    Cell[15961, 425, 544, 15, 84, "Reference",
      CellTags->{"i:18", "2.6"}]},
  "2.7"->{
    Cell[16542, 445, 66, 1, 40, "Section",
      CellTags->"2.7"],
    Cell[16633, 450, 70, 1, 40, "Subsection",
      CellTags->"2.7"],
    Cell[16706, 453, 3725, 57, 882, "Input",
      CellTags->{"i:8", "2.7"}],
    Cell[20468, 515, 73, 1, 40, "Subsection",
      CellTags->"2.7"],
    Cell[20544, 518, 3581, 55, 856, "Input",
      CellTags->{"i:11", "2.7"}],
    Cell[24162, 578, 62, 1, 40, "Subsection",
      CellTags->"2.7"],
    Cell[24227, 581, 3111, 49, 739, "Input",
      CellTags->{"i:15", "2.7"}]},
  "i:8"->{
    Cell[16706, 453, 3725, 57, 882, "Input",
      CellTags->{"i:8", "2.7"}]},
  "i:11"->{
    Cell[20544, 518, 3581, 55, 856, "Input",
      CellTags->{"i:11", "2.7"}]},
  "i:15"->{
    Cell[24227, 581, 3111, 49, 739, "Input",
      CellTags->{"i:15", "2.7"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"2.1", 29121, 674},
  {"i:1", 29544, 687},
  {"2.2", 29630, 690},
  {"i:2", 30262, 709},
  {"i:3", 30349, 712},
  {"2.3", 30435, 715},
  {"2.4", 30577, 720},
  {"i:12", 30732, 725},
  {"2.5", 30820, 728},
  {"i:16", 32401, 775},
  {"i:17", 32490, 778},
  {"2.6", 32580, 781},
  {"i:18", 32741, 786},
  {"2.7", 32834, 789},
  {"i:8", 33359, 804},
  {"i:11", 33450, 807},
  {"i:15", 33542, 810}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"2.1"],
Cell[1777, 54, 56, 1, 153, "Title",
  CellTags->"2.1"],
Cell[1836, 57, 118, 2, 22, "Quote",
  CellTags->"2.1"],
Cell[1957, 61, 190, 6, 24, "QuoteAttribution",
  CellTags->"2.1"],

Cell[CellGroupData[{
Cell[2172, 71, 55, 1, 40, "Section",
  CellTags->"2.1"],
Cell[2230, 74, 993, 21, 140, "Text",
  CellTags->{"i:1", "2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3260, 100, 90, 1, 40, "Section",
  CellTags->"2.2"],
Cell[3353, 103, 963, 20, 128, "Text",
  CellTags->{"i:2", "2.2"}],
Cell[4319, 125, 2080, 32, 338, "Text",
  CellTags->"2.2"],
Cell[6402, 159, 563, 10, 80, "Text",
  CellTags->{"i:3", "2.2"}],
Cell[6968, 171, 68, 1, 20, "BulletListItem",
  CellTags->"2.2"],
Cell[7039, 174, 356, 7, 66, "Text",
  CellTags->"2.2"],
Cell[7398, 183, 87, 1, 20, "BulletListItem",
  CellTags->"2.2"],
Cell[7488, 186, 328, 6, 66, "Text",
  CellTags->"2.2"],
Cell[7819, 194, 278, 6, 52, "Text",
  CellTags->"2.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8134, 205, 96, 1, 58, "Section",
  CellTags->"2.3"],
Cell[8233, 208, 296, 6, 66, "Text",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8566, 219, 72, 1, 40, "Section",
  CellTags->"2.4"],
Cell[8641, 222, 869, 14, 136, "Text",
  CellTags->{"i:12", "2.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9547, 241, 71, 1, 40, "Section",
  CellTags->"2.5"],
Cell[9621, 244, 355, 9, 54, "Project",
  CellTags->"2.5"],
Cell[9979, 255, 751, 13, 124, "Project",
  CellTags->"2.5"],
Cell[10733, 270, 218, 6, 40, "Project",
  CellTags->"2.5"],
Cell[10954, 278, 184, 6, 22, "BulletListItem",
  CellTags->"2.5"],
Cell[11141, 286, 178, 5, 34, "BulletListItem",
  CellTags->"2.5"],
Cell[11322, 293, 257, 6, 48, "BulletListItem",
  CellTags->"2.5"],
Cell[11582, 301, 537, 11, 68, "Note",
  CellTags->{"i:16", "2.5"}],
Cell[12122, 314, 301, 7, 54, "Text",
  CellTags->"2.5"],
Cell[12426, 323, 128, 3, 50, "Input",
  CellTags->"2.5"],
Cell[12557, 328, 340, 7, 66, "Text",
  CellTags->"2.5"],
Cell[12900, 337, 186, 3, 63, "Input",
  CellTags->"2.5"],
Cell[13089, 342, 86, 1, 24, "Text",
  CellTags->"2.5"],
Cell[13178, 345, 68, 1, 37, "Input",
  CellTags->"2.5"],
Cell[13249, 348, 40, 1, 24, "Text",
  CellTags->"2.5"],
Cell[13292, 351, 173, 5, 63, "Input",
  CellTags->"2.5"],
Cell[13468, 358, 384, 7, 80, "Text",
  CellTags->"2.5"],
Cell[13855, 367, 84, 1, 37, "Input",
  CellTags->"2.5"],
Cell[13942, 370, 314, 7, 54, "Note",
  CellTags->"2.5"],
Cell[14259, 379, 136, 4, 38, "Text",
  CellTags->"2.5"],
Cell[14398, 385, 679, 11, 206, "Input",
  CellTags->{"i:17", "2.5"}],
Cell[15080, 398, 188, 6, 40, "Project",
  CellTags->"2.5"],
Cell[15271, 406, 597, 11, 110, "Project",
  CellTags->"2.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15905, 422, 53, 1, 40, "Section",
  CellTags->"2.6"],
Cell[15961, 425, 544, 15, 84, "Reference",
  CellTags->{"i:18", "2.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[16542, 445, 66, 1, 40, "Section",
  CellTags->"2.7"],

Cell[CellGroupData[{
Cell[16633, 450, 70, 1, 40, "Subsection",
  CellTags->"2.7"],
Cell[16706, 453, 3725, 57, 882, "Input",
  CellTags->{"i:8", "2.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[20468, 515, 73, 1, 40, "Subsection",
  CellTags->"2.7"],
Cell[20544, 518, 3581, 55, 856, "Input",
  CellTags->{"i:11", "2.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[24162, 578, 62, 1, 40, "Subsection",
  CellTags->"2.7"],
Cell[24227, 581, 3111, 49, 739, "Input",
  CellTags->{"i:15", "2.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

