(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30134,        716]*)
(*NotebookOutlinePosition[     37294,        927]*)
(*  CellTagsIndexPosition[     36825,        904]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3", "ChapterLine",
  CellTags->"3.1"],

Cell["Deciding Whether to Interact", "Title",
  CellTags->"3.1"],

Cell["\"You've got a nasty reputation, Mr. Gittes. I like that.\"", "Quote",
  CellTags->"3.1"],

Cell[TextData[{
  "\[LongDash]John Huston in ",
  StyleBox["Chinatown",
    FontSlant->"Italic"],
  " (1974)"
}], "QuoteAttribution",
  CellTags->"3.1"],

Cell[CellGroupData[{

Cell["3.1  Introduction", "Section",
  CellTags->"3.1"],

Cell[TextData[{
  "Why are people generally honest in their dealings with others, even in the \
absense of a central authority to enforce good behavior? In this chapter, we \
model the role of ostracism as a tool for discouraging bad behavior, and \
thereby encouraging good behavior. We first look at two cases in which people \
have the ability to remember or learn about other people's bad behavior. In \
the first situation, people remember every individual who has ",
  StyleBox["done them wron",
    FontSlant->"Italic"],
  "g in a previous encounter and they refuse to interact with such a person \
again. In the second situation, good guys use word-of-mouth or gossip in \
addition to personal experience to learn who are the bad guys, and they avoid \
interacting with a person with a",
  StyleBox[" bad rep",
    FontSlant->"Italic"],
  " even once. In a final case, people will be able to ",
  StyleBox["pick up on",
    FontSlant->"Italic"],
  " the signals of intent (to be good or bad) emitted by each person and use \
those ",
  StyleBox["vibes",
    FontSlant->"Italic"],
  " to decide whether to interact with a stranger about whom they have no \
information."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{"gossip", 
    "", ""}, {"remembering behavior", "", ""}, {"signals of intent", "", 
    ""}, {"vibes", "", ""}}},
  CellTags->{"i:1", "3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2  Fool Me Once, Shame on You; Fool Me Twice, Shame on Me", "Section",
  CellTags->"3.2"],

Cell["\<\
In this model, an individual decides whether to interact with \
another person, based on knowledge about that person which has been gained \
through a previous first-hand interaction with the person. \
\>", "Text",
  CellTags->"3.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3  I Heard It Through the Grapevine", "Section",
  CellTags->"3.3"],

Cell[TextData[{
  "We can allow individuals who interact with one another to share \
information or ",
  StyleBox["gossip",
    FontSlant->"Italic"],
  " about the bad behavior of other individuals. This exchange results in \
individuals being excluded or ",
  StyleBox["ostracized",
    FontSlant->"Italic"],
  " from interactions with people with whom they have never interacted in the \
past and so imposes an even higher penalty on past bad behavior than the \
previous model."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:9", "IndexEntries" -> {{"gossip", 
    "", ""}, {"ostracism", "", ""}, {"prisoner's dilemma", "optional", ""}, {
    "social ostracism", "", ""}}},
  CellTags->{"i:9", "3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4  Signals", "Section",
  CellTags->"3.4"],

Cell["\"I suggest you deactivate your emotion chip for now.\"", "Quote",
  CellTags->"3.4"],

Cell[TextData[{
  "\[LongDash]Patrick Stewart in ",
  StyleBox["Star Trek: First Contact",
    FontSlant->"Italic"],
  " (1996)"
}], "QuoteAttribution",
  CellTags->"3.4"],

Cell[TextData[{
  "In both the onceBurntTwiceShy and badRep models, bad behavior returns an \
immediate benefit to a bad guy but the side effect of being placed on a good \
guy's list of bad guys results in a bad guy being limited to one interaction, \
at most, with a given individual. Hence, in these models, bad people \
inevitably ",
  StyleBox["come to a bad end",
    FontSlant->"Italic"],
  " as no mechanism is available to allow a person to escape his previous \
past behavior and redeem himself. It's similar to having a ",
  StyleBox["scarlet A",
    FontSlant->"Italic"],
  " permanently tattooed on your forehead."
}], "Text",
  CellTags->"3.4"],

Cell[TextData[{
  "These simple models of social exclusion or shunning may account for the \
tendency of people living in an isolated close-knit community to be \
cooperative and friendly with one another. However, in a society where people \
are mobile, the situation is different and using personal experience and \
reputation may be inadequate tools for discouraging bad behavior. People tend \
to become ",
  StyleBox["lost in the crowd",
    FontSlant->"Italic"],
  " in such a society and as a result they cross paths with other people \
about whom they know nothing, either personally or through others. In this \
case, the decision about whether to interact with another person must be made \
on some other basis."
}], "Text",
  CellTags->"3.4"],

Cell[TextData[{
  "When we consider interacting with a person about whom we can obtain no \
information, we must resort to ",
  StyleBox["sizing up",
    FontSlant->"Italic"],
  " the other person and making a best guess as to how he will behave in an \
interaction. It has been proposed [Frank 1988] that individuals emit various \
",
  StyleBox["signals",
    FontSlant->"Italic"],
  " or ",
  StyleBox["vibes",
    FontSlant->"Italic"],
  " that allow others to anticipate the person's predisposition (nonbinding \
commitment) to behave in a certain way. "
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{
    "behavioral predisposition", "", ""}, {"committment", "non-binding", 
    ""}, {"signals", "", ""}, {"vibes", "", ""}}},
  CellTags->{"i:11", "3.4"}],

Cell["\<\
In this section, we focus on the use of the signals given off by \
another person to decide whether to interact with that person.\
\>", "Text",
  CellTags->"3.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5  Computer Simulation Projects", "Section",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "In the simple models presented in this chapter, only acts of bad behavior \
are used in deciding whether to interact with an individual. It is simple to \
incorporate acts of good behavior into the decision by having the agents keep \
a list of good people and to use that list, either by itself or in \
conjunction with the bad guy list, in deciding whether to interact. (This \
brings to mind the lyrics, \"making a list, checking it twice, going to find \
out who's naughty or nice\" from the song \"Santa Claus Is Coming To Town.\") \
Do this and see how it affects the results."
}], "Project",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["2",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Consider a model in which individuals play with people they know to be \
good, don't play with people they know to be bad, and otherwise play with \
probability ",
  StyleBox["p", "IT"],
  ". How does the system's behavior change for different values of ",
  StyleBox["p", "IT"],
  "?"
}], "Project",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["3",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " What is the effect of having a limited memory of past behavior? Create a \
variant of the model where an individual's bad guy list can only be a certain \
length, and once that length is reached, any interaction with a bad guy \
results in the addition of the bad guy's name to the end of the list and the \
removal of the first name in the list. Observe the effect on the resource \
levels of good guys and bad guys. As another variant, suppose that good guys \
have better memories (so that their bad guy list has a longer maximum length) \
than do bad guys. How does this compare to the case when bad guys have better \
memories than good guys? Yet another variant of memory list limitations to \
consider is to give the population a random distribution of maximum memory \
list lengths. Finally, suppose that each individual clears his memory \
(empties his bad guy list) with some probability ",
  StyleBox["p", "IT"],
  " on each time step. How does this affect the importance of memory \
limitations? "
}], "Project",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["4",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Kitcher [Batali and Kitcher 1995] has proposed an iterated optional \
prisoner's dilemma game with the standard ",
  StyleBox["T", "IT"],
  ", ",
  StyleBox["R", "IT"],
  ", ",
  StyleBox["P", "IT"],
  ", ",
  StyleBox["S", "IT"],
  ", interaction payoffs and the ",
  StyleBox["W", "IT"],
  " opt-out payoff consisting of five types of individuals:"
}], "Project",
  CellTags->"3.5"],

Cell["the solo person who never interacts;", "BulletListItem",
  CellTags->"3.5"],

Cell["\<\
the undiscriminating altruist who is always a good guy and always \
interacts;\
\>", "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:15", "IndexEntries" -> {{
    "undiscriminating altruist", "", ""}}},
  CellTags->{"i:15", "3.5"}],

Cell["\<\
the undiscriminating defector who is always a bad guy and always \
interacts;\
\>", "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:16", "IndexEntries" -> {{
    "undiscriminating defector", "", ""}}},
  CellTags->{"i:16", "3.5"}],

Cell[TextData[
"the discriminating altruist who is always a good guy and interacts with any \
other person who is willing to interact, provided that the person has not \
previously behaved badly with him\[LongDash]otherwise he opts out;"], 
  "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:17", "IndexEntries" -> {{
    "discriminating altruist", "", ""}}},
  CellTags->{"i:17", "3.5"}],

Cell[TextData[
"the discriminating defector is always a bad guy and interacts with any other \
person who is willing to interact, provided that the person has not \
previously behaved badly with him\[LongDash]otherwise he opts out."], 
  "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:18", "IndexEntries" -> {{
    "discriminating defector", "", ""}}},
  CellTags->{"i:18", "3.5"}],

Cell["\<\
Implement this model in a program and observe its behavior over \
time.\
\>", "Text",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["5",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " In the vibes program, the number of decide rules can be reduced from five \
to three by having the determination by each of two facing individuals to \
interact or not be made by just one of the individuals as was done in the \
cultural transmission program in Chapter 2. "
}], "Project",
  CellTags->"3.5"],

Cell[TextData[{
  "The computation is done as follows: if the signal strength of the south \
(east) facing individual is ",
  StyleBox["x", "IT"],
  " and the signal strength of the north (west) facing individual is ",
  StyleBox["y", "IT"],
  ", then we write a rule that updates the four-tuple value of the south \
(east) facing individual to a five-tuple in which an additional element has \
been added to the end of the list. The value of this last element is given \
by"
}], "Text",
  CellTags->"3.5"],

Cell["Floor[x + Random[]] * Floor[y + Random[]] ", "Input",
  CellTags->"3.5"],

Cell["\<\
which will equal 1 if both individuals have independently decided \
to interact and 0 if either one or both of the individuals have decided to \
opt out of the interaction.\
\>", "Text",
  CellTags->"3.5"],

Cell["\<\
The three rules for this decision-making process are written \
as:\
\>", "Text",
  CellTags->"3.5"],

Cell["\<\
decide[{3, a_, x_, b_}, _, _, {1, _, y_, _}, _] :=
    {3, a, x, b, Floor[x + Random[]] * Floor[y + Random[]]}
decide[{2, a_, x_, b_}, _, {4, _, y_, _}, _, _] :=
    {2, a, x, b, Floor[x + Random[]] * Floor[y + Random[]]}
decide[z_, _, _, _, _] := z\
\>", "Input",
  CellTags->"3.5"],

Cell["\<\
If these decide rules are used, then the appropriate interact rules \
are given by\
\>", "Text",
  CellTags->"3.5"],

Cell["\<\
interact[{3, a_, x_, b_, k_}, _, _, {1, d_, _, _}, _] :=
                        {3, a, x, b + costbenefit[a, d, k]}
interact[{2, a_, x_, b_, k_}, _, {4, d_, _, _}, _, _] :=
                        {2, a, x, b + costbenefit[a, d, k]}
interact[{1, a_, x_, b_}, {3, d_, _, _, k_}, _, _, _] :=
                        {1, a, x, b + costbenefit[a, d, k]}
interact[{4, a_, x_, b_}, _, _, _, {2, d_, _, _, k_}] :=
                        {4, a, x, b + costbenefit[a, d, k]}
interact[z_, _, _, _, _] := z\
\>", "Input",
  CellTags->"3.5"],

Cell["where", "Text",
  CellTags->"3.5"],

Cell["\<\
costbenefit[1, 1, 1] = R
costbenefit[0, 1, 1] = T
costbenefit[1, 0, 1] = S
costbenefit[0, 0, 1] = P
costbenefit[_, _, 0] = W\
\>", "Input",
  CellTags->"3.5"],

Cell["\<\
Use a variety of criteria, such as aesthetics and speed, to decide \
which rule set is preferable to use.\
\>", "Text",
  CellTags->"3.5"],

Cell[TextData[{
  StyleBox["6",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " The usefulness of signaling depends not only on the ability of \
individuals to send a signal, but also on the ability of an observer to \
correctly interpret the signal being sent. In the vibes program, the decide \
rules assume that all individuals have the same signal detection ability so \
that each individual decides if he should interact or not based solely on the \
strength of the signal he receives from another individual. Modify the vibes \
model to endow individuals with varying abilities to detect and interpret the \
",
  StyleBox["first impressions",
    FontSlant->"Italic"],
  " made by others."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:19", "IndexEntries" -> {{
    "first impressions", "", ""}}},
  CellTags->{"i:19", "3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.6  References", "Section",
  CellTags->"3.6"],

Cell[TextData[{
  "Batali, John and Philip Kitcher. 1995. \"Evolution of Altruism in Optional \
and Compulsory Games.\" ",
  StyleBox["Journal of Theoretical Biology",
    FontSlant->"Italic"],
  " 175: 161\[Dash]171.\nEnquist, Magnus and Olof Leimat. 1993. \"The \
Evolution of Cooperation in Mobile Organisms.\" ",
  StyleBox["Animal Behavior",
    FontSlant->"Italic"],
  " 45: 747\[Dash]757.\nFrank, Robert H. 1988. ",
  StyleBox["Passions Within Reason: The Strategic Role of the Emotions",
    FontSlant->"Italic"],
  ". New York, NY: W.W. Norton."
}], "Reference",
  CellTags->"3.6"],

Cell["\<\
Frank emphasizes the use of the visual display of emotions, such as \
facial expressions or body language as a signaling device that allows others \
to anticipate the person's predisposition to behave in a certain way. He says \
that emotions are especially useful for providing a fairly accurate measure \
of a person's intentions because emotional responses such as indignation, \
humor, fear, guilt, remorse, compassion, and the like (what Adam Smith called \
moral sentiments) are generally beyond a person's purposeful control, making \
them difficult to fake consistently and rendering a person's behavior \
automatic and consistent. As a result, emotionally based behavior is at least \
somewhat predictable by others, and therefore a person's emotional displays \
can be used by another person to decide whether to interact with him.\
\>", 
  "ReferenceNote",
  CellTags->"3.6"],

Cell[TextData[{
  "Thaler, Richard H. 1992. ",
  StyleBox["The Winner's Curse: Paradoxes and Anomalies of Economic Life",
    FontSlant->"Italic"],
  ". The Free Press, chap. 2, 6\[Dash]20. Reprinted from Robyn M. Dawes and \
Richard H. Thaler, 1988, \"Cooperation.\" ",
  StyleBox["Journal of Economic Persepctives",
    FontSlant->"Italic"],
  " 2 (Summer): 187\[Dash]197."
}], "Reference",
  CellTags->"3.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7  Programs in the Chapter", "Section",
  CellTags->"3.7"],

Cell[CellGroupData[{

Cell["3.7.1  onceBurntTwiceShy", "Subsection",
  CellTags->"3.7"],

Cell[TextData[
"onceBurntTwiceShy[n_, p_, g_,\n                         {P_, R_, S_, T_, \
W_}, t_] :=\nModule[{RND, k = 0, society, interact, payoff,\n                 \
                  walk, vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n \
 society = Table[Floor[p + Random[]], {n}, {n}] /.\n               1 \
\[RuleDelayed] {RND, ++k, Floor[g + Random[]], {}, 0};\n  payoff[1, 1] = R;\n \
 payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  interact[{1, \
a1_, x1_, b1_, r_},\n           {3, a3_, x3_, b3_, _}, _, _, _] :=\n          \
      {1, a1, x1, b1, r + W} /;\n                     MemberQ[b1, a3] || \
MemberQ[b3, a1];\n  interact[{2, a2_, x2_, b2_, r_}, _,\n           {4, a4_, \
x4_, b4_, _}, _, _] :=\n                {2, a2, x2, b2, r + W} /;\n           \
          MemberQ[b2, a4] || MemberQ[b4, a2];\n  interact[{3, a3_, x3_, b3_, \
r_}, _, _,\n           {1, a1_, x1_, b1_, _}, _] :=\n                {3, a3, \
x3, b3, r + W} /;\n                     MemberQ[b3, a1] || MemberQ[b1, a3];\n \
 interact[{4, a4_, x4_, b4_, r_}, _, _, _,\n           {2, a2_, x2_, b2_, _}] \
:=\n                {4, a4, x4, b4, r + W} /;\n                     \
MemberQ[b4, a2] || MemberQ[b2, a4];\n  interact[{1, a1_, x1_, b1_, r_},\n     \
      {3, a3_, x3_, _, _}, _, _, _] :=\n                {1, a1, x1, Union[b1, \
Drop[{a3}, x3]],\n                                    r + payoff[x1, x3]};\n  \
interact[{2, a2_, x2_ ,b2_, r_}, _,\n           {4, a4_, x4_, _, _}, _, _] :=\
\n                {2, a2, x2, Union[b2, Drop[{a4}, x4]],\n                    \
                r + payoff[x2, x4]};\n  interact[{3, a3_, x3_, b3_, r_}, _, \
_,\n           {1, a1_, x1_, _, _}, _] :=\n                {3, a3, x3, \
Union[b3, Drop[{a1}, x1]],\n                                    r + \
payoff[x3, x1]};\n  interact[{4, a4_, x4_, b4_, r_}, _, _, _,\n           {2, \
a2_, x2_, _, _}] :=\n                {4, a4, x4, Union[b4, Drop[{a2}, x2]],\n \
                                   r + payoff[x4, x2]};\n  interact[z_, _, _, \
_, _] := z;\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[vonNeumann[interact, GN[walk, \
#]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:21", "IndexEntries" -> {{
    "onceBurntTwiceShy", "", ""}}},
  CellTags->{"i:21", "3.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.2  badRep", "Subsection",
  CellTags->"3.7"],

Cell[TextData[
"badRep[n_, p_, g_, {P_, R_, S_, T_, W_}, t_] := \nModule[{RND, k = 0, \
society, interact, payoff,\n                                   walk, \
vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.\n               1 \[RuleDelayed] \
{RND, ++k, Floor[g + Random[]], {}, 0};\n  payoff[1, 1] = R;\n  payoff[0, 1] \
= T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  interact[{1, a1_, x1_, b1_, \
r_},\n           {3, a3_, x3_, b3_, _}, _, _, _] :=\n                {1, a1, \
x1, b1, r + W} /;\n                     MemberQ[b1, a3] || MemberQ[b3, a1];\n \
 interact[{2, a2_, x2_, b2_, r_}, _,\n           {4, a4_, x4_, b4_, _}, _, _] \
:=\n                {2, a2, x2, b2, r + W} /;\n                     \
MemberQ[b2, a4] || MemberQ[b4, a2];\n  interact[{3, a3_, x3_, b3_, r_}, _, _,\
\n           {1, a1_, x1_, b1_, _}, _] :=\n                {3, a3, x3, b3, r \
+ W} /;\n                     MemberQ[b3, a1] || MemberQ[b1, a3];\n  \
interact[{4, a4_, x4_, b4_, r_}, _, _, _,\n           {2, a2_, x2_, b2_, _}] \
:=\n                {4, a4, x4, b4, r + W} /;\n                     \
MemberQ[b4, a2] || MemberQ[b2, a4];\n  interact[{1, a1_, x1_, b1_, r_},\n     \
      {3, a3_, x3_, b3_, _}, _, _, _] :=\n               {1, a1, x1, \
Union[b1, b3, Drop[{a3}, x3]],\n                                      r + \
payoff[x1, x3]};\n  interact[{2, a2_, x2_ ,b2_, r_}, _,\n           {4, a4_, \
x4_, b4_, _}, _, _] :=\n               {2, a2, x2, Union[b2, b4, Drop[{a4}, \
x4]],\n                                      r + payoff[x2, x4]};\n  \
interact[{3, a3_, x3_, b3_, r_}, _, _,\n           {1, a1_, x1_, b1_, _}, _] \
:=\n               {3, a3, x3, Union[b3, b1, Drop[{a1}, x1]],\n               \
                       r + payoff[x3, x1]};\n  interact[{4, a4_, x4_, b4_, \
r_}, _, _, _,\n           {2, a2_, x2_, b2_, _}] :=\n               {4, a4, \
x4, Union[b4, b2, Drop[{a2}, x2]],\n                                      r + \
payoff[x4, x2]};\n  interact[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[vonNeumann[interact, GN[walk, \
#]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:22", "IndexEntries" -> {{"badRep", 
    "", ""}}},
  CellTags->{"i:22", "3.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.3  vibes", "Subsection",
  CellTags->"3.7"],

Cell[TextData[{
  "vibes[n_, p_, g_, {P_, R_, S_, T_, W_}, t_] := \nModule[{RND, society, \
decide, interact, costbenefit,\n                                    walk, \
vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /. \n              1 \[RuleDelayed] \
{RND, Floor[g + Random[]], Random[], 0};\n  decide[{1, a_, x_, b_}, {3, _, \
y_, _}, _, _, _] := \n                        {1, a, x, b, Floor[y + \
Random[]]};\n  decide[{2, a_, x_, b_}, _, {4, _, y_, _}, _, _] :=\n           \
             {2, a, x, b, Floor[y + Random[]]};\n  decide[{3, a_, x_, b_}, _, \
_, {1, _, y_, _}, _] :=\n                        {3, a, x, b, Floor[y + \
Random[]]};\n  decide[{4, a_, x_, b_}, _, _, _, {2, _, y_, _}] :=\n           \
             {4, a, x, b, Floor[y + Random[]]};\n  decide[z_, _, _, _, _] := \
z;\n  costbenefit[1, 1, 1] = R;\n  costbenefit[0, 1, 1] = T;\n  \
costbenefit[1, 0, 1] = S;\n  costbenefit[0, 0, 1] = P;\n  costbenefit[_, _, \
0] = W;\n  interact[{3, a_, x_, b_, k_}, _, _,\n           {1, d_, _, _, h_}, \
_] :=\n                {3, a, x, b + costbenefit[a, d, (k * h)]};\n  \
interact[{2, a_, x_, b_, k_}, _,\n           {4, d_, _, _, h_}, _, _] :=\n    \
            {2, a, x, b + costbenefit[a, d, (k * h)]};\n  interact[{1, a_, \
x_, b_, k_},\n           {3, d_, _, _, h_}, _, _, _] :=\n                {1, \
a, x, b + costbenefit[a, d, (k * h)]};\n  interact[{4, a_, x_, b_, k_}, _, _, \
_,\n           {2, d_, _, _, h_}] :=\n                {4, a, x, b + \
costbenefit[a, d, (k * h)]};\n  interact[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n",
  "  walk[",
  "0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk, vonNeumann[interact,\n   \
                vonNeumann[decide, #]]]&, society, t]];"
}], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:23", "IndexEntries" -> {{"vibes", 
    "", ""}}},
  CellTags->{"i:23", "3.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "3. Deciding Whether to Interact"}], "Header"], Inherited, 
      Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 24, "IndexEntries" -> {{"i:1", 
  "gossip", "", ""}, {"i:1", "remembering behavior", "", ""}, {"i:1", 
  "signals of intent", "", ""}, {"i:1", "vibes", "", ""}, {"i:9", "gossip", 
  "", ""}, {"i:9", "ostracism", "", ""}, {"i:9", "prisoner's dilemma", 
  "optional", ""}, {"i:9", "social ostracism", "", ""}, {"i:11", 
  "behavioral predisposition", "", ""}, {"i:11", "committment", 
  "non-binding", ""}, {"i:11", "signals", "", ""}, {"i:11", "vibes", "", 
  ""}, {"i:15", "undiscriminating altruist", "", ""}, {"i:16", 
  "undiscriminating defector", "", ""}, {"i:17", "discriminating altruist", 
  "", ""}, {"i:18", "discriminating defector", "", ""}, {"i:19", 
  "first impressions", "", ""}, {"i:21", "onceBurntTwiceShy", "", ""}, {
  "i:22", "badRep", "", ""}, {"i:23", "vibes", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@2PR000000000006T<01T1T00000000000
00000000003oo`@2QM3oo`000iL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "3.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"3.1"],
    Cell[1777, 54, 64, 1, 153, "Title",
      CellTags->"3.1"],
    Cell[1844, 57, 95, 1, 22, "Quote",
      CellTags->"3.1"],
    Cell[1942, 60, 152, 6, 24, "QuoteAttribution",
      CellTags->"3.1"],
    Cell[2119, 70, 55, 1, 40, "Section",
      CellTags->"3.1"],
    Cell[2177, 73, 1397, 28, 200, "Text",
      CellTags->{"i:1", "3.1"}]},
  "i:1"->{
    Cell[2177, 73, 1397, 28, 200, "Text",
      CellTags->{"i:1", "3.1"}]},
  "3.2"->{
    Cell[3611, 106, 97, 1, 58, "Section",
      CellTags->"3.2"],
    Cell[3711, 109, 243, 5, 52, "Text",
      CellTags->"3.2"]},
  "3.3"->{
    Cell[3991, 119, 75, 1, 40, "Section",
      CellTags->"3.3"],
    Cell[4069, 122, 710, 16, 86, "Text",
      CellTags->{"i:9", "3.3"}]},
  "i:9"->{
    Cell[4069, 122, 710, 16, 86, "Text",
      CellTags->{"i:9", "3.3"}]},
  "3.4"->{
    Cell[4816, 143, 50, 1, 40, "Section",
      CellTags->"3.4"],
    Cell[4869, 146, 91, 1, 22, "Quote",
      CellTags->"3.4"],
    Cell[4963, 149, 171, 6, 24, "QuoteAttribution",
      CellTags->"3.4"],
    Cell[5137, 157, 658, 14, 114, "Text",
      CellTags->"3.4"],
    Cell[5798, 173, 753, 14, 140, "Text",
      CellTags->"3.4"],
    Cell[6554, 189, 792, 19, 84, "Text",
      CellTags->{"i:11", "3.4"}],
    Cell[7349, 210, 172, 4, 38, "Text",
      CellTags->"3.4"]},
  "i:11"->{
    Cell[6554, 189, 792, 19, 84, "Text",
      CellTags->{"i:11", "3.4"}]},
  "3.5"->{
    Cell[7558, 219, 71, 1, 40, "Section",
      CellTags->"3.5"],
    Cell[7632, 222, 719, 14, 124, "Project",
      CellTags->"3.5"],
    Cell[8354, 238, 421, 13, 56, "Project",
      CellTags->"3.5"],
    Cell[8778, 253, 1145, 21, 196, "Project",
      CellTags->"3.5"],
    Cell[9926, 276, 486, 18, 56, "Project",
      CellTags->"3.5"],
    Cell[10415, 296, 81, 1, 20, "BulletListItem",
      CellTags->"3.5"],
    Cell[10499, 299, 252, 6, 20, "BulletListItem",
      CellTags->{"i:15", "3.5"}],
    Cell[10754, 307, 251, 6, 20, "BulletListItem",
      CellTags->{"i:16", "3.5"}],
    Cell[11008, 315, 398, 7, 48, "BulletListItem",
      CellTags->{"i:17", "3.5"}],
    Cell[11409, 324, 393, 7, 48, "BulletListItem",
      CellTags->{"i:18", "3.5"}],
    Cell[11805, 333, 114, 4, 24, "Text",
      CellTags->"3.5"],
    Cell[11922, 339, 409, 10, 68, "Project",
      CellTags->"3.5"],
    Cell[12334, 351, 506, 11, 84, "Text",
      CellTags->"3.5"],
    Cell[12843, 364, 78, 1, 37, "Input",
      CellTags->"3.5"],
    Cell[12924, 367, 215, 5, 38, "Text",
      CellTags->"3.5"],
    Cell[13142, 374, 109, 4, 24, "Text",
      CellTags->"3.5"],
    Cell[13254, 380, 293, 7, 89, "Input",
      CellTags->"3.5"],
    Cell[13550, 389, 125, 4, 24, "Text",
      CellTags->"3.5"],
    Cell[13678, 395, 541, 11, 141, "Input",
      CellTags->"3.5"],
    Cell[14222, 408, 40, 1, 24, "Text",
      CellTags->"3.5"],
    Cell[14265, 411, 168, 7, 89, "Input",
      CellTags->"3.5"],
    Cell[14436, 420, 148, 4, 38, "Text",
      CellTags->"3.5"],
    Cell[14587, 426, 864, 19, 112, "Project",
      CellTags->{"i:19", "3.5"}]},
  "i:15"->{
    Cell[10499, 299, 252, 6, 20, "BulletListItem",
      CellTags->{"i:15", "3.5"}]},
  "i:16"->{
    Cell[10754, 307, 251, 6, 20, "BulletListItem",
      CellTags->{"i:16", "3.5"}]},
  "i:17"->{
    Cell[11008, 315, 398, 7, 48, "BulletListItem",
      CellTags->{"i:17", "3.5"}]},
  "i:18"->{
    Cell[11409, 324, 393, 7, 48, "BulletListItem",
      CellTags->{"i:18", "3.5"}]},
  "i:19"->{
    Cell[14587, 426, 864, 19, 112, "Project",
      CellTags->{"i:19", "3.5"}]},
  "3.6"->{
    Cell[15488, 450, 53, 1, 40, "Section",
      CellTags->"3.6"],
    Cell[15544, 453, 590, 14, 100, "Reference",
      CellTags->"3.6"],
    Cell[16137, 469, 896, 14, 140, "ReferenceNote",
      CellTags->"3.6"],
    Cell[17036, 485, 411, 10, 72, "Reference",
      CellTags->"3.6"]},
  "3.7"->{
    Cell[17484, 500, 66, 1, 40, "Section",
      CellTags->"3.7"],
    Cell[17575, 505, 65, 1, 40, "Subsection",
      CellTags->"3.7"],
    Cell[17643, 508, 4232, 63, 1077, "Input",
      CellTags->{"i:21", "3.7"}],
    Cell[21912, 576, 54, 1, 40, "Subsection",
      CellTags->"3.7"],
    Cell[21969, 579, 4216, 64, 1064, "Input",
      CellTags->{"i:22", "3.7"}],
    Cell[26222, 648, 53, 1, 40, "Subsection",
      CellTags->"3.7"],
    Cell[26278, 651, 3816, 60, 947, "Input",
      CellTags->{"i:23", "3.7"}]},
  "i:21"->{
    Cell[17643, 508, 4232, 63, 1077, "Input",
      CellTags->{"i:21", "3.7"}]},
  "i:22"->{
    Cell[21969, 579, 4216, 64, 1064, "Input",
      CellTags->{"i:22", "3.7"}]},
  "i:23"->{
    Cell[26278, 651, 3816, 60, 947, "Input",
      CellTags->{"i:23", "3.7"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"3.1", 32119, 758},
  {"i:1", 32542, 771},
  {"3.2", 32629, 774},
  {"3.3", 32771, 779},
  {"i:9", 32923, 784},
  {"3.4", 33009, 787},
  {"i:11", 33499, 802},
  {"3.5", 33586, 805},
  {"i:15", 35223, 852},
  {"i:16", 35321, 855},
  {"i:17", 35419, 858},
  {"i:18", 35517, 861},
  {"i:19", 35615, 864},
  {"3.6", 35707, 867},
  {"3.7", 36005, 876},
  {"i:21", 36534, 891},
  {"i:22", 36627, 894},
  {"i:23", 36720, 897}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"3.1"],
Cell[1777, 54, 64, 1, 153, "Title",
  CellTags->"3.1"],
Cell[1844, 57, 95, 1, 22, "Quote",
  CellTags->"3.1"],
Cell[1942, 60, 152, 6, 24, "QuoteAttribution",
  CellTags->"3.1"],

Cell[CellGroupData[{
Cell[2119, 70, 55, 1, 40, "Section",
  CellTags->"3.1"],
Cell[2177, 73, 1397, 28, 200, "Text",
  CellTags->{"i:1", "3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3611, 106, 97, 1, 58, "Section",
  CellTags->"3.2"],
Cell[3711, 109, 243, 5, 52, "Text",
  CellTags->"3.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3991, 119, 75, 1, 40, "Section",
  CellTags->"3.3"],
Cell[4069, 122, 710, 16, 86, "Text",
  CellTags->{"i:9", "3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4816, 143, 50, 1, 40, "Section",
  CellTags->"3.4"],
Cell[4869, 146, 91, 1, 22, "Quote",
  CellTags->"3.4"],
Cell[4963, 149, 171, 6, 24, "QuoteAttribution",
  CellTags->"3.4"],
Cell[5137, 157, 658, 14, 114, "Text",
  CellTags->"3.4"],
Cell[5798, 173, 753, 14, 140, "Text",
  CellTags->"3.4"],
Cell[6554, 189, 792, 19, 84, "Text",
  CellTags->{"i:11", "3.4"}],
Cell[7349, 210, 172, 4, 38, "Text",
  CellTags->"3.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7558, 219, 71, 1, 40, "Section",
  CellTags->"3.5"],
Cell[7632, 222, 719, 14, 124, "Project",
  CellTags->"3.5"],
Cell[8354, 238, 421, 13, 56, "Project",
  CellTags->"3.5"],
Cell[8778, 253, 1145, 21, 196, "Project",
  CellTags->"3.5"],
Cell[9926, 276, 486, 18, 56, "Project",
  CellTags->"3.5"],
Cell[10415, 296, 81, 1, 20, "BulletListItem",
  CellTags->"3.5"],
Cell[10499, 299, 252, 6, 20, "BulletListItem",
  CellTags->{"i:15", "3.5"}],
Cell[10754, 307, 251, 6, 20, "BulletListItem",
  CellTags->{"i:16", "3.5"}],
Cell[11008, 315, 398, 7, 48, "BulletListItem",
  CellTags->{"i:17", "3.5"}],
Cell[11409, 324, 393, 7, 48, "BulletListItem",
  CellTags->{"i:18", "3.5"}],
Cell[11805, 333, 114, 4, 24, "Text",
  CellTags->"3.5"],
Cell[11922, 339, 409, 10, 68, "Project",
  CellTags->"3.5"],
Cell[12334, 351, 506, 11, 84, "Text",
  CellTags->"3.5"],
Cell[12843, 364, 78, 1, 37, "Input",
  CellTags->"3.5"],
Cell[12924, 367, 215, 5, 38, "Text",
  CellTags->"3.5"],
Cell[13142, 374, 109, 4, 24, "Text",
  CellTags->"3.5"],
Cell[13254, 380, 293, 7, 89, "Input",
  CellTags->"3.5"],
Cell[13550, 389, 125, 4, 24, "Text",
  CellTags->"3.5"],
Cell[13678, 395, 541, 11, 141, "Input",
  CellTags->"3.5"],
Cell[14222, 408, 40, 1, 24, "Text",
  CellTags->"3.5"],
Cell[14265, 411, 168, 7, 89, "Input",
  CellTags->"3.5"],
Cell[14436, 420, 148, 4, 38, "Text",
  CellTags->"3.5"],
Cell[14587, 426, 864, 19, 112, "Project",
  CellTags->{"i:19", "3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[15488, 450, 53, 1, 40, "Section",
  CellTags->"3.6"],
Cell[15544, 453, 590, 14, 100, "Reference",
  CellTags->"3.6"],
Cell[16137, 469, 896, 14, 140, "ReferenceNote",
  CellTags->"3.6"],
Cell[17036, 485, 411, 10, 72, "Reference",
  CellTags->"3.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17484, 500, 66, 1, 40, "Section",
  CellTags->"3.7"],

Cell[CellGroupData[{
Cell[17575, 505, 65, 1, 40, "Subsection",
  CellTags->"3.7"],
Cell[17643, 508, 4232, 63, 1077, "Input",
  CellTags->{"i:21", "3.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[21912, 576, 54, 1, 40, "Subsection",
  CellTags->"3.7"],
Cell[21969, 579, 4216, 64, 1064, "Input",
  CellTags->{"i:22", "3.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[26222, 648, 53, 1, 40, "Subsection",
  CellTags->"3.7"],
Cell[26278, 651, 3816, 60, 947, "Input",
  CellTags->{"i:23", "3.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

