(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38291,        986]*)
(*NotebookOutlinePosition[     48085,       1275]*)
(*  CellTagsIndexPosition[     47577,       1251]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4", "ChapterLine",
  CellTags->"4.1"],

Cell["Choosing How to Behave", "Title",
  CellTags->"4.1"],

Cell["\"We know how to behave! We've had lessons.\"", "Quote",
  CellTags->"4.1"],

Cell[TextData[{
  "\[LongDash]John Lennon in ",
  StyleBox["A Hard Day's Night",
    FontSlant->"Italic"],
  " (1964)"
}], "QuoteAttribution",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["4.1  Introduction", "Section",
  CellTags->"4.1"],

Cell[TextData[{
  "The classical prisoner's dilemma model discussed in Chapter 3 assumes that \
there are only two types of interaction behaviors: being good all of the time \
or being bad all of the time. Real people, of course, are not nearly that \
simple-minded in choosing their interaction behavior. A person can keep track \
in his mind of his own past interaction behavior and the result of that \
behavior, as well as the past interaction behavior of others. This enables a \
person to learn from this past interaction history and to adapt his behavior \
accordingly. Two models in Chapter 3 examined the easiest adaptation that a \
person can make based on the past, which is to simply refuse to interact with \
anyone who has treated him, or someone he knows, badly before. There are \
numerous other, more sophisticated adaptations that can be made based on a \
person's memory of past behavior. For example, a person could interact with \
anyone regardless of past behavior, but tailor his behavior based on that \
person's past history. Another response could involve introspection in which \
a person monitors his own interaction history and adjusts his behavior based \
on how well his past behavior has ",
  StyleBox["paid off",
    FontSlant->"Italic"],
  " for him. In this chapter, we look at models of each of these behavioral \
strategies and their effect on an individual's resource levels over time."
}], "Text",
  CellTags->"4.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4.2  Choosing One's Interaction Behavior with Another Individual \
Based on the Behavioral History of the Other Individual\
\>", "Section",
  CellTags->"4.2"],

Cell[TextData[{
  "The ability of people to recognize people and remember past interaction \
behavior are prerequisites for engaging in ",
  StyleBox["reciprocity",
    FontSlant->"Italic"],
  ". We develop a model in which each person keeps a record of the past \
behaviors of every individual with whom he has interacted, thereby enabling \
him to choose how to behave with a particular individual using various \
criteria based on previous encounters."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{
    "reciprocity", "", ""}}},
  CellTags->{"i:1", "4.2"}],

Cell["\<\
In order to demonstrate how this model works, we consider a very \
simple system [Stebbins 1996; Rees 1997] comprised of individuals using one \
of the four behavior strategies:\
\>", "Text",
  CellTags->"4.2"],

Cell[TextData[{
  "always behave nicely (an individual following this strategy is called a ",
  StyleBox["pollyanna",
    FontSlant->"Italic"],
  ");"
}], "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{"pollyanna", 
    "", ""}}},
  CellTags->{"i:2", "4.2"}],

Cell[TextData[{
  "always behave badly (an individual following this strategy is called a ",
  StyleBox["sociopath",
    FontSlant->"Italic"],
  ");"
}], "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:3", "IndexEntries" -> {{"sociopath", 
    "", ""}}},
  CellTags->{"i:3", "4.2"}],

Cell[TextData[{
  "behave nicely in the first encounter with a person and then behave in the \
same manner as that person did in the previous encounter (an individual \
following this version of the ",
  StyleBox["tit-for-tat",
    FontSlant->"Italic"],
  " strategy is called a ",
  StyleBox["nice retaliator",
    FontSlant->"Italic"],
  "); or"
}], "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:4", "IndexEntries" -> {{
    "nice retaliator", "", ""}, {"tit-for-tat strategy", "", ""}}},
  CellTags->{"i:4", "4.2"}],

Cell[TextData[{
  "behave badly in the first encounter with a person and then behave in the \
same manner as that person did in the previous encounter (an individual \
following this version of the ",
  StyleBox["tit-for-tat ",
    FontSlant->"Italic"],
  "strategy is called a ",
  StyleBox["mean retaliator",
    FontSlant->"Italic"],
  ")."
}], "BulletListItem",
  TaggingRules:>{"IndexingCellTag" -> "i:5", "IndexEntries" -> {{
    "mean retaliator", "", ""}}},
  CellTags->{"i:5", "4.2"}],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " The ",
  StyleBox["responding-in-kind",
    FontSlant->"Italic"],
  " behavior used in the tit-for tat strategies can be succinctly expressed \
in the somewhat less than golden rule ",
  StyleBox["do unto another as they have done unto you",
    FontSlant->"Italic"],
  "."
}], "Note",
  TaggingRules:>{"IndexingCellTag" -> "i:6", "IndexEntries" -> {{
    "responding-in-kind", "", ""}}},
  CellTags->{"i:6", "4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3  Aspirations", "Section",
  CellTags->"4.3"],

Cell[TextData[{
  "Posch [1997] has proposed a model that differs fundamentally from the \
previous model in that it allows a person to learn and adapt his behavior \
based on both his past experience and personal goals. This is done by having \
each individual periodically evaluate his performance by looking at his \
recent payoffs to determine if they meet his payoff goal and then keeping or \
changing his behavior based on whether he is achieving his aspiration level \
(this is known as ",
  StyleBox["satiation",
    FontSlant->"Italic"],
  ")."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:7", "IndexEntries" -> {{
    "aspiration level", "", ""}, {"introspection", "", ""}, {"Posch", "", 
    ""}, {"satiation", "", ""}}},
  CellTags->{"i:7", "4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4  Computer Simulation Projects", "Section",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " A variant of the tit-for-tat strategy is the tit-for-two-tats strategy in \
which an individual doesn't retaliate by behaving badly against another \
person until that person has behaved badly in two successive interactions. \
Incorporate this strategy into the behavioral history-based strategy program \
by modifying the behave rules."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:10", "IndexEntries" -> {{
    "tit-for-two-tats strategy", "", ""}}},
  CellTags->{"i:10", "4.4"}],

Cell[TextData[{
  StyleBox["2",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " In one variation of the aspiration model, each individual's probability \
of re-evaluating his behavior is not fixed but, instead, increases or \
decreases with the difference between his last payoff and his aspiration \
level. This can be implemented by changing the interact rules to"
}], "Project",
  CellTags->"4.4"],

Cell["\<\
interact[{1, b1_, a1_, e1_, p1_, r1_},
         {3, b3_, _, _, _, _}, _, _, _] := 
              {1, b1, a1, e1 - payoff[b1, b3], Join[
               p1, {payoff[b1, b3]}], r1 + payoff[b1, b3]}
interact[{2, b2_, a2_ ,e2_, p2_, r2_}, _,
         {4, b4_, _, _, _, _}, _, _] :=
              {2, b2, a2, e2 - payoff[b2, b4], Join[
               p2, {payoff[b2, b4]}], r2 + payoff[b2, b4]}
interact[{3, b3_, a3_, e3_, p3_, r3_}, _, _,
         {1, b1_, _, _, _, _}, _] :=
              {3, b3, a3, e3 - payoff[b3, b1], Join[
               p3, {payoff[b3, b1]}], r3 + payoff[b3, b1]}
interact[{4, b4_, a4_, e4_, p4_, r4_}, _, _, _,
         {2, b2_, _, _, _, _}] :=
              {4, b4, a4, e4 - payoff[b4, b2], Join[
               p4, {payoff[b4, b2]}], r4 + payoff[b4, b2]}\
\>", "Input",
  CellTags->"4.4"],

Cell["\<\
Implement this code in a program and run it to see what happens. \
\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["3",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " An individual could keep a history of his own behavior and payoffs and \
bias his choice of behavior towards the behavior producing the higher payoff. \
For example, a person would be twice as likely to choose one behavior over \
another if the average payoff from that behavior had been twice as much as \
the average payoff from the other behavior. Implement this strategy and run \
the simulation to see how the resource levels are affected."
}], "Project",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["4",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " In yet another variation of the aspiration model, the payoffs for an \
interaction between any two facing individuals varies. For each interaction \
that takes place, the values of ",
  StyleBox["R", "IT"],
  ", ",
  StyleBox["S", "IT"],
  ", ",
  StyleBox["T", "IT"],
  ", and ",
  StyleBox["P", "IT"],
  " are chosen randomly using Random[Real, {\[Alpha], \[Beta]}] where \
\[Alpha] and \[Beta] are integers (e.g., \[Alpha] = -3 and \[Beta] = 5). \
Implement this code in a program and run it to see what happens. "
}], "Project",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["5",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "Nowak and co-workers [Nowak et al. 1994; 1995] have developed a ",
  StyleBox["keeping up with the Joneses",
    FontSlant->"Italic"],
  " version of the win stay-lose shift strategy. All of the lattice sites are \
occupied by individuals (who are therefore immobile) who interact with each \
of their nearest neighbors over a number of time steps. The interaction \
behavior (cooperate or defect) used by a person in each time step is \
determined as follows: In a given time step, a person interacts with himself \
and with his eight nearest neighbors (ie., the nine sites in the Moore \
neighborhood of the person) in a pairwise manner with either good or bad \
behavior. The total payoff to the person resulting from all nine pairwise \
interactions is determined. The person then compares his total payoff to the \
payoffs received by all of the people in his neighborhood (who similarly have \
interacted with their neighbors), and adapts for the next time step the \
strategy of the neighbor (which included himself) who received the biggest \
payoff."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{
    "win stay-lose shift strategy", "", ""}}},
  CellTags->{"i:11", "4.4"}],

Cell[TextData[{
  "This ",
  StyleBox["static",
    FontSlant->"Italic"],
  " spatial prisoner's dilemma can be modified to incorporate the mobility of \
the agents, thereby enabling interaction partners to change over time. We \
present the development of this model here in detail because it contains some \
interesting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:12", "IndexEntries" -> {{
    "prisoner's dilemma", "mobile", ""}, {"prisoner's dilemma", "spatial", 
    ""}, {"prisoner's dilemma", "static", ""}}},
  CellTags->{"i:12", "4.4"}],

Cell[TextData[{
  "The model employs an ",
  StyleBox["n", "IT"],
  " by ",
  StyleBox["n", "IT"],
  " square lattice, with periodic boundary conditions. The lattice sites are \
either empty or occupied. The site values are integer values."
}], "Text",
  CellTags->"4.4"],

Cell["\<\
The value of this single element is the integer 0, 1, or -1 where \
the values have the meanings:\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[
"0 \[LongDash] a site occupied by a bad guy (defector or noncooperator);"], 
  "ListItem",
  CellTags->"4.4"],

Cell[TextData[
"1 \[LongDash] a site occupied by a good guy (cooperator); and "], "ListItem",\

  CellTags->"4.4"],

Cell[TextData["-1 \[LongDash] an empty site."], "ListItem",
  CellTags->"4.4"],

Cell["\<\
Note: Until now, we have used 0 to denote an empty site. The \
usefulness of letting -1 represent empty sites in this model becomes apparent \
in the following description of the payoff rules. \
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[{
  "For",
  " ",
  "a density ",
  StyleBox["r", "IT"],
  " of people, of whom a fraction ",
  StyleBox["k", "IT"],
  " are bad guys and the rest are good guys, the initial configuration is \
given by"
}], "Text",
  CellTags->"4.4"],

Cell[TextData[
"society = Table[Floor[-1 + r + Random[]], {n}, {n}] /.\n             0 \
\[RuleDelayed] Floor[1 - k + Random[]]"], "Input",
  CellTags->"4.4"],

Cell["\<\
The prisoner's dilemma \"game\" is played over a number of time \
steps (i.e., rounds). In each time step, the following occur consecutively.\
\
\>", "Text",
  CellTags->"4.4"],

Cell["\<\
Each site on the lattice interacts in a pairwise manner with itself \
and with the eight nearest neighbor sites in its Moore neighborhood and the \
total payoff to each site from these interactions is calculated.\
\>", 
  "BulletListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "Each site examines the total payoff received by each site in its \
neighborhood. If the site is empty it remains empty. If the site is occupied \
by a good guy or a bad guy, he adopts the strategy (remains good or bad or ",
  StyleBox["switches sides",
    FontSlant->"Italic"],
  " from good to bad or vice versa) based on the strategy used by the person \
in his neighborhood that received the largest payoff, and randomly chooses a \
direction (north, east, south, or west) to face."
}], "BulletListItem",
  CellTags->"4.4"],

Cell["\<\
Each person on an occupied site that faces an empty site not faced \
by any other person moves to that site. All other individuals remain in \
place. An empty site faced by exactly one person becomes occupied by that \
person. All other empty sites remain unoccupied.\
\>", "BulletListItem",
  CellTags->"4.4"],

Cell["We implement these stages of each time step as follows.", "Text",
  CellTags->"4.4"],

Cell[CellGroupData[{

Cell["Calculating the {payoff to site, strategy of site} matrix", 
  "Subsubsection",
  CellTags->"4.4"],

Cell["\<\
Each site interacts with the sites in its Moore neighborhood in a \
pairwise manner. A payoff value is computed for each interaction as \
follows.\
\>", "Text",
  CellTags->"4.4"],

Cell["\<\
An empty site interacting with a good guy or a bad guy or an empty \
site has a payoff of 0.\
\>", "BulletListItem",
  CellTags->"4.4"],

Cell["A good guy interacting with a good guy has a payoff of 1.", 
  "BulletListItem",
  CellTags->"4.4"],

Cell["A good guy interacting with a bad guy has a payoff of 0.", 
  "BulletListItem",
  CellTags->"4.4"],

Cell["A good guy interacting with an empty site has a payoff of 0.", 
  "BulletListItem",
  CellTags->"4.4"],

Cell["A bad guy interacting with a defector has a payoff of 0.", 
  "BulletListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "A bad guy interacting with a good guy has a payoff of ",
  StyleBox["p", "IT"],
  " (where ",
  StyleBox["p", "IT"],
  " > 1.0)."
}], "BulletListItem",
  CellTags->"4.4"],

Cell["A bad guy interacting with an empty site has a payoff of 0.", 
  "BulletListItem",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " In the absence of empty sites (",
  StyleBox["r", "IT"],
  " = 0), these payoff values correspond to using ",
  StyleBox["S", "IT"],
  " = ",
  StyleBox["P", "IT"],
  " = 0, ",
  StyleBox["R", "IT"],
  " = 1, ",
  StyleBox["T", "IT"],
  " = ",
  StyleBox["p", "IT"],
  " (",
  StyleBox["p", "IT"],
  " > 1) in the static prisoner's dilemma game. These values are used to \
simplify the program by using a single payoff parameter value but other \
payoff values should produce the same results."
}], "Text",
  CellTags->"4.4"],

Cell["\<\
The total payoff for a site is the sum of the nine payoffs \
resulting from the interactions of the site with each site in its \
neighborhood (including itself). The total payoff to an empty site is zero.\
\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " In the payoff calculation that follows, an empty site (i.e., one having a \
value of -1) is treated as a bad guy (with a value of 0) and so the total \
payoff to an empty site may be incorrectly calculated as nonzero, but this is \
irrelevant since empty sites are dealt with differently than occupied sites \
in the later steps of the calculation."
}], "Text",
  CellTags->"4.4"],

Cell["\<\
We take the matrix whose elements are integer-number values \
representing the strategies of the sites in the lattice (0 for a bad guy, 1 \
for a good guy, and -1 for an empty site) and use it to create a matrix whose \
elements are ordered pairs whose first component is the total payoff to the \
corresponding site in the lattice and whose second component is the strategy \
of the corresponding site in the lattice.\
\>", "Text",
  CellTags->"4.4"],

Cell["\<\
The {payoff, strategy} matrix is calculated by applying the \
following anonymous function to the lattice, represented here by mat.\
\>", 
  "Text",
  CellTags->"4.4"],

Cell[TextData[
"MapThread[List, {Moore[payoff, (# /. -1 \[Rule] 0)], #}, 2]&[mat]"], "Input",\

  CellTags->"4.4"],

Cell["where", "Text",
  CellTags->"4.4"],

Cell["\<\
Moore[func_, lat_] :=
  MapThread[func, Map[RotateRight[lat, #]&,
           {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},
            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2]\
\>", "Input",
  CellTags->"4.4"],

Cell["and the payoff rules are given by ", "Text",
  CellTags->"4.4"],

Cell["\<\
payoff[1, a_, b_, c_, d_, e_, f_, g_, h_] :=
                         1 + a + b + c + d + e + f + g + h
payoff[0, a_, b_, c_, d_, e_, f_, g_, h_] :=
                          p (a + b + c + d + e + f + g + h)\
\>", "Input",
  CellTags->"4.4"],

Cell["\<\
where the arguments to the payoff rules are the values of the nine \
sites in the Moore neighborhood of a site.\
\>", "Text",
  CellTags->"4.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculating the {direction faced by site, strategy of site} \
matrix\
\>", "Subsubsection",
  CellTags->"4.4"],

Cell["\<\
We take the matrix whose elements are ordered pairs whose \
components are the total payoff and the strategy of the corresponding site in \
the lattice and use it to create a matrix of elements that are ordered pairs \
whose components are the direction faced and the strategy adopted by the \
corresponding site in the lattice (i.e., the strategy used by the site in the \
neighborhood that received the highest payoff).\
\>", "Text",
  CellTags->"4.4"],

Cell["\<\
The direction faced by a site is given by an integer ranging from 0 \
to 4 where the values have the meanings:\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData["0 \[LongDash] an empty site;"], "ListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "1",
  " \[LongDash] ",
  "a site occupied by a north facing individual;"
}], "ListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "2",
  " \[LongDash] ",
  "a site occupied by a east facing individual;"
}], "ListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "3",
  " \[LongDash] ",
  "a site occupied by a south facing individual; and"
}], "ListItem",
  CellTags->"4.4"],

Cell[TextData[{
  "4",
  " \[LongDash] ",
  "a site occupied by a west facing individual."
}], "ListItem",
  CellTags->"4.4"],

Cell["\<\
The{direction faced, strategy used} matrix is determined using\
\>",
   "Text",
  CellTags->"4.4"],

Cell[TextData[
"Moore[strategy, MapThread[List,\n             {Moore[payoff, (# /. -1 \
\[Rule] 0)], #}, 2]]&[mat] "], "Input",
  CellTags->"4.4"],

Cell["where the strategy rules are given by:", "Text",
  CellTags->"4.4"],

Cell["\<\
strategy[{_, -1}, ___] := {0, -1}
strategy[x: {_, _}..] := {Random[Integer, {1, 4}],
   Cases[#, {Max[Transpose[#][[1]]], _}][[1, 2]]&[
                                DeleteCases[{x},{_, -1}]]}\
\>", "Input",
  CellTags->"4.4"],

Cell["\<\
We take the matrix with elements of ordered pair values whose \
components are the direction faced and the strategy adopted by the \
corresponding site in the lattice and use the following rules to move the \
good guys and bad guys.\
\>", "Text",
  CellTags->"4.4"],

Cell["\<\
move[{1,x_},{y_?Positive,_},_,_,_,_,_,_,_,_,_,_,_] := x
move[{2,x_},_,{y_?Positive,_},_,_,_,_,_,_,_,_,_,_] := x
move[{3,x_},_,_,{y_?Positive,_},_,_,_,_,_,_,_,_,_] := x
move[{4,x_},_,_,_,{y_?Positive,_},_,_,_,_,_,_,_,_] := x
move[{1,x_},{0,-1},_,_,_,{4,_},_,_,_,_,_,_,_] := x
move[{1,x_},{0,-1},_,_,_,_,_,_,{2,_},_,_,_,_] := x
move[{1,x_},{0,-1},_,_,_,_,_,_,_,{3,_},_,_,_] := x
move[{2,x_},_,{0,-1},_,_,{3,_},_,_,_,_,_,_,_] := x
move[{2,x_},_,{0,-1},_,_,_,{1,_},_,_,_,_,_,_] := x
move[{2,x_},_,{0,-1},_,_,_,_,_,_,_,{4,_},_,_] := x
move[{3,x_},_,_,{0,-1},_,_,{4,_},_,_,_,_,_,_] := x
move[{3,x_},_,_,{0,-1},_,_,_,{2,_},_,_,_,_,_] := x
move[{3,x_},_,_,{0,-1},_,_,_,_,_,_,_,{1,_},_] := x
move[{4,x_},_,_,_,{0,-1},_,_,{1,_},_,_,_,_,_] := x
move[{4,x_},_,_,_,{0,-1},_,_,_,{3,_},_,_,_,_] := x
move[{4,x_},_,_,_,{0,-1},_,_,_,_,_,_,_,{2,_}] := x
move[{1,_},{0,-1},_,_,_,_,_,_,_,_,_,_,_] := -1
move[{2,_},_,{0,-1},_,_,_,_,_,_,_,_,_,_] := -1
move[{3,_},_,_,{0,-1},_,_,_,_,_,_,_,_,_] := -1
move[{4,_},_,_,_,{0,-1},_,_,_,_,_,_,_,_] := -1
move[{0,-1},{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := -1
move[{0,-1},{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := -1
move[{0,-1},{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := -1
move[{0,-1},_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := -1
move[{0,-1},_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := -1
move[{0,-1},_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := -1
move[{0,-1},{3,x_},_,_,_,_,_,_,_,_,_,_,_] := x
move[{0,-1},_,{4,x_},_,_,_,_,_,_,_,_,_,_] := x
move[{0,-1},_,_,{1,x_},_,_,_,_,_,_,_,_,_] := x
move[{0,-1},_,_,_,{2,x_},_,_,_,_,_,_,_,_] := x
move[{0,-1},_,_,_,_,_,_,_,_,_,_,_,_] := -1\
\>", "Input",
  CellTags->"4.4"],

Cell["\<\
The lattice whose site values consist of the new strategy matrix is \
calculated by applying the move rules to the {direction faced, strategy used} \
matrix using\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[
"GN[move, Moore[strategy, MapThread[List,\n            {Moore[payoff, (# /. \
-1 \[Rule] 0)], #}, 2]]]&[mat] "], "Input",
  CellTags->"4.4"],

Cell["where", "Text",
  CellTags->"4.4"],

Cell["\<\
GN[func_, lat_] :=
  MapThread[func, Map[RotateRight[lat, #]&,
            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},
             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},
             {0, -2}, {-2, 0}, {0, 2}}], 2]\
\>", "Input",
  CellTags->"4.4"],

Cell[TextData[{
  "The mobile prisoner's dilemma program evolves over ",
  StyleBox["t", "IT"],
  " time steps, starting with the initial lattice configuration, society, \
using the following nesting operation."
}], "Text",
  CellTags->"4.4"],

Cell[TextData[
"NestList[GN[move, Moore[strategy, MapThread[List,\n      {Moore[payoff, (# \
/. -1 \[Rule] 0)], #}, 2]]]&, society, t]"], "Input",
  CellTags->"4.4"],

Cell["\<\
The mobile prisoner's dilemma program is assembled from the \
previously given code fragments.\
\>", "Text",
  CellTags->"4.4"],

Cell[TextData[
"mobilePrisonerDilemma[n_, r_, k_, p_, t_] :=\nModule[{RND, society, payoff, \
strategy, move, Moore, GN},\n\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[-1 + r + Random[]], {n}, {n}] /.\n               0 \[RuleDelayed] \
Floor[1 - k + Random[]];\n  \n  payoff[1, a_, b_, c_, d_, e_, f_, g_, h_] :=\n\
                       1 + a + b + c + d + e + f + g + h;\n  payoff[0, a_, \
b_, c_, d_, e_, f_, g_, h_] :=\n                        p (a + b + c + d + e \
+ f + g + h);\n  \n  strategy[{_, -1}, ___] := {0, -1}\n  strategy[x:{_, \
_}..] := {RND,\n     Cases[#, {Max[Transpose[#][[1]]], _}][[1, 2]]&[\n        \
                        DeleteCases[{x},{_, -1}]]};\n  \n  \
move[{1,x_},{y_?Positive,_},_,_,_,_,_,_,_,_,_,_,_] := x;\n  \
move[{2,x_},_,{y_?Positive,_},_,_,_,_,_,_,_,_,_,_] := x;\n  \
move[{3,x_},_,_,{y_?Positive,_},_,_,_,_,_,_,_,_,_] := x;\n  \
move[{4,x_},_,_,_,{y_?Positive,_},_,_,_,_,_,_,_,_] := x;\n  \
move[{1,x_},{0,-1},_,_,_,{4,_},_,_,_,_,_,_,_] := x;\n  \
move[{1,x_},{0,-1},_,_,_,_,_,_,{2,_},_,_,_,_] := x;\n  \
move[{1,x_},{0,-1},_,_,_,_,_,_,_,{3,_},_,_,_] := x;\n  \
move[{2,x_},_,{0,-1},_,_,{3,_},_,_,_,_,_,_,_] := x;\n  \
move[{2,x_},_,{0,-1},_,_,_,{1,_},_,_,_,_,_,_] := x;\n  \
move[{2,x_},_,{0,-1},_,_,_,_,_,_,_,{4,_},_,_] := x;\n  \
move[{3,x_},_,_,{0,-1},_,_,{4,_},_,_,_,_,_,_] := x;\n  \
move[{3,x_},_,_,{0,-1},_,_,_,{2,_},_,_,_,_,_] := x;\n  \
move[{3,x_},_,_,{0,-1},_,_,_,_,_,_,_,{1,_},_] := x;\n  \
move[{4,x_},_,_,_,{0,-1},_,_,{1,_},_,_,_,_,_] := x;\n  \
move[{4,x_},_,_,_,{0,-1},_,_,_,{3,_},_,_,_,_] := x;\n  \
move[{4,x_},_,_,_,{0,-1},_,_,_,_,_,_,_,{2,_}] := x;\n  \
move[{1,_},{0,-1},_,_,_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{2,_},_,{0,-1},_,_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{3,_},_,_,{0,-1},_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{4,_},_,_,_,{0,-1},_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := -1;\n  \
move[{0,-1},{3,x_},_,_,_,_,_,_,_,_,_,_,_] := x;\n  \
move[{0,-1},_,{4,x_},_,_,_,_,_,_,_,_,_,_] := x;\n  \
move[{0,-1},_,_,{1,x_},_,_,_,_,_,_,_,_,_] := x;\n  \
move[{0,-1},_,_,_,{2,x_},_,_,_,_,_,_,_,_] := x;\n  \
move[{0,-1},_,_,_,_,_,_,_,_,_,_,_,_] := -1;\n  \n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  \n  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n     \
       {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 \n  NestList[GN[move, Moore[strategy, MapThread[List,\n     {Moore[payoff, \
(# /. -1 \[Rule] 0)], #}, 2]]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:13", "IndexEntries" -> {{
    "mobilePrisonerDilemma", "", ""}}},
  CellTags->{"i:13", "4.4"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.5  References", "Section",
  CellTags->"4.5"],

Cell[TextData[{
  "Nowak, Martin A., Sebastian Bonhoeffer, and Robert M. May. 1994. \"Spatial \
Games and the Maintenance of Cooperation.\" In ",
  StyleBox["Proceedings of the National Academy of Sciences USA",
    FontSlant->"Italic"],
  " 91; 4877\[Dash]81.\nNowak, Martin A., Robert M. May, and Karl Sigmund. \
1995. \"The Arithmetics of Mutual Help.\" ",
  StyleBox["Scientific American",
    FontSlant->"Italic"],
  " 272 (June): 76\[Dash]81.\nPosch, Martin. 1997. \"Win Stay-Lose Shift: An \
Elementary Learning Rule for Normal Form Games.\" 1997 Sante Fe Institute \
Working Papers No. 97-06- 056 E.\nRees, Peter. 1997. \"Simulation Sheds Light \
on Cooperation.\" ",
  StyleBox["Scientific Computing World",
    FontSlant->"Italic"],
  " (June): 25\[Dash]29.\nStebbins, George. 1996. \"The Evolution of \
Cooperation as Examined Using the Prisoner's Dilemma.\" \
http://www.cs.utah.edu/~stebbins/java/cs573/paper.html"
}], "Reference",
  CellTags->"4.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6  Programs in the Chapter", "Section",
  CellTags->"4.6"],

Cell[CellGroupData[{

Cell["4.6.1  pollysociotit4tat", "Subsection",
  CellTags->"4.6"],

Cell[TextData[
"pollysociotit4tat[n_, p_, {s_, t_, u_, v_},\n                          {P_, \
R_, S_, T_}, q_] := \nModule[{RND, k = 0, society, behave, decide,\n          \
         payoff, act, walk, vonNeumann, GN},\n  RND := Random[Integer, {1, \
4}];\n  society = Table[Floor[p + Random[]], {n}, {n}]  /.\n    1 \
\[RuleDelayed] {++k, Floor[1 + v + u + Random[]]} /.\n    {{m_, 1} \
\[RuleDelayed] {RND, m, Table[{}, {k}], 0,\n                     Floor[1 + \
t/(s + t) + Random[]]},\n     {m_, 2} \[RuleDelayed] {RND, m, Table[{}, {k}], \
0,\n                     Floor[3 + v/(v + u) + Random[]]}};\n  behave[1, _] = \
1;\n  behave[2, {___, 0}] = 0;\n  behave[2, _] = 1;\n  behave[3, _] = 0;\n  \
behave[4, {___, 1}] = 1;\n  behave[4, _] = 0;\n  decide[{1, name1_, lis1_, \
res1_, strat1_},\n         {3, name3_, _, _, _}, _, _, _] :=\n                \
{1, name1, lis1, res1,\n                  behave[strat1, lis1[[name3]]], \
strat1};\n  decide[{3, name3_, lis3_, res3_, strat3_}, _, _,\n         {1, \
name1_, _, _, _}, _] := \n                {3, name3, lis3, res3,\n            \
      behave[strat3, lis3[[name1]]], strat3};\n  decide[{2, name2_, lis2_, \
res2_, strat2_}, _,\n         {4, name4_, _, _, _}, _, _] := \n               \
 {2, name2, lis2, res2,\n                  behave[strat2, lis2[[name4]]], \
strat2};\n  decide[{4, name4_, lis4_, res4_, strat4_}, _, _, _,\n         {2, \
name2_, _, _, _}] := \n                {4, name4, lis4, res4,\n               \
   behave[strat4, lis4[[name2]]], strat4};\n  decide[z_, _, _, _, _] := z;\n  \
payoff[1, 1] = R;\n  payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = \
P;\n  act[{1, name1_, lis1_, res1_, behave1_, strat1_},\n      {3, name3_, _, \
_, behave3_, _}, _, _, _] := \n             {1, name1, ReplacePart[lis1,\n    \
           Join[lis1[[name3]], {behave3}], name3],\n               res1 + \
payoff[behave1, behave3], strat1};\n\n  act[{3, name3_, lis3_, res3_, \
behave3_, strat3_}, _, _,\n      {1, name1_, _, _, behave1_, _}, _] := \n     \
        {3, name3, ReplacePart[lis3,\n               Join[lis3[[name1]], \
{behave1}], name1],\n               res3 + payoff[behave3, behave1], strat3};\
\n\n  act[{2, name2_, lis2_, res2_, behave2_, strat2_}, _,\n      {4, name4_, \
_, _, behave4_, _}, _, _] := \n             {2, name2, ReplacePart[lis2,\n    \
           Join[lis2[[name4]], {behave4}], name4],\n               res2 + \
payoff[behave2, behave4], strat2};\n\n  act[{4, name4_, lis4_, res4_, \
behave4_, strat4_}, _, _,\n   _, {2, name2_, _, _, behave2_, _}] := \n        \
     {4, name4, ReplacePart[lis4,\n               Join[lis4[[name2]], \
{behave2}], name2],\n               res4 + payoff[behave4, behave2], strat4};\
\n  act[z_, _, _, _, _] := z;\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] \
:= {RND,a};\n  walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;  \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n         {{0, 0}, {1, 0}, {0, -1}, \
{-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk,\n    vonNeumann[act, \
vonNeumann[decide, #]]]&, society, q]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:14", "IndexEntries" -> {{
    "pollysociotit4tat", "", ""}}},
  CellTags->{"i:14", "4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6.2  aspirations", "Subsection",
  CellTags->"4.6"],

Cell[TextData[{
  "aspirations[n_, p_, g_, {P_, R_, S_, T_}, t_] := \nModule[{society, \
interact, payoff,  eval, walk, vonNeumann, GN, RND},\n  RND := \
Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\
\n      1 \[RuleDelayed] {RND, Floor[g + Random[]],\n           Random[Real, \
{Min[#], Max[#]}&[{R, S, T, P}]],\n           Random[], {}, 0};\n  payoff[1, \
1] = R;\n  payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  \
interact[{1, b1_, a1_, e1_, p1_, r1_},\n           {3, b3_, _, _, _, _}, _, \
_, _] :=  \n             {1, b1, a1, e1, Join[p1, {payoff[b1, b3]}],\n        \
                             r1 + payoff[b1, b3]};\n  interact[{2, b2_, a2_ \
,e2_, p2_, r2_}, _,\n           {4, b4_, _, _, _, _}, _, _] :=\n             \
{2, b2, a2, e2, Join[p2, {payoff[b2, b4]}],\n                                 \
    r2 + payoff[b2, b4]};\n  interact[{3, b3_, a3_, e3_, p3_, r3_}, _, _,\n   \
        {1, b1_, _, _, _, _}, _] := \n             {3, b3, a3, e3, Join[p3, \
{payoff[b3, b1]}],\n                                     r3 + payoff[b3, \
b1]};\n  interact[{4, b4_, a4_, e4_, p4_, r4_}, _, _, _,\n           {2, b2_, \
_, _, _, _}] :=\n             {4, b4, a4, e4, Join[p4, {payoff[b4, b2]}],\n   \
                                  r4 + payoff[b4, b2]};\n  interact[z_, _, _, \
_, _] := z;\n  eval[{x_, b_, 0, e_, pp_, r_}] :=  {x, b, 0, e, {}, r};\n  \
eval[{x_, b_, a_, e_, {}, r_}] :=  {x, b, a, e, {}, r};\n  eval[{x_, 1, a_, \
e_, pp_, r_}] :=  {x,\n    Sign[Floor[(Apply[Plus, pp]/Length[pp])/a]],\n     \
                  a, e, {}, r} /; (Random[] + e) > 1;\n  eval[{x_, 0, a_, e_, \
pp_, r_}] :=  {x,\n    1 - Sign[Floor[(Apply[Plus, pp]/Length[pp])/a]],\n     \
                  a, e, {}, r} /; (Random[] + e) > 1;\n  eval[z_, _, _, _, _] \
:= z;\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n",
  "  walk[",
  "0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestList[GN[walk,\n   Map[eval, \
vonNeumann[interact, #], {2}]]&, society, t]]"
}], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:15", "IndexEntries" -> {{
    "aspirations", "", ""}}},
  CellTags->{"i:15", "4.6"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "4. Choosing How to Behave"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 16, "IndexEntries" -> {{"i:1", 
  "reciprocity", "", ""}, {"i:2", "pollyanna", "", ""}, {"i:3", "sociopath", 
  "", ""}, {"i:4", "nice retaliator", "", ""}, {"i:4", 
  "tit-for-tat strategy", "", ""}, {"i:5", "mean retaliator", "", ""}, {
  "i:6", "responding-in-kind", "", ""}, {"i:7", "aspiration level", "", ""}, {
  "i:7", "introspection", "", ""}, {"i:7", "Posch", "", ""}, {"i:7", 
  "satiation", "", ""}, {"i:10", "tit-for-two-tats strategy", "", ""}, {
  "i:11", "win stay-lose shift strategy", "", ""}, {"i:12", 
  "prisoner's dilemma", "mobile", ""}, {"i:12", "prisoner's dilemma", 
  "spatial", ""}, {"i:12", "prisoner's dilemma", "static", ""}, {"i:13", 
  "mobilePrisonerDilemma", "", ""}, {"i:14", "pollysociotit4tat", "", ""}, {
  "i:15", "aspirations", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@E2X000000000006T<01T1T00000000000
00000000003oo`@GFD3oo`02DE`00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "4.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"4.1"],
    Cell[1777, 54, 58, 1, 153, "Title",
      CellTags->"4.1"],
    Cell[1838, 57, 81, 1, 22, "Quote",
      CellTags->"4.1"],
    Cell[1922, 60, 161, 6, 24, "QuoteAttribution",
      CellTags->"4.1"],
    Cell[2108, 70, 55, 1, 40, "Section",
      CellTags->"4.1"],
    Cell[2166, 73, 1455, 22, 250, "Text",
      CellTags->"4.1"]},
  "4.2"->{
    Cell[3658, 100, 168, 4, 76, "Section",
      CellTags->"4.2"],
    Cell[3829, 106, 591, 12, 82, "Text",
      CellTags->{"i:1", "4.2"}],
    Cell[4423, 120, 220, 5, 52, "Text",
      CellTags->"4.2"],
    Cell[4646, 127, 294, 8, 38, "BulletListItem",
      CellTags->{"i:2", "4.2"}],
    Cell[4943, 137, 293, 8, 38, "BulletListItem",
      CellTags->{"i:3", "4.2"}],
    Cell[5239, 147, 531, 13, 50, "BulletListItem",
      CellTags->{"i:4", "4.2"}],
    Cell[5773, 162, 493, 13, 50, "BulletListItem",
      CellTags->{"i:5", "4.2"}],
    Cell[6269, 177, 481, 14, 58, "Note",
      CellTags->{"i:6", "4.2"}]},
  "i:1"->{
    Cell[3829, 106, 591, 12, 82, "Text",
      CellTags->{"i:1", "4.2"}]},
  "i:2"->{
    Cell[4646, 127, 294, 8, 38, "BulletListItem",
      CellTags->{"i:2", "4.2"}]},
  "i:3"->{
    Cell[4943, 137, 293, 8, 38, "BulletListItem",
      CellTags->{"i:3", "4.2"}]},
  "i:4"->{
    Cell[5239, 147, 531, 13, 50, "BulletListItem",
      CellTags->{"i:4", "4.2"}]},
  "i:5"->{
    Cell[5773, 162, 493, 13, 50, "BulletListItem",
      CellTags->{"i:5", "4.2"}]},
  "i:6"->{
    Cell[6269, 177, 481, 14, 58, "Note",
      CellTags->{"i:6", "4.2"}]},
  "4.3"->{
    Cell[6787, 196, 54, 1, 40, "Section",
      CellTags->"4.3"],
    Cell[6844, 199, 769, 15, 96, "Text",
      CellTags->{"i:7", "4.3"}]},
  "i:7"->{
    Cell[6844, 199, 769, 15, 96, "Text",
      CellTags->{"i:7", "4.3"}]},
  "4.4"->{
    Cell[7650, 219, 71, 1, 40, "Section",
      CellTags->"4.4"],
    Cell[7724, 222, 594, 13, 82, "Project",
      CellTags->{"i:10", "4.4"}],
    Cell[8321, 237, 422, 10, 68, "Project",
      CellTags->"4.4"],
    Cell[8746, 249, 820, 18, 232, "Input",
      CellTags->"4.4"],
    Cell[9569, 269, 110, 4, 24, "Text",
      CellTags->"4.4"],
    Cell[9682, 275, 581, 12, 96, "Project",
      CellTags->"4.4"],
    Cell[10266, 289, 653, 19, 84, "Project",
      CellTags->"4.4"],
    Cell[10922, 310, 1319, 24, 196, "Project",
      CellTags->{"i:11", "4.4"}],
    Cell[12244, 336, 627, 15, 70, "Text",
      CellTags->{"i:12", "4.4"}],
    Cell[12874, 353, 271, 8, 40, "Text",
      CellTags->"4.4"],
    Cell[13148, 363, 140, 4, 38, "Text",
      CellTags->"4.4"],
    Cell[13291, 369, 124, 3, 20, "ListItem",
      CellTags->"4.4"],
    Cell[13418, 374, 114, 3, 20, "ListItem",
      CellTags->"4.4"],
    Cell[13535, 379, 78, 1, 20, "ListItem",
      CellTags->"4.4"],
    Cell[13616, 382, 236, 5, 52, "Text",
      CellTags->"4.4"],
    Cell[13855, 389, 247, 10, 40, "Text",
      CellTags->"4.4"],
    Cell[14105, 401, 158, 3, 50, "Input",
      CellTags->"4.4"],
    Cell[14266, 406, 186, 5, 38, "Text",
      CellTags->"4.4"],
    Cell[14455, 413, 268, 6, 48, "BulletListItem",
      CellTags->"4.4"],
    Cell[14726, 421, 546, 10, 92, "BulletListItem",
      CellTags->"4.4"],
    Cell[15275, 433, 320, 6, 62, "BulletListItem",
      CellTags->"4.4"],
    Cell[15598, 441, 90, 1, 24, "Text",
      CellTags->"4.4"],
    Cell[15713, 446, 104, 2, 30, "Subsubsection",
      CellTags->"4.4"],
    Cell[15820, 450, 189, 5, 38, "Text",
      CellTags->"4.4"],
    Cell[16012, 457, 145, 4, 34, "BulletListItem",
      CellTags->"4.4"],
    Cell[16160, 463, 105, 2, 20, "BulletListItem",
      CellTags->"4.4"],
    Cell[16268, 467, 104, 2, 20, "BulletListItem",
      CellTags->"4.4"],
    Cell[16375, 471, 108, 2, 20, "BulletListItem",
      CellTags->"4.4"],
    Cell[16486, 475, 104, 2, 20, "BulletListItem",
      CellTags->"4.4"],
    Cell[16593, 479, 189, 7, 22, "BulletListItem",
      CellTags->"4.4"],
    Cell[16785, 488, 107, 2, 20, "BulletListItem",
      CellTags->"4.4"],
    Cell[16895, 492, 590, 21, 70, "Text",
      CellTags->"4.4"],
    Cell[17488, 515, 249, 6, 52, "Text",
      CellTags->"4.4"],
    Cell[17740, 523, 445, 9, 82, "Text",
      CellTags->"4.4"],
    Cell[18188, 534, 461, 8, 94, "Text",
      CellTags->"4.4"],
    Cell[18652, 544, 177, 5, 38, "Text",
      CellTags->"4.4"],
    Cell[18832, 551, 114, 3, 37, "Input",
      CellTags->"4.4"],
    Cell[18949, 556, 40, 1, 24, "Text",
      CellTags->"4.4"],
    Cell[18992, 559, 216, 6, 76, "Input",
      CellTags->"4.4"],
    Cell[19211, 567, 69, 1, 24, "Text",
      CellTags->"4.4"],
    Cell[19283, 570, 252, 6, 76, "Input",
      CellTags->"4.4"],
    Cell[19538, 578, 154, 4, 38, "Text",
      CellTags->"4.4"],
    Cell[19729, 587, 120, 4, 30, "Subsubsection",
      CellTags->"4.4"],
    Cell[19852, 593, 464, 8, 94, "Text",
      CellTags->"4.4"],
    Cell[20319, 603, 153, 4, 38, "Text",
      CellTags->"4.4"],
    Cell[20475, 609, 77, 1, 20, "ListItem",
      CellTags->"4.4"],
    Cell[20555, 612, 126, 5, 20, "ListItem",
      CellTags->"4.4"],
    Cell[20684, 619, 125, 5, 20, "ListItem",
      CellTags->"4.4"],
    Cell[20812, 626, 130, 5, 20, "ListItem",
      CellTags->"4.4"],
    Cell[20945, 633, 125, 5, 20, "ListItem",
      CellTags->"4.4"],
    Cell[21073, 640, 108, 4, 24, "Text",
      CellTags->"4.4"],
    Cell[21184, 646, 146, 3, 50, "Input",
      CellTags->"4.4"],
    Cell[21333, 651, 73, 1, 24, "Text",
      CellTags->"4.4"],
    Cell[21409, 654, 238, 6, 76, "Input",
      CellTags->"4.4"],
    Cell[21650, 662, 275, 6, 52, "Text",
      CellTags->"4.4"],
    Cell[21928, 670, 1604, 33, 427, "Input",
      CellTags->"4.4"],
    Cell[23535, 705, 205, 5, 38, "Text",
      CellTags->"4.4"],
    Cell[23743, 712, 155, 3, 50, "Input",
      CellTags->"4.4"],
    Cell[23901, 717, 40, 1, 24, "Text",
      CellTags->"4.4"],
    Cell[23944, 720, 262, 7, 89, "Input",
      CellTags->"4.4"],
    Cell[24209, 729, 242, 6, 40, "Text",
      CellTags->"4.4"],
    Cell[24454, 737, 165, 3, 50, "Input",
      CellTags->"4.4"],
    Cell[24622, 742, 137, 4, 38, "Text",
      CellTags->"4.4"],
    Cell[24762, 748, 3152, 50, 830, "Input",
      CellTags->{"i:13", "4.4"}]},
  "i:10"->{
    Cell[7724, 222, 594, 13, 82, "Project",
      CellTags->{"i:10", "4.4"}]},
  "i:11"->{
    Cell[10922, 310, 1319, 24, 196, "Project",
      CellTags->{"i:11", "4.4"}]},
  "i:12"->{
    Cell[12244, 336, 627, 15, 70, "Text",
      CellTags->{"i:12", "4.4"}]},
  "i:13"->{
    Cell[24762, 748, 3152, 50, 830, "Input",
      CellTags->{"i:13", "4.4"}]},
  "4.5"->{
    Cell[27963, 804, 53, 1, 40, "Section",
      CellTags->"4.5"],
    Cell[28019, 807, 963, 19, 200, "Reference",
      CellTags->"4.5"]},
  "4.6"->{
    Cell[29019, 831, 66, 1, 40, "Section",
      CellTags->"4.6"],
    Cell[29110, 836, 65, 1, 40, "Subsection",
      CellTags->"4.6"],
    Cell[29178, 839, 4955, 72, 1324, "Input",
      CellTags->{"i:14", "4.6"}],
    Cell[34170, 916, 59, 1, 40, "Subsection",
      CellTags->"4.6"],
    Cell[34232, 919, 4019, 62, 1012, "Input",
      CellTags->{"i:15", "4.6"}]},
  "i:14"->{
    Cell[29178, 839, 4955, 72, 1324, "Input",
      CellTags->{"i:14", "4.6"}]},
  "i:15"->{
    Cell[34232, 919, 4019, 62, 1012, "Input",
      CellTags->{"i:15", "4.6"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"4.1", 40253, 1028},
  {"4.2", 40667, 1041},
  {"i:1", 41292, 1058},
  {"i:2", 41378, 1061},
  {"i:3", 41473, 1064},
  {"i:4", 41568, 1067},
  {"i:5", 41664, 1070},
  {"i:6", 41760, 1073},
  {"4.3", 41846, 1076},
  {"i:7", 41998, 1081},
  {"4.4", 42084, 1084},
  {"i:10", 46482, 1213},
  {"i:11", 46573, 1216},
  {"i:12", 46667, 1219},
  {"i:13", 46756, 1222},
  {"4.5", 46847, 1225},
  {"4.6", 46998, 1230},
  {"i:14", 47378, 1241},
  {"i:15", 47471, 1244}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"4.1"],
Cell[1777, 54, 58, 1, 153, "Title",
  CellTags->"4.1"],
Cell[1838, 57, 81, 1, 22, "Quote",
  CellTags->"4.1"],
Cell[1922, 60, 161, 6, 24, "QuoteAttribution",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[2108, 70, 55, 1, 40, "Section",
  CellTags->"4.1"],
Cell[2166, 73, 1455, 22, 250, "Text",
  CellTags->"4.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3658, 100, 168, 4, 76, "Section",
  CellTags->"4.2"],
Cell[3829, 106, 591, 12, 82, "Text",
  CellTags->{"i:1", "4.2"}],
Cell[4423, 120, 220, 5, 52, "Text",
  CellTags->"4.2"],
Cell[4646, 127, 294, 8, 38, "BulletListItem",
  CellTags->{"i:2", "4.2"}],
Cell[4943, 137, 293, 8, 38, "BulletListItem",
  CellTags->{"i:3", "4.2"}],
Cell[5239, 147, 531, 13, 50, "BulletListItem",
  CellTags->{"i:4", "4.2"}],
Cell[5773, 162, 493, 13, 50, "BulletListItem",
  CellTags->{"i:5", "4.2"}],
Cell[6269, 177, 481, 14, 58, "Note",
  CellTags->{"i:6", "4.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[6787, 196, 54, 1, 40, "Section",
  CellTags->"4.3"],
Cell[6844, 199, 769, 15, 96, "Text",
  CellTags->{"i:7", "4.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7650, 219, 71, 1, 40, "Section",
  CellTags->"4.4"],
Cell[7724, 222, 594, 13, 82, "Project",
  CellTags->{"i:10", "4.4"}],
Cell[8321, 237, 422, 10, 68, "Project",
  CellTags->"4.4"],
Cell[8746, 249, 820, 18, 232, "Input",
  CellTags->"4.4"],
Cell[9569, 269, 110, 4, 24, "Text",
  CellTags->"4.4"],
Cell[9682, 275, 581, 12, 96, "Project",
  CellTags->"4.4"],
Cell[10266, 289, 653, 19, 84, "Project",
  CellTags->"4.4"],
Cell[10922, 310, 1319, 24, 196, "Project",
  CellTags->{"i:11", "4.4"}],
Cell[12244, 336, 627, 15, 70, "Text",
  CellTags->{"i:12", "4.4"}],
Cell[12874, 353, 271, 8, 40, "Text",
  CellTags->"4.4"],
Cell[13148, 363, 140, 4, 38, "Text",
  CellTags->"4.4"],
Cell[13291, 369, 124, 3, 20, "ListItem",
  CellTags->"4.4"],
Cell[13418, 374, 114, 3, 20, "ListItem",
  CellTags->"4.4"],
Cell[13535, 379, 78, 1, 20, "ListItem",
  CellTags->"4.4"],
Cell[13616, 382, 236, 5, 52, "Text",
  CellTags->"4.4"],
Cell[13855, 389, 247, 10, 40, "Text",
  CellTags->"4.4"],
Cell[14105, 401, 158, 3, 50, "Input",
  CellTags->"4.4"],
Cell[14266, 406, 186, 5, 38, "Text",
  CellTags->"4.4"],
Cell[14455, 413, 268, 6, 48, "BulletListItem",
  CellTags->"4.4"],
Cell[14726, 421, 546, 10, 92, "BulletListItem",
  CellTags->"4.4"],
Cell[15275, 433, 320, 6, 62, "BulletListItem",
  CellTags->"4.4"],
Cell[15598, 441, 90, 1, 24, "Text",
  CellTags->"4.4"],

Cell[CellGroupData[{
Cell[15713, 446, 104, 2, 30, "Subsubsection",
  CellTags->"4.4"],
Cell[15820, 450, 189, 5, 38, "Text",
  CellTags->"4.4"],
Cell[16012, 457, 145, 4, 34, "BulletListItem",
  CellTags->"4.4"],
Cell[16160, 463, 105, 2, 20, "BulletListItem",
  CellTags->"4.4"],
Cell[16268, 467, 104, 2, 20, "BulletListItem",
  CellTags->"4.4"],
Cell[16375, 471, 108, 2, 20, "BulletListItem",
  CellTags->"4.4"],
Cell[16486, 475, 104, 2, 20, "BulletListItem",
  CellTags->"4.4"],
Cell[16593, 479, 189, 7, 22, "BulletListItem",
  CellTags->"4.4"],
Cell[16785, 488, 107, 2, 20, "BulletListItem",
  CellTags->"4.4"],
Cell[16895, 492, 590, 21, 70, "Text",
  CellTags->"4.4"],
Cell[17488, 515, 249, 6, 52, "Text",
  CellTags->"4.4"],
Cell[17740, 523, 445, 9, 82, "Text",
  CellTags->"4.4"],
Cell[18188, 534, 461, 8, 94, "Text",
  CellTags->"4.4"],
Cell[18652, 544, 177, 5, 38, "Text",
  CellTags->"4.4"],
Cell[18832, 551, 114, 3, 37, "Input",
  CellTags->"4.4"],
Cell[18949, 556, 40, 1, 24, "Text",
  CellTags->"4.4"],
Cell[18992, 559, 216, 6, 76, "Input",
  CellTags->"4.4"],
Cell[19211, 567, 69, 1, 24, "Text",
  CellTags->"4.4"],
Cell[19283, 570, 252, 6, 76, "Input",
  CellTags->"4.4"],
Cell[19538, 578, 154, 4, 38, "Text",
  CellTags->"4.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19729, 587, 120, 4, 30, "Subsubsection",
  CellTags->"4.4"],
Cell[19852, 593, 464, 8, 94, "Text",
  CellTags->"4.4"],
Cell[20319, 603, 153, 4, 38, "Text",
  CellTags->"4.4"],
Cell[20475, 609, 77, 1, 20, "ListItem",
  CellTags->"4.4"],
Cell[20555, 612, 126, 5, 20, "ListItem",
  CellTags->"4.4"],
Cell[20684, 619, 125, 5, 20, "ListItem",
  CellTags->"4.4"],
Cell[20812, 626, 130, 5, 20, "ListItem",
  CellTags->"4.4"],
Cell[20945, 633, 125, 5, 20, "ListItem",
  CellTags->"4.4"],
Cell[21073, 640, 108, 4, 24, "Text",
  CellTags->"4.4"],
Cell[21184, 646, 146, 3, 50, "Input",
  CellTags->"4.4"],
Cell[21333, 651, 73, 1, 24, "Text",
  CellTags->"4.4"],
Cell[21409, 654, 238, 6, 76, "Input",
  CellTags->"4.4"],
Cell[21650, 662, 275, 6, 52, "Text",
  CellTags->"4.4"],
Cell[21928, 670, 1604, 33, 427, "Input",
  CellTags->"4.4"],
Cell[23535, 705, 205, 5, 38, "Text",
  CellTags->"4.4"],
Cell[23743, 712, 155, 3, 50, "Input",
  CellTags->"4.4"],
Cell[23901, 717, 40, 1, 24, "Text",
  CellTags->"4.4"],
Cell[23944, 720, 262, 7, 89, "Input",
  CellTags->"4.4"],
Cell[24209, 729, 242, 6, 40, "Text",
  CellTags->"4.4"],
Cell[24454, 737, 165, 3, 50, "Input",
  CellTags->"4.4"],
Cell[24622, 742, 137, 4, 38, "Text",
  CellTags->"4.4"],
Cell[24762, 748, 3152, 50, 830, "Input",
  CellTags->{"i:13", "4.4"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27963, 804, 53, 1, 40, "Section",
  CellTags->"4.5"],
Cell[28019, 807, 963, 19, 200, "Reference",
  CellTags->"4.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29019, 831, 66, 1, 40, "Section",
  CellTags->"4.6"],

Cell[CellGroupData[{
Cell[29110, 836, 65, 1, 40, "Subsection",
  CellTags->"4.6"],
Cell[29178, 839, 4955, 72, 1324, "Input",
  CellTags->{"i:14", "4.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34170, 916, 59, 1, 40, "Subsection",
  CellTags->"4.6"],
Cell[34232, 919, 4019, 62, 1012, "Input",
  CellTags->{"i:15", "4.6"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

