(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33163,        886]*)
(*NotebookOutlinePosition[     42952,       1175]*)
(*  CellTagsIndexPosition[     42355,       1147]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5", "ChapterLine",
  CellTags->"5.1"],

Cell["Grouping and Conforming", "Title",
  CellTags->"5.1"],

Cell["\<\
\"I hate it! I hate having to go along with everything my friends \
say.\"\
\>", "Quote",
  CellTags->"5.1"],

Cell[TextData[{
  "\[LongDash]Molly Ringwald in ",
  StyleBox["The Breakfast Club",
    FontSlant->"Italic"],
  " (1985)"
}], "QuoteAttribution",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["5.1  Introduction", "Section",
  CellTags->"5.1"],

Cell[TextData[
"Many social and economic situations can be viewed, as we have done in \
previous chapters, as bilateral interactions between two individuals. \
However, other social phenomena can be better described in terms of \
interactions between an individual and a group of other people. (We are not \
discussing so-called group-level interactions between clusters of people but \
rather interactions between an individual and two or more other individuals). \
In this chapter, we look at several phenomena that result from this sort of \
individual\[Dash]group interaction, including neighborhood formation which \
can lead to voluntary segregation and local conformism which can result in \
the development of social norms and the spread of fads and fashions."], "Text",\

  CellTags->"5.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2  Forming Neighborhoods", "Section",
  CellTags->"5.2"],

Cell[TextData[{
  "A model for self-forming neighborhoods based on the desire of people to \
live with their ",
  StyleBox["own kind",
    FontSlant->"Italic"],
  " was proposed by Schelling [1978, 147\[Dash]53] in one of the first \
applications of computer simulation in social science. The Schelling model, \
which allows an individual who is not happy with the number of nearest \
neighbors who are like him, to move to the nearest empty site that has a \
sufficient number of similar nearest neighbors, demonstrated that spatial \
segregation, or ",
  StyleBox["ghettoization",
    FontSlant->"Italic"],
  ", occurs spontaneously, without being imposed by a central authority. It \
can result in the clustering of people by gender or age at a social gathering \
or in the clustering of people by ethnicity or race in society at large. "
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{
    "ghettoization", "", ""}, {"neighborhoods", "self-forming", ""}, {
    "Schelling", "", ""}, {"segretation", "", ""}}},
  CellTags->{"i:1", "5.2"}],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Because the Schelling model considers the movement of a person from where \
he is to be a result of his unhappiness with his neighbors, it is sometimes \
viewed as a model of an undesirable social phenomenon (fleeing). However, \
segregation, when it is voluntary, can have either positive or negative \
social and/or economic consequences [Durlauf 1997]. "
}], "Note",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{"fleeing", 
    "", ""}}},
  CellTags->{"i:2", "5.2"}],

Cell["\<\
Here we recast the Schelling model so that an individual can decide \
to move, rather than stay where he is because of a desire to be with \
individuals who have similar attributes.\
\>", "Text",
  CellTags->"5.2"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " We restrict movement to adjacent lattice sites here but in Chapter 6 we \
return to the Schelling model and allow nonlocal movements as well."
}], "Note",
  CellTags->"5.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3  Conforming", "Section",
  CellTags->"5.3"],

Cell["\<\
In the neighborhood model, each individual uses his list of \
attribute values to decide whether to stay or move. An alternative to moving \
away from people who do not have a sufficient number of shared attribute \
values is to adopt the attribute values of these people. Although fixed \
traits such as race and gender can't be changed, beliefs, including beliefs \
about people with certain fixed traits, can be changed. \
\>", "Text",
  CellTags->"5.3"],

Cell[TextData[{
  "Here, we let each individual change his meme value(s) based on the meme \
values of all of the individuals around him. This models the process of \
conforming, in which an individual tries to ",
  StyleBox["fit in ",
    FontSlant->"Italic"],
  "with the crowd. Conforming to a group and emulating a role model are both \
one-way value changes, however, they differ in that the latter involves \
interacting with a single individual and the former involves interacting with \
several other individuals. We look here at the change of meme values \
involving people who are spatial neighbors. In the next chapter, we examine \
meme changes involving people who form a",
  StyleBox[" social neighborhood ",
    FontSlant->"Italic"],
  "consisting of individuals who either share some common meme values, such \
as friends, or who are related to one another, but are not necessarily \
adjacent to one another spatially. "
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:5", "IndexEntries" -> {{
    "comforming to a group", "", ""}, {"role model", "emulating a", ""}}},
  CellTags->{"i:5", "5.3"}],

Cell["\<\
On each time step in our model, every individual randomly chooses a \
meme value to change and then changes it to a value lying between its current \
value and the average value of that meme amongst its neighbors. \
\>", "Text",\

  CellTags->"5.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4  Social Norms, Fads, and Fashions", "Section",
  CellTags->"5.4"],

Cell["\<\
Social norms are commonly defined in terms of expectations, values, \
or behavior [Axelrod 1986]. The main characteristic of a social norm is that \
it involves agreement or consensus amongst a large number of individuals in a \
group without the intervention of a central authority.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:8", "IndexEntries" -> {{
    "social norms", "", ""}}},
  CellTags->{"i:8", "5.4"}],

Cell["\<\
Robert Axelrod [1986] has suggested several mechanisms that can \
give rise to and maintain a social norm, including membership which works by \
enabling like-minded individuals to interact with one another and excluding \
individuals who are not like-minded through a self-selection process (see \
Durlauf [1997] for some interesting ideas on membership and neighborhood). \
This process is evident in the preceding simulations.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:9", "IndexEntries" -> {{
    "membership", "", ""}}},
  CellTags->{"i:9", "5.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5  Computer Simulation Projects", "Section",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "Schelling [1978] found that two modifications of his basic voluntary \
segregation model result in a close packing of the population of one type of \
person whereas the population of the other type of person is more spread out. \
The criteria were: (1) the requirement used by one type of person for being \
happy with his neighbors differs from the requirement used by another type of \
person for being happy with his neighbors, or (2) the population of one type \
of person is in the minority with respect to the population of the other type \
of person. Implement these two variations of the Schelling model into the \
neighborhood model and observe the behaviors of these variants."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:10", "IndexEntries" -> {{
    "Schelling", "", ""}, {"segregation", "voluntary", ""}}},
  CellTags->{"i:10", "5.5"}],

Cell[TextData[{
  StyleBox["2",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "Mobility is incorporated into the conforming model in this chapter. Modify \
the program so that individuals are immobile. Run the simulation and compare \
the result to that obtained when mobility is included. Look to see if there \
is a difference in the rate at which uniform values spread throughout the \
population."
}], "Project",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["3",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "Alter the conforming model so that the probability of an individual \
conforming is greater, the more the person differs from his neighbors. \
Observe the effect of this modification."
}], "Project",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["4",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontWeight->"Bold"],
  "In the model of conforming in this chapter, each individual randomly \
chooses a meme value to bring into line with the average value of that meme \
amongst his neighbors. It might be more effective as a means of gaining \
acceptance to attempt to determine which meme is most important to the \
neighbors and then change the value of that meme."
}], "Project",
  CellTags->"5.5"],

Cell["\<\
Various criteria can be used to determine which meme is most \
important to the group. One indication of this might be that the more central \
a meme is to a group, the less its value will vary amongst the members. We \
can find the meme whose value varies least amongst the neighbors of an \
individual by summing the squares of the pairwise differences of all of the \
neighbors' values for each meme and taking the meme that returns the lowest \
value (e.g., if all of the neighbors agree on a particular meme, this sum \
will be zero). The computation for this is performed as follows.\
\>", "Text",\

  CellTags->"5.5"],

Cell[TextData[{
  "We first form a list comprised of lists containing the values of the \
corresponding meme for each person in the neighborhood (e.g., the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "th list will have all of the values of the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "th meme in the neighborhood) using"
}], "Text",
  CellTags->"5.5"],

Cell["Transpose[Transpose[DeleteCases[lis, 0]][[2]]]", "Input",
  CellTags->"5.5"],

Cell["\<\
We then determine the sum of the pairwise differences among the \
meme values in each of these lists using\
\>", "Text",
  CellTags->"5.5"],

Cell["\<\
Map[Apply[Plus, Flatten[Outer[Subtract, #, #]]^2]&,
            Transpose[Transpose[DeleteCases[lis, 0]][[2]]]]\
\>", "Input",
  CellTags->"5.5"],

Cell[TextData[{
  "We can illustrate how this operation works for a single list of meme \
values, {",
  StyleBox["a", "IT"],
  ", ",
  StyleBox["b", "IT"],
  ", ",
  StyleBox["c", "IT"],
  "}. (This might be the list of the values of the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "th meme amongst the three people in the neighborhood around an individual; \
we use symbols rather than numerical values to make the explanation \
clearer.)"
}], "Text",
  CellTags->"5.5"],

Cell[CellGroupData[{

Cell["Flatten[Outer[Subtract, #, #]^2]&[{a, b, c}]", "Input",
  CellTags->"5.5"],

Cell[BoxData[
    \({0, \((a - b)\)\^2, \((a - c)\)\^2, \((\(-a\) + b)\)\^2, 0, 
      \((b - c)\)\^2, \((\(-a\) + c)\)\^2, \((\(-b\) + c)\)\^2, 0}\)], 
  "Output",
  CellTags->"5.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply[Plus, Flatten[Outer[Subtract, #, #]^2]&[{a, b, c}]]", "Input",
  CellTags->"5.5"],

Cell[BoxData[
    \(\((a - b)\)\^2 + \((\(-a\) + b)\)\^2 + \((a - c)\)\^2 + 
      \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 + \((\(-b\) + c)\)\^2\)], "Output",\

  CellTags->"5.5"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " This computation actually returns twice the sum of the ",
  StyleBox["difference-squared",
    FontSlant->"Italic"],
  " values which does not affect its usefulness for determining which meme \
has the smallest square distance value."
}], "Note",
  CellTags->"5.5"],

Cell["\<\
We can write these operations into a one-liner function \
definition\
\>", "Text",
  CellTags->"5.5"],

Cell["\<\
memeValueVariations[lis_] :=
  Map[Apply[Plus, Flatten[Outer[Subtract, #, #]]^2]&,
            Transpose[Transpose[DeleteCases[lis, 0]][[2]]]]\
\>", "Input",
  CellTags->"5.5"],

Cell["\<\
Finally, to determine which meme has the minimum difference-squared \
value, we take\
\>", "Text",
  CellTags->"5.5"],

Cell["Flatten[Position[#, Min[#]]]&[memeValueVariations[lis]]", "Input",
  CellTags->"5.5"],

Cell["\<\
which returns a list of the location(s) of the meme(s) that have \
the smallest difference-squared value (i.e., a return of {1, 3} indicates \
that the first and third memes both have the smallest difference-squared \
value). In the case where more than one meme has the same smallest \
difference-squared value, we randomly choose which meme to change by applying \
the anonymous function\
\>", "Text",
  CellTags->"5.5"],

Cell["#[[Random[Integer, {1, Length[#]}]]]&", "Input",
  CellTags->"5.5"],

Cell[" to the list of locations so that overall we have", "Text",
  CellTags->"5.5"],

Cell["\<\
#[[Random[Integer, {1, Length[#]}]]]&[
  Flatten[Position[#, Min[#]]]&[memeValueVariations[lis]]]\
\>", "Input",
  CellTags->"5.5"],

Cell["\<\
Finally, we can incorporate this calculation into the conform \
program by replacing the third change rule\
\>", "Text",
  CellTags->"5.5"],

Cell["\<\
change[{a_, y_}, res__] :=
  Module[{r = Random[Integer, {1, s}]},
    {a, ReplacePart[y,
         Random[Integer, {y[[r]], memeAvg[{res}, r]}], r]}]\
\>", "Input",
  CellTags->"5.5"],

Cell["with the memeValueVariations definition and the change rule", "Text",
  CellTags->"5.5"],

Cell["\<\
memeValueVariations[lis_] :=
  Map[Apply[Plus, Flatten[Outer[Subtract, #, #]]^2]&,
            Transpose[Transpose[DeleteCases[lis, 0]][[2]]]]\
\>", "Input",
  CellTags->"5.5"],

Cell["\<\
change[{a_, y_}, res__] := Module[{r},
  r = #[[Random[Integer, {1, Length[#]}]]]&[
      Flatten[Position[#, Min[#]]]&[
      memeValueVariations[{res}]]];
  {a, ReplacePart[y,
         Random[Integer, {y[[r]], memeAvg[{res}, r]}], r]}]\
\>", "Input",
  CellTags->"5.5"],

Cell["\<\
Write the program for this model and compare the results it \
produces with the results obtained with the conform program.\
\>", "Text",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["5",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " The conform model combines the neighborhood model with a group average \
mechanism of individual meme change. One alternative to this is to use a \
pairwise meme exchange mechanism, as discussed in Chapter 2, with the \
neighborhood model. This can be done by incorporating the decide rules, \
exchange rules, and vonNeumann function from Chapter 2 into the neighborhood \
program, and by changing the first argument of the NestList operation to the \
following."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{"memes", 
    "spreading", ""}}},
  CellTags->{"i:11", "5.5"}],

Cell["\<\
GN[walk, Moore[movestay,
             vonNeumann[exchange, vonNeumann[decide, #]]]]&\
\>", "Input",
  CellTags->"5.5"],

Cell["\<\
Carry out this modification, run the modified program, and compare \
the results obtained to the results of the conform model.\
\>", "Text",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["6",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " One model for the spread of ideas, fads, or fashions is suggested by the \
results of the role of social status described in Chapter 4: randomly assign \
social status values to individuals in the population. Randomly change one of \
the meme values of the individual in society with the highest social status. \
Then allow the new meme value to spread by changing, in each time step, the \
corresponding meme of the neighboring individual(s) with the highest social \
status to have the same value. Run this simulation to see the effect of the \
spread (or diffusion) of a meme value from the highest social status \
individuals to the individuals with the lowest social status. "
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:11", "IndexEntries" -> {{"memes", 
    "spreading", ""}}},
  CellTags->{"i:11", "5.5"}],

Cell[TextData[{
  StyleBox["7",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Another model for the spread of fads and fashion based on social status \
would average over neighborhood meme values by weighting the meme value of a \
higher status individual more than the meme value of a lower status \
individual. Implement this idea into a program and see what behavior it shows \
over time."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:12", "IndexEntries" -> {{"fads", "", 
    ""}, {"fashions", "", ""}, {"social status", "", ""}}},
  CellTags->{"i:12", "5.5"}],

Cell[TextData[{
  StyleBox["8",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Suppose that social status is endogeneous, either increasing or \
decreasing as an individual becomes more like his neighbors. Run a simulation \
that incorporates this idea and see how the results differ for these two \
cases."
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:13", "IndexEntries" -> {{
    "social status", "endogeneous", ""}}},
  CellTags->{"i:13", "5.5"}],

Cell[TextData[{
  StyleBox["9",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Axelrod [1986] has developed a behavioral-based model of social norms \
using the following definition: \"a norm exists in a given social setting to \
the extent that individuals usually act in a certain way and are often \
punished when seen not to be acting in this way.\" In his model, individuals \
are either good or bad. If an individual is good, neither he nor anyone else \
in the society gets anything. If an individual is bad, he receives a positive \
payoff ",
  StyleBox["T", "IT"],
  " (standing for the temptation to be bad) and all of the other individuals \
in the society receive a negative payoff ",
  StyleBox["H", "IT"],
  " (standing for being hurt by the bad behavior). If an individual does \
behave badly, he is observed with a chance ",
  StyleBox["S", "IT"],
  " (standing for being seen) by some of the other individuals. These \
individuals may impose a negative payoff ",
  StyleBox["P", "IT"],
  " (standing for penalty) on the bad guy while they receive a negative \
payoff ",
  StyleBox["E", "IT"],
  " (standing for the cost of enforcement) to themselves. "
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:14", "IndexEntries" -> {{"Axelrod", 
    "", ""}}},
  CellTags->{"i:14", "5.5"}],

Cell[TextData[{
  "Each individual in the society has two attributes, boldness ",
  StyleBox["B", "IT"],
  " and vengefulness ",
  StyleBox["V", "IT"],
  " which are both real numbers between 0 and 1 [for computational purposes, \
each individual is assigned ",
  StyleBox["B", "IT"],
  " and ",
  StyleBox["V", "IT"],
  " values, each randomly chosen from eight possible values (0/7, 1/7, 2/7, \
3/7, 4/7, 5/7, 6/7, 7/7)]."
}], "Text",
  CellTags->"5.5"],

Cell["\<\
The following processes occur on each time step (with the resulting \
payoffs described previously).\
\>", "Text",
  CellTags->"5.5"],

Cell[TextData[{
  "A value of ",
  StyleBox["S", "IT"],
  " is chosen for each individual from a uniform distribution between 0 and \
1, and an individual is bad whenever his ",
  StyleBox["B", "IT"],
  " value is equal to or greater than ",
  StyleBox["S", "IT"],
  " (i.e., whenever the chance of being seen by someone is less than the \
individual's boldness). "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual sees a bad individual (except the bad guy himself) with \
probability ",
  StyleBox["S", "IT"],
  ". "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual who sees the defection punishes the defector with \
probability ",
  StyleBox["V", "IT"],
  " (i.e., the more vengeful an individual is, the more likely he is to \
punish someone he sees being bad). "
}], "BulletListItem",
  CellTags->"5.5"],

Cell["Implement this model.", "Text",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["10.",
    FontWeight->"Bold"],
  " The main shortcoming of the Axelrod model was anticipated by John Maynard \
Smith [1982] who concludes his book with the following statement (enclosed \
[...] words are added for clarification). \"A group of individuals can agree \
not to [be bad] and to punish any member of the group who does [behave \
badly]. That, by itself, is not sufficient to guarantee [maintenance of the \
social norm] because the act of punishing is presumably costly and therefore \
individuals would be tempted to accept the benefits of [agreeing not to be \
bad] but not the costs of enforcing it [by punishing bad guys].\" Smith \
offered a solution to this problem, suggesting that \"[maintenance of the \
social norm] requires that refusal by an individual to participate in \
enforcing the [agreement] should also be regarded as a breach which will be \
punished.\""
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:15", "IndexEntries" -> {{
    "Smith, John Maynard", "", ""}}},
  CellTags->{"i:15", "5.5"}],

Cell[TextData[{
  "This mechanism was adopted by Axelrod [1986] who refers to it as a ",
  StyleBox["metanorm",
    FontSlant->"Italic"],
  ". His metanorm model works as follows."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:16", "IndexEntries" -> {{"metanorm", 
    "", ""}}},
  CellTags->{"i:16", "5.5"}],

Cell[TextData[{
  "A value of ",
  StyleBox["S", "IT"],
  " is chosen for each individual from a uniform distribution between 0 and \
1, and an individual behaves badly whenever his ",
  StyleBox["B", "IT"],
  " value is equal to or greater than ",
  StyleBox["S", "IT"],
  " (i.e., whenever the chance of being seen by someone is less than the \
individual's boldness). "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual sees a person being bad (except the bad guy himself) with \
probability ",
  StyleBox["S", "IT"],
  ". "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual who sees the bad behavior punishes the bad guy with \
probability ",
  StyleBox["V", "IT"],
  " (i.e., the more vengeful an individual is, the more likely he is to \
punish someone he sees being bad). "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual sees a nonpunishing individual (except the nonpunisher) \
with probability ",
  StyleBox["S", "IT"],
  ". "
}], "BulletListItem",
  CellTags->"5.5"],

Cell[TextData[{
  "Each individual who sees the nonpunishment punishes the nonpunisher with \
probability ",
  StyleBox["V", "IT"],
  "."
}], "BulletListItem",
  CellTags->"5.5"],

Cell["Implement this model.", "Text",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " The problem with the metanorm model of vengefulness against nonpunishers \
is that it often does not seem to work in the real world. For example, even \
the presence of a central authority to enforce the punishment of nonenforcers \
often fails to prevent the tolerance of bad behavior by others. This is \
evidenced by the frequent occurrence of cheating scandals in schools, \
including those that have an honor code in which not only cheaters but people \
who fail to report cheaters are punished. The prime reason for the failure of \
metanorms to work is that they fail to account for the penalty, often in the \
form of social ostracism, imposed on so-called squealers, within a group."
}], "Note",
  CellTags->"5.5"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Alternative means of maintaining a social norm, in addition to \
membership, have been suggested [Axelrod 1986; Tierney 1997], including the \
development of a social conscience [Frank 1987] and social ostracism. These \
mechanisms can be simulated using the ideas presented in Chapter 3."
}], "Note",
  TaggingRules:>{"IndexingCellTag" -> "i:17", "IndexEntries" -> {{
    "membership", "", ""}, {"social conscience", "", ""}, {
    "social ostracism", "", ""}}},
  CellTags->{"i:17", "5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.6  References", "Section",
  CellTags->"5.6"],

Cell[TextData[{
  "Axelrod, Robert. 1986. \"An Evolutionary Approach to Norms.\" ",
  StyleBox["American Political Science Review",
    FontSlant->"Italic"],
  " 80: 1095\[Dash]1111.",
  "\n",
  "Durlauf, Steven N. 1997. \"The Memberships Theory of Inequality: Ideas and \
Implications.\" Sante Fe Institute Working Papers No. 97-05-047. Abstract.",
  "\n",
  "Frank, Robert H. 1987. \"If ",
  StyleBox["Homo Economicus",
    FontSlant->"Italic"],
  " Could Choose His Own Utility Function, Would He Want One with a \
Conscience?\" ",
  StyleBox["American Economic Review",
    FontSlant->"Italic"],
  " 77: 593\[Dash]604.",
  "\n",
  "Schelling, Thomas C. 1978. ",
  StyleBox["Micromotives and Macrobehavior",
    FontSlant->"Italic"],
  ". New York: W. W. Norton.",
  "\n",
  "Smith, John Maynard. 1982. ",
  StyleBox["Evolution and The Theory of Games",
    FontSlant->"Italic"],
  ". New York: Cambridge University Press, 173.",
  "\n",
  "Tierney, John. 1997. \"The Boor War.\" ",
  StyleBox["The New York Times Magazine",
    FontSlant->"Italic"],
  ", 5 January [includes statements attributed to Robert Axelrod]."
}], "Reference",
  TaggingRules:>{"IndexingCellTag" -> "i:18", "IndexEntries" -> {{
    "Frank, Robert H.", "", ""}}},
  CellTags->{"i:18", "5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.7  Programs in the Chapter", "Section",
  CellTags->"5.7"],

Cell[CellGroupData[{

Cell["5.7.1  neighborhood", "Subsection",
  CellTags->"5.7"],

Cell[TextData[
"neighborhood[n_, p_, v_, w_, t_] := \nModule[{walk, movestay, society, RND, \
Moore, GN},\n  RND := Random[Integer, {1, 4}];\n  society = Table[Floor[p + \
Random[]], {n}, {n}] /. \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, w}], {v}]};\n  movestay[0, __] := 0;\n  \
movestay[{a_, b_}, res__] := \n    {a * Round[1 - Count[Map[Count[b - #[[2]], \
0]&, \n       {res} /. 0 \[Rule] {0, 0}], _?(# >= v / 2 &)] / 8.], b};\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestList[GN[walk, Moore[movestay, #]]&, society,t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:4", "IndexEntries" -> {{
    "neighborhood", "", ""}}},
  CellTags->{"i:4", "5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.7.2  conform", "Subsection",
  CellTags->"5.7"],

Cell[TextData[
"conform[n_, p_, s_, m_, t_] := \nModule[{change, movestay, walk, society, \
RND, Moore, GN},   \n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.  \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, m}], {s}]};\n  memeAvg[lis_, r_] := \n    \
(Apply[Plus, Map[#[[2, r]]&, #]]/Length[#])&[\n                               \
      DeleteCases[lis, 0]];\n  change[0, _, _, _, _, _, _, _, _] := 0;\n  \
change[z_, 0, 0, 0, 0, 0, 0, 0, 0] := z;\n  change[{a_, y_}, res__] :=\n    \
Module[{r = Random[Integer, {1, s}]},\n    {a, ReplacePart[y,\n       \
Random[Integer, {y[[r]], memeAvg[{res}, r]}], r]}];\n  movestay[0, __] := 0;\n\
  movestay[{a_, b_}, res__] := \n    {a * Round[1 - Count[Map[Count[b - \
#[[2]], 0]&,\n       {res} /. 0 \[Rule] {0, 0}], _?(# >= s / 2 &)] / 8.], b};\
\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestList[GN[walk,\n         Moore[movestay, Moore[change, #]]]&, society, \
t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:7", "IndexEntries" -> {{"conform", 
    "", ""}}},
  CellTags->{"i:7", "5.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "5. Grouping and Conforming"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 21, "IndexEntries" -> {{"i:1", 
  "ghettoization", "", ""}, {"i:1", "neighborhoods", "self-forming", ""}, {
  "i:1", "Schelling", "", ""}, {"i:1", "segretation", "", ""}, {"i:2", 
  "fleeing", "", ""}, {"i:5", "comforming to a group", "", ""}, {"i:5", 
  "role model", "emulating a", ""}, {"i:8", "social norms", "", ""}, {"i:9", 
  "membership", "", ""}, {"i:10", "Schelling", "", ""}, {"i:10", 
  "segregation", "voluntary", ""}, {"i:11", "memes", "spreading", ""}, {
  "i:11", "memes", "spreading", ""}, {"i:12", "fads", "", ""}, {"i:12", 
  "fashions", "", ""}, {"i:12", "social status", "", ""}, {"i:13", 
  "social status", "endogeneous", ""}, {"i:14", "Axelrod", "", ""}, {"i:15", 
  "Smith, John Maynard", "", ""}, {"i:16", "metanorm", "", ""}, {"i:17", 
  "membership", "", ""}, {"i:17", "social conscience", "", ""}, {"i:17", 
  "social ostracism", "", ""}, {"i:18", "Frank, Robert H.", "", ""}, {"i:4", 
  "neighborhood", "", ""}, {"i:7", "conform", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@E2X000000000006T<01T1T00000000000
00000000003oo`@J3f3oo`02Da@00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "5.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"5.1"],
    Cell[1777, 54, 59, 1, 153, "Title",
      CellTags->"5.1"],
    Cell[1839, 57, 118, 4, 22, "Quote",
      CellTags->"5.1"],
    Cell[1960, 63, 164, 6, 24, "QuoteAttribution",
      CellTags->"5.1"],
    Cell[2149, 73, 55, 1, 40, "Section",
      CellTags->"5.1"],
    Cell[2207, 76, 799, 12, 150, "Text",
      CellTags->"5.1"]},
  "5.2"->{
    Cell[3043, 93, 64, 1, 40, "Section",
      CellTags->"5.2"],
    Cell[3110, 96, 1071, 20, 154, "Text",
      CellTags->{"i:1", "5.2"}],
    Cell[4184, 118, 554, 11, 82, "Note",
      CellTags->{"i:2", "5.2"}],
    Cell[4741, 131, 224, 5, 52, "Text",
      CellTags->"5.2"],
    Cell[4968, 138, 238, 6, 40, "Note",
      CellTags->"5.2"]},
  "i:1"->{
    Cell[3110, 96, 1071, 20, 154, "Text",
      CellTags->{"i:1", "5.2"}]},
  "i:2"->{
    Cell[4184, 118, 554, 11, 82, "Note",
      CellTags->{"i:2", "5.2"}]},
  "5.3"->{
    Cell[5243, 149, 53, 1, 40, "Section",
      CellTags->"5.3"],
    Cell[5299, 152, 467, 8, 94, "Text",
      CellTags->"5.3"],
    Cell[5769, 162, 1117, 20, 168, "Text",
      CellTags->{"i:5", "5.3"}],
    Cell[6889, 184, 259, 6, 52, "Text",
      CellTags->"5.3"]},
  "i:5"->{
    Cell[5769, 162, 1117, 20, 168, "Text",
      CellTags->{"i:5", "5.3"}]},
  "5.4"->{
    Cell[7185, 195, 75, 1, 40, "Section",
      CellTags->"5.4"],
    Cell[7263, 198, 432, 8, 66, "Text",
      CellTags->{"i:8", "5.4"}],
    Cell[7698, 208, 576, 10, 94, "Text",
      CellTags->{"i:9", "5.4"}]},
  "i:8"->{
    Cell[7263, 198, 432, 8, 66, "Text",
      CellTags->{"i:8", "5.4"}]},
  "i:9"->{
    Cell[7698, 208, 576, 10, 94, "Text",
      CellTags->{"i:9", "5.4"}]},
  "5.5"->{
    Cell[8311, 223, 71, 1, 40, "Section",
      CellTags->"5.5"],
    Cell[8385, 226, 962, 17, 138, "Project",
      CellTags->{"i:10", "5.5"}],
    Cell[9350, 245, 458, 11, 68, "Project",
      CellTags->"5.5"],
    Cell[9811, 258, 320, 9, 54, "Project",
      CellTags->"5.5"],
    Cell[10134, 269, 482, 11, 82, "Project",
      CellTags->"5.5"],
    Cell[10619, 282, 634, 11, 122, "Text",
      CellTags->"5.5"],
    Cell[11256, 295, 361, 10, 56, "Text",
      CellTags->"5.5"],
    Cell[11620, 307, 82, 1, 37, "Input",
      CellTags->"5.5"],
    Cell[11705, 310, 149, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[11857, 316, 155, 4, 50, "Input",
      CellTags->"5.5"],
    Cell[12015, 322, 474, 15, 70, "Text",
      CellTags->"5.5"],
    Cell[12514, 341, 80, 1, 37, "Input",
      CellTags->"5.5"],
    Cell[12597, 344, 183, 4, 38, "Output",
      CellTags->"5.5"],
    Cell[12817, 353, 93, 1, 37, "Input",
      CellTags->"5.5"],
    Cell[12913, 356, 176, 4, 38, "Output",
      CellTags->"5.5"],
    Cell[13104, 363, 330, 9, 54, "Note",
      CellTags->"5.5"],
    Cell[13437, 374, 111, 4, 24, "Text",
      CellTags->"5.5"],
    Cell[13551, 380, 186, 5, 63, "Input",
      CellTags->"5.5"],
    Cell[13740, 387, 127, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[13870, 393, 91, 1, 37, "Input",
      CellTags->"5.5"],
    Cell[13964, 396, 432, 8, 80, "Text",
      CellTags->"5.5"],
    Cell[14399, 406, 73, 1, 37, "Input",
      CellTags->"5.5"],
    Cell[14475, 409, 84, 1, 24, "Text",
      CellTags->"5.5"],
    Cell[14562, 412, 141, 4, 50, "Input",
      CellTags->"5.5"],
    Cell[14706, 418, 149, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[14858, 424, 193, 6, 76, "Input",
      CellTags->"5.5"],
    Cell[15054, 432, 94, 1, 24, "Text",
      CellTags->"5.5"],
    Cell[15151, 435, 186, 5, 63, "Input",
      CellTags->"5.5"],
    Cell[15340, 442, 281, 8, 102, "Input",
      CellTags->"5.5"],
    Cell[15624, 452, 165, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[15792, 458, 709, 15, 110, "Project",
      CellTags->{"i:11", "5.5"}],
    Cell[16504, 475, 128, 4, 50, "Input",
      CellTags->"5.5"],
    Cell[16635, 481, 169, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[16807, 487, 927, 17, 138, "Project",
      CellTags->{"i:11", "5.5"}],
    Cell[17737, 506, 599, 13, 68, "Project",
      CellTags->{"i:12", "5.5"}],
    Cell[18339, 521, 484, 12, 54, "Project",
      CellTags->{"i:13", "5.5"}],
    Cell[18826, 535, 1329, 29, 190, "Project",
      CellTags->{"i:14", "5.5"}],
    Cell[20158, 566, 455, 13, 70, "Text",
      CellTags->"5.5"],
    Cell[20616, 581, 143, 4, 38, "Text",
      CellTags->"5.5"],
    Cell[20762, 587, 406, 11, 68, "BulletListItem",
      CellTags->"5.5"],
    Cell[21171, 600, 178, 6, 36, "BulletListItem",
      CellTags->"5.5"],
    Cell[21352, 608, 276, 7, 52, "BulletListItem",
      CellTags->"5.5"],
    Cell[21631, 617, 56, 1, 24, "Text",
      CellTags->"5.5"],
    Cell[21690, 620, 1063, 18, 166, "Project",
      CellTags->{"i:15", "5.5"}],
    Cell[22756, 640, 315, 8, 40, "Text",
      CellTags->{"i:16", "5.5"}],
    Cell[23074, 650, 413, 11, 68, "BulletListItem",
      CellTags->"5.5"],
    Cell[23490, 663, 180, 6, 36, "BulletListItem",
      CellTags->"5.5"],
    Cell[23673, 671, 278, 7, 50, "BulletListItem",
      CellTags->"5.5"],
    Cell[23954, 680, 183, 6, 36, "BulletListItem",
      CellTags->"5.5"],
    Cell[24140, 688, 178, 6, 36, "BulletListItem",
      CellTags->"5.5"],
    Cell[24321, 696, 56, 1, 24, "Text",
      CellTags->"5.5"],
    Cell[24380, 699, 788, 13, 138, "Note",
      CellTags->"5.5"],
    Cell[25171, 714, 557, 11, 68, "Note",
      CellTags->{"i:17", "5.5"}]},
  "i:10"->{
    Cell[8385, 226, 962, 17, 138, "Project",
      CellTags->{"i:10", "5.5"}]},
  "i:11"->{
    Cell[15792, 458, 709, 15, 110, "Project",
      CellTags->{"i:11", "5.5"}],
    Cell[16807, 487, 927, 17, 138, "Project",
      CellTags->{"i:11", "5.5"}]},
  "i:12"->{
    Cell[17737, 506, 599, 13, 68, "Project",
      CellTags->{"i:12", "5.5"}]},
  "i:13"->{
    Cell[18339, 521, 484, 12, 54, "Project",
      CellTags->{"i:13", "5.5"}]},
  "i:14"->{
    Cell[18826, 535, 1329, 29, 190, "Project",
      CellTags->{"i:14", "5.5"}]},
  "i:15"->{
    Cell[21690, 620, 1063, 18, 166, "Project",
      CellTags->{"i:15", "5.5"}]},
  "i:16"->{
    Cell[22756, 640, 315, 8, 40, "Text",
      CellTags->{"i:16", "5.5"}]},
  "i:17"->{
    Cell[25171, 714, 557, 11, 68, "Note",
      CellTags->{"i:17", "5.5"}]},
  "5.6"->{
    Cell[25765, 730, 53, 1, 40, "Section",
      CellTags->"5.6"],
    Cell[25821, 733, 1269, 35, 206, "Reference",
      CellTags->{"i:18", "5.6"}]},
  "i:18"->{
    Cell[25821, 733, 1269, 35, 206, "Reference",
      CellTags->{"i:18", "5.6"}]},
  "5.7"->{
    Cell[27127, 773, 66, 1, 40, "Section",
      CellTags->"5.7"],
    Cell[27218, 778, 60, 1, 40, "Subsection",
      CellTags->"5.7"],
    Cell[27281, 781, 2664, 43, 635, "Input",
      CellTags->{"i:4", "5.7"}],
    Cell[29982, 829, 55, 1, 40, "Subsection",
      CellTags->"5.7"],
    Cell[30040, 832, 3083, 49, 765, "Input",
      CellTags->{"i:7", "5.7"}]},
  "i:4"->{
    Cell[27281, 781, 2664, 43, 635, "Input",
      CellTags->{"i:4", "5.7"}]},
  "i:7"->{
    Cell[30040, 832, 3083, 49, 765, "Input",
      CellTags->{"i:7", "5.7"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"5.1", 35318, 930},
  {"5.2", 35732, 943},
  {"i:1", 36086, 954},
  {"i:2", 36173, 957},
  {"5.3", 36259, 960},
  {"i:5", 36541, 969},
  {"5.4", 36629, 972},
  {"i:8", 36854, 979},
  {"i:9", 36939, 982},
  {"5.5", 37025, 985},
  {"i:10", 40715, 1092},
  {"i:11", 40807, 1095},
  {"i:12", 40980, 1100},
  {"i:13", 41072, 1103},
  {"i:14", 41164, 1106},
  {"i:15", 41258, 1109},
  {"i:16", 41352, 1112},
  {"i:17", 41440, 1115},
  {"5.6", 41528, 1118},
  {"i:18", 41691, 1123},
  {"5.7", 41786, 1126},
  {"i:4", 42161, 1137},
  {"i:7", 42251, 1140}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"5.1"],
Cell[1777, 54, 59, 1, 153, "Title",
  CellTags->"5.1"],
Cell[1839, 57, 118, 4, 22, "Quote",
  CellTags->"5.1"],
Cell[1960, 63, 164, 6, 24, "QuoteAttribution",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[2149, 73, 55, 1, 40, "Section",
  CellTags->"5.1"],
Cell[2207, 76, 799, 12, 150, "Text",
  CellTags->"5.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3043, 93, 64, 1, 40, "Section",
  CellTags->"5.2"],
Cell[3110, 96, 1071, 20, 154, "Text",
  CellTags->{"i:1", "5.2"}],
Cell[4184, 118, 554, 11, 82, "Note",
  CellTags->{"i:2", "5.2"}],
Cell[4741, 131, 224, 5, 52, "Text",
  CellTags->"5.2"],
Cell[4968, 138, 238, 6, 40, "Note",
  CellTags->"5.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5243, 149, 53, 1, 40, "Section",
  CellTags->"5.3"],
Cell[5299, 152, 467, 8, 94, "Text",
  CellTags->"5.3"],
Cell[5769, 162, 1117, 20, 168, "Text",
  CellTags->{"i:5", "5.3"}],
Cell[6889, 184, 259, 6, 52, "Text",
  CellTags->"5.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7185, 195, 75, 1, 40, "Section",
  CellTags->"5.4"],
Cell[7263, 198, 432, 8, 66, "Text",
  CellTags->{"i:8", "5.4"}],
Cell[7698, 208, 576, 10, 94, "Text",
  CellTags->{"i:9", "5.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8311, 223, 71, 1, 40, "Section",
  CellTags->"5.5"],
Cell[8385, 226, 962, 17, 138, "Project",
  CellTags->{"i:10", "5.5"}],
Cell[9350, 245, 458, 11, 68, "Project",
  CellTags->"5.5"],
Cell[9811, 258, 320, 9, 54, "Project",
  CellTags->"5.5"],
Cell[10134, 269, 482, 11, 82, "Project",
  CellTags->"5.5"],
Cell[10619, 282, 634, 11, 122, "Text",
  CellTags->"5.5"],
Cell[11256, 295, 361, 10, 56, "Text",
  CellTags->"5.5"],
Cell[11620, 307, 82, 1, 37, "Input",
  CellTags->"5.5"],
Cell[11705, 310, 149, 4, 38, "Text",
  CellTags->"5.5"],
Cell[11857, 316, 155, 4, 50, "Input",
  CellTags->"5.5"],
Cell[12015, 322, 474, 15, 70, "Text",
  CellTags->"5.5"],

Cell[CellGroupData[{
Cell[12514, 341, 80, 1, 37, "Input",
  CellTags->"5.5"],
Cell[12597, 344, 183, 4, 38, "Output",
  CellTags->"5.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12817, 353, 93, 1, 37, "Input",
  CellTags->"5.5"],
Cell[12913, 356, 176, 4, 38, "Output",
  CellTags->"5.5"]
}, Open  ]],
Cell[13104, 363, 330, 9, 54, "Note",
  CellTags->"5.5"],
Cell[13437, 374, 111, 4, 24, "Text",
  CellTags->"5.5"],
Cell[13551, 380, 186, 5, 63, "Input",
  CellTags->"5.5"],
Cell[13740, 387, 127, 4, 38, "Text",
  CellTags->"5.5"],
Cell[13870, 393, 91, 1, 37, "Input",
  CellTags->"5.5"],
Cell[13964, 396, 432, 8, 80, "Text",
  CellTags->"5.5"],
Cell[14399, 406, 73, 1, 37, "Input",
  CellTags->"5.5"],
Cell[14475, 409, 84, 1, 24, "Text",
  CellTags->"5.5"],
Cell[14562, 412, 141, 4, 50, "Input",
  CellTags->"5.5"],
Cell[14706, 418, 149, 4, 38, "Text",
  CellTags->"5.5"],
Cell[14858, 424, 193, 6, 76, "Input",
  CellTags->"5.5"],
Cell[15054, 432, 94, 1, 24, "Text",
  CellTags->"5.5"],
Cell[15151, 435, 186, 5, 63, "Input",
  CellTags->"5.5"],
Cell[15340, 442, 281, 8, 102, "Input",
  CellTags->"5.5"],
Cell[15624, 452, 165, 4, 38, "Text",
  CellTags->"5.5"],
Cell[15792, 458, 709, 15, 110, "Project",
  CellTags->{"i:11", "5.5"}],
Cell[16504, 475, 128, 4, 50, "Input",
  CellTags->"5.5"],
Cell[16635, 481, 169, 4, 38, "Text",
  CellTags->"5.5"],
Cell[16807, 487, 927, 17, 138, "Project",
  CellTags->{"i:11", "5.5"}],
Cell[17737, 506, 599, 13, 68, "Project",
  CellTags->{"i:12", "5.5"}],
Cell[18339, 521, 484, 12, 54, "Project",
  CellTags->{"i:13", "5.5"}],
Cell[18826, 535, 1329, 29, 190, "Project",
  CellTags->{"i:14", "5.5"}],
Cell[20158, 566, 455, 13, 70, "Text",
  CellTags->"5.5"],
Cell[20616, 581, 143, 4, 38, "Text",
  CellTags->"5.5"],
Cell[20762, 587, 406, 11, 68, "BulletListItem",
  CellTags->"5.5"],
Cell[21171, 600, 178, 6, 36, "BulletListItem",
  CellTags->"5.5"],
Cell[21352, 608, 276, 7, 52, "BulletListItem",
  CellTags->"5.5"],
Cell[21631, 617, 56, 1, 24, "Text",
  CellTags->"5.5"],
Cell[21690, 620, 1063, 18, 166, "Project",
  CellTags->{"i:15", "5.5"}],
Cell[22756, 640, 315, 8, 40, "Text",
  CellTags->{"i:16", "5.5"}],
Cell[23074, 650, 413, 11, 68, "BulletListItem",
  CellTags->"5.5"],
Cell[23490, 663, 180, 6, 36, "BulletListItem",
  CellTags->"5.5"],
Cell[23673, 671, 278, 7, 50, "BulletListItem",
  CellTags->"5.5"],
Cell[23954, 680, 183, 6, 36, "BulletListItem",
  CellTags->"5.5"],
Cell[24140, 688, 178, 6, 36, "BulletListItem",
  CellTags->"5.5"],
Cell[24321, 696, 56, 1, 24, "Text",
  CellTags->"5.5"],
Cell[24380, 699, 788, 13, 138, "Note",
  CellTags->"5.5"],
Cell[25171, 714, 557, 11, 68, "Note",
  CellTags->{"i:17", "5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[25765, 730, 53, 1, 40, "Section",
  CellTags->"5.6"],
Cell[25821, 733, 1269, 35, 206, "Reference",
  CellTags->{"i:18", "5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[27127, 773, 66, 1, 40, "Section",
  CellTags->"5.7"],

Cell[CellGroupData[{
Cell[27218, 778, 60, 1, 40, "Subsection",
  CellTags->"5.7"],
Cell[27281, 781, 2664, 43, 635, "Input",
  CellTags->{"i:4", "5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[29982, 829, 55, 1, 40, "Subsection",
  CellTags->"5.7"],
Cell[30040, 832, 3083, 49, 765, "Input",
  CellTags->{"i:7", "5.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

