(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12382,        317]*)
(*NotebookOutlinePosition[     17099,        462]*)
(*  CellTagsIndexPosition[     16703,        442]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6", "ChapterLine",
  CellTags->"6.1"],

Cell["Social Networking and Moving to Far-Flung Locations", "Title",
  CellTags->"6.1"],

Cell["\<\
\"Telephone call? All of these nuts could just make phone calls, \
they could spread insanity, oozing through telephone cables, oozing into the \
ears of all these poor sane people, infecting them. Wackos everywhere, plague \
of madness.\"\
\>", "Quote",
  CellTags->"6.1"],

Cell[TextData[{
  "\[LongDash]Brad Pitt in ",
  StyleBox["Twelve Monkeys",
    FontSlant->"Italic"],
  " (1995)"
}], "QuoteAttribution",
  CellTags->"6.1"],

Cell[CellGroupData[{

Cell["6.1  Introduction", "Section",
  CellTags->"6.1"],

Cell[TextData[{
  "The use of spatial neighborhoods in modeling both the movement of \
individuals and their interactions is realistic in many situtations such as \
at a social gathering (a party) or in an organization (a company). However, \
it is too restrictive for modeling the sorts of economic and social phenomena \
that are increasingly taking place in the modern world where the tools of \
technology have fundamentally altered the nature of human interactions and \
movement. Today, a person can interact instantaneously with one or more \
people who are far away, using the telephone or email [a sister of one of the \
authors (RJG) first met her husband on the Internet]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and",
  StyleBox[" ",
    FontSlant->"Italic"],
  "the mass media can be used to propagate memes (the purpose of \
televangelism) or to spread gossip (talk shows create and maintain \
celebrity). People today can also move about from one location to another \
distant location (using an airplane or a car). In this chapter we present \
some basic tools that can be used for modeling nonlocal interactions and \
movement."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{"email", "", 
    ""}, {"gossip", "", ""}, {"memes", "propagating", ""}, {
    "nonlocal interaction", "", ""}, {"nonlocal movement", "", ""}}},
  CellTags->{"i:1", "6.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2  Reach Out and Touch Someone", "Section",
  CellTags->"6.2"],

Cell["\<\
In this model, which is a simple nonlocal version of the cultural \
transmission models in Chapter 2, each person randomly selects a friend (a \
member of his social network) to interact with and if the other person is \
agreeable, the two of them interact by changing the value of a randomly \
chosen meme.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{
    "social network", "", ""}}},
  CellTags->{"i:2", "6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3  Follow the Leader", "Section",
  CellTags->"6.3"],

Cell["\<\
In this model, which is a nonlocal version of the charlesBarkley \
model in Chapter 5, each person changes the value of a randomly chosen meme \
to equal the value of the corresponding meme of the friend in his social \
network who has the highest social status.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:9", "IndexEntries" -> {{
    "social status", "", ""}}},
  CellTags->{"i:9", "6.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4  Nonlocal Movement", "Section",
  CellTags->"6.4"],

Cell["\<\
We illustrate the nonlocal movement of people using the variant of \
the Schelling model of self-forming neighborhoods that we developed in \
Chapter 5.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:12", "IndexEntries" -> {{
    "neighborhoods", "self-forming", ""}, {"nonlocal movement", "", ""}}},
  CellTags->{"i:12", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5  Computer Simulation Projects", "Section",
  CellTags->"6.5"],

Cell[TextData[{
  StyleBox["1",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Change the distribution of the sizes of social networks so that some \
individuals are especially charismatic, having many friends. How does the \
presence of these charismatic individuals affect the spread of new ideas? "
}], "Project",
  TaggingRules:>{"IndexingCellTag" -> "i:17", "IndexEntries" -> {{
    "charismatic individuals", "", ""}}},
  CellTags->{"i:17", "6.5"}],

Cell[TextData[{
  StyleBox["2",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Make the social status of an individual vary with the number of friends \
he has and see how this affects the results. "
}], "Project",
  CellTags->"6.5"],

Cell[TextData[{
  StyleBox["3",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " Let individuals have multiple (e.g., two) distinct sets of friends and \
let each operate on different memes. How do your findings change?"
}], "Project",
  CellTags->"6.5"],

Cell[TextData[{
  StyleBox["4",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"],
  " In the cultural transmission models, the social network remains the same \
over time. Modify the models so that people are added to or removed from the \
social network, based on a criterion of your choice."
}], "Project",
  CellTags->"6.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.6  References", "Section",
  CellTags->"6.6"],

Cell[TextData[{
  "Epstein, Joshua M. and Robert Axtell. 1996. ",
  StyleBox["Growing Artifical Societies",
    FontSlant->"Italic"],
  ". Cambridge MA: Brookings Institute Press/MIT Press."
}], "Reference",
  CellTags->"6.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.7  Programs in the Chapter", "Section",
  CellTags->"6.7"],

Cell[CellGroupData[{

Cell["6.7.1  peopleWhoNeedPeople", "Subsection",
  CellTags->"6.7"],

Cell[TextData[
"peopleWhoNeedPeople[n_, p_, s_, m_, f_, t_] :=\nModule[{k = 0, society, \
decide, exchange, \n                                satellites, \
socialCircle},\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \
\[RuleDelayed] ++k /. x_?Positive \[RuleDelayed] {x, Union[DeleteCases[\n     \
           Table[Random[Integer, {1, k}], {f}], x]],\n                  \
Table[Random[Integer, {1, m}], {s}]};\n  society = society /. {a_, b_, c_} \
\[RuleDelayed] {a, Union[b,\n    Cases[society, {x_, {___, a, ___}, _} \
\[RuleDelayed] x, {2}]], c};\n  decide[{{a_, b_, c_}, res__}] :=\n    {a, b, \
c, {res}[[#2, 1]], #1,\n      Random[Integer, {c[[#1]], {res}[[#2, 3, \
#1]]}]}&[\n               Random[Integer, {1, s}],\n               \
Random[Integer, {1, Length[{res}]}]];\n  decide[{{x_, {}, y_}}] := {x, {}, \
y};\n  decide[0] := 0;\n  exchange[{{a_, b_, c_, aa_, pos_, d_}, ___,\n       \
     {aa_, _, _, a_, _, _}, ___}] := \n                {a, b, ReplacePart[c, \
d, pos]} /; a < aa;\n  exchange[{{a_, b_, c_, aa_, _, _}, ___,\n            \
{aa_, _, _, a_, pos_, d_}, ___}] := \n                {a, b, ReplacePart[c, \
d, pos]};\n  exchange[{{a_, b_, c_, ___}, ___}] := {a, b, c};\n  exchange[0] \
:= 0;\n  socialCircle[func_, lat_] :=\n                Map[func[satellites[#, \
lat]]&, lat, {2}];\n  satellites[0, _] = 0;\n  satellites[{a_, b_, c___}, \
lat_] := Join[{{a, b, c}},\n       Cases[lat, {Apply[Alternatives, b], _, \
___}, {2}]];\n  NestList[socialCircle[exchange,\n                  \
socialCircle[decide, #]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:18", "IndexEntries" -> {{
    "peopleWhoNeedPeople", "", ""}}},
  CellTags->{"i:18", "6.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.7.2 iWillFollowHim", "Subsection",
  CellTags->"6.7"],

Cell[TextData[
"iWillFollowHim[n_, p_, s_, m_, f_, t_] :=\nModule[{k = 0, society, exchange,\
\n                             satellites, socialCircle},\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \[RuleDelayed] ++k /. \
x_?Positive \[RuleDelayed] {x, Union[DeleteCases[\n        \
Table[Random[Integer, {1, k}], {f}], x]],  \n          Random[], \
Table[Random[Integer, {1, m}], {s}]};\n  society = society /.\n    {a_, b_, \
c_, d_} \[RuleDelayed] {a, Union[b, Cases[society,\n            {x_, {___, a, \
___}, _, _} \[RuleDelayed] x, {2}]], c, d};\n  exchange[{{a_, b_, c_, d_}, \
res__}] := {a, b, c,\n    ReplacePart[d,\n         Sort[{res}, #1[[3]] > \
#2[[3]]&][[1, 4, #]], #]}&[\n           Random[Integer, {1, s}]];\n  \
exchange[{{a_,  {}, c_, d_}}] := {a, {}, c, d};\n  exchange[0] := 0;\n  \
socialCircle[func_, lat_] :=\n                Map[func[satellites[#, lat]]&, \
lat, {2}];\n  satellites[0, _] = 0;\n  satellites[{a_, b_, c___}, lat_] := \
Join[{{a, b, c}},\n      Cases[lat, {Apply[Alternatives, b], _, ___}, {2}]];\n\
  NestList[socialCircle[exchange, #]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:19", "IndexEntries" -> {{
    "iWillFollowHim", "", ""}}},
  CellTags->{"i:19", "6.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.7.3  flight", "Subsection",
  CellTags->"6.7"],

Cell[TextData[
"flight[n_, p_, g_, t_] := \nModule[{society, decideToFly, flyAway, Moore},\n \
 society = Table[Floor[p + Random[]], {n}, {n}] /.\n                          \
 1 \[RuleDelayed] {1 + Floor[g + Random[]]};\n  decideToFly[{1}, res__] := \
{1, 1} /;\n                  Count[{res}, {1}] < Count[{res}, {2}];\n  \
decideToFly[{2}, res__] := {2, 2} /;\n                  Count[{res}, {2}] < \
Count[{res}, {1}];\n  decideToFly[0, res__] := {0, 1} /;\n                  \
Count[{res}, {1}] > Count[{res}, {2}];\n  decideToFly[0, res__] := {0, 2} /;\n\
                  Count[{res}, {2}] > Count[{res}, {1}];\n  decideToFly[x_, \
__] := x;\n  flyAway[lat_] := \n  Module[{a1, a2, e1, e2, randomize, \
multiReplacePart},\n   {a1, a2, e1, e2} = Map[Position[lat, #, {2}]&,\n       \
                 {{1, 1}, {2, 2}, {0, 1}, {0, 2}}];\n   randomize[{}] := {};\n\
   randomize[lis_] :=\n     Transpose[Sort[Map[{Random[], #}&, lis]]][[2]];\n \
  a1 = Take[randomize[a1], Min[Length[a1], Length[e1]]];\n   a2 = \
Take[randomize[a2], Min[Length[a2], Length[e2]]];\n   e1 = Take[e1, \
Length[a1]];\n   e2 = Take[e2, Length[a2]];\n   multiReplacePart[mat_, lis1_, \
lis2_] :=\n    Fold[ReplacePart[#1, Part[#1, Apply[Sequence,\n    \
First[#2]]], Last[#2]]&, mat, Transpose[{lis1, lis2}]];\n   ReplacePart[#, 0, \
Join[a1, a2]]&[\n      multiReplacePart[#, a2, e2]&[\n        \
multiReplacePart[lat, a1, e1]]] /.\n                         {{0, _} \
\[RuleDelayed] 0, {x_, _} \[RuleDelayed] {x}}];\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  NestList[flyAway[Moore[decideToFly, #]]&, society, t]]"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:20", "IndexEntries" -> {{"flight", 
    "", ""}}},
  CellTags->{"i:20", "6.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "6. Social Networks"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 21, "IndexEntries" -> {{"i:1", 
  "email", "", ""}, {"i:1", "gossip", "", ""}, {"i:1", "memes", 
  "propagating", ""}, {"i:1", "nonlocal interaction", "", ""}, {"i:1", 
  "nonlocal movement", "", ""}, {"i:2", "social network", "", ""}, {"i:9", 
  "social status", "", ""}, {"i:12", "neighborhoods", "self-forming", ""}, {
  "i:12", "nonlocal movement", "", ""}, {"i:17", "charismatic individuals", 
  "", ""}, {"i:18", "peopleWhoNeedPeople", "", ""}, {"i:19", 
  "iWillFollowHim", "", ""}, {"i:20", "flight", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@E2X000000000006T<01T1T00000000000
00000000003oo`@J683oo`02Da@00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "6.1"->{
    Cell[1731, 51, 43, 1, 92, "ChapterLine",
      CellTags->"6.1"],
    Cell[1777, 54, 87, 1, 180, "Title",
      CellTags->"6.1"],
    Cell[1867, 57, 283, 6, 50, "Quote",
      CellTags->"6.1"],
    Cell[2153, 65, 155, 6, 24, "QuoteAttribution",
      CellTags->"6.1"],
    Cell[2333, 75, 55, 1, 40, "Section",
      CellTags->"6.1"],
    Cell[2391, 78, 1401, 25, 208, "Text",
      CellTags->{"i:1", "6.1"}]},
  "i:1"->{
    Cell[2391, 78, 1401, 25, 208, "Text",
      CellTags->{"i:1", "6.1"}]},
  "6.2"->{
    Cell[3829, 108, 70, 1, 40, "Section",
      CellTags->"6.2"],
    Cell[3902, 111, 458, 9, 66, "Text",
      CellTags->{"i:2", "6.2"}]},
  "i:2"->{
    Cell[3902, 111, 458, 9, 66, "Text",
      CellTags->{"i:2", "6.2"}]},
  "6.3"->{
    Cell[4397, 125, 60, 1, 40, "Section",
      CellTags->"6.3"],
    Cell[4460, 128, 412, 8, 66, "Text",
      CellTags->{"i:9", "6.3"}]},
  "i:9"->{
    Cell[4460, 128, 412, 8, 66, "Text",
      CellTags->{"i:9", "6.3"}]},
  "6.4"->{
    Cell[4909, 141, 60, 1, 40, "Section",
      CellTags->"6.4"],
    Cell[4972, 144, 347, 7, 38, "Text",
      CellTags->{"i:12", "6.4"}]},
  "i:12"->{
    Cell[4972, 144, 347, 7, 38, "Text",
      CellTags->{"i:12", "6.4"}]},
  "6.5"->{
    Cell[5356, 156, 71, 1, 40, "Section",
      CellTags->"6.5"],
    Cell[5430, 159, 477, 11, 54, "Project",
      CellTags->{"i:17", "6.5"}],
    Cell[5910, 172, 256, 8, 40, "Project",
      CellTags->"6.5"],
    Cell[6169, 182, 275, 8, 40, "Project",
      CellTags->"6.5"],
    Cell[6447, 192, 343, 9, 54, "Project",
      CellTags->"6.5"]},
  "i:17"->{
    Cell[5430, 159, 477, 11, 54, "Project",
      CellTags->{"i:17", "6.5"}]},
  "6.6"->{
    Cell[6827, 206, 53, 1, 40, "Section",
      CellTags->"6.6"],
    Cell[6883, 209, 226, 6, 38, "Reference",
      CellTags->"6.6"]},
  "6.7"->{
    Cell[7146, 220, 66, 1, 40, "Section",
      CellTags->"6.7"],
    Cell[7237, 225, 67, 1, 40, "Subsection",
      CellTags->"6.7"],
    Cell[7307, 228, 1714, 24, 427, "Input",
      CellTags->{"i:18", "6.7"}],
    Cell[9058, 257, 61, 1, 40, "Subsection",
      CellTags->"6.7"],
    Cell[9122, 260, 1249, 18, 310, "Input",
      CellTags->{"i:19", "6.7"}],
    Cell[10408, 283, 54, 1, 40, "Subsection",
      CellTags->"6.7"],
    Cell[10465, 286, 1877, 26, 492, "Input",
      CellTags->{"i:20", "6.7"}]},
  "i:18"->{
    Cell[7307, 228, 1714, 24, 427, "Input",
      CellTags->{"i:18", "6.7"}]},
  "i:19"->{
    Cell[9122, 260, 1249, 18, 310, "Input",
      CellTags->{"i:19", "6.7"}]},
  "i:20"->{
    Cell[10465, 286, 1877, 26, 492, "Input",
      CellTags->{"i:20", "6.7"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"6.1", 14077, 355},
  {"i:1", 14501, 368},
  {"6.2", 14588, 371},
  {"i:2", 14739, 376},
  {"6.3", 14824, 379},
  {"i:9", 14975, 384},
  {"6.4", 15060, 387},
  {"i:12", 15213, 392},
  {"6.5", 15299, 395},
  {"i:17", 15657, 406},
  {"6.6", 15747, 409},
  {"6.7", 15894, 414},
  {"i:18", 16416, 429},
  {"i:19", 16507, 432},
  {"i:20", 16598, 435}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 43, 1, 92, "ChapterLine",
  CellTags->"6.1"],
Cell[1777, 54, 87, 1, 180, "Title",
  CellTags->"6.1"],
Cell[1867, 57, 283, 6, 50, "Quote",
  CellTags->"6.1"],
Cell[2153, 65, 155, 6, 24, "QuoteAttribution",
  CellTags->"6.1"],

Cell[CellGroupData[{
Cell[2333, 75, 55, 1, 40, "Section",
  CellTags->"6.1"],
Cell[2391, 78, 1401, 25, 208, "Text",
  CellTags->{"i:1", "6.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3829, 108, 70, 1, 40, "Section",
  CellTags->"6.2"],
Cell[3902, 111, 458, 9, 66, "Text",
  CellTags->{"i:2", "6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4397, 125, 60, 1, 40, "Section",
  CellTags->"6.3"],
Cell[4460, 128, 412, 8, 66, "Text",
  CellTags->{"i:9", "6.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4909, 141, 60, 1, 40, "Section",
  CellTags->"6.4"],
Cell[4972, 144, 347, 7, 38, "Text",
  CellTags->{"i:12", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[5356, 156, 71, 1, 40, "Section",
  CellTags->"6.5"],
Cell[5430, 159, 477, 11, 54, "Project",
  CellTags->{"i:17", "6.5"}],
Cell[5910, 172, 256, 8, 40, "Project",
  CellTags->"6.5"],
Cell[6169, 182, 275, 8, 40, "Project",
  CellTags->"6.5"],
Cell[6447, 192, 343, 9, 54, "Project",
  CellTags->"6.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6827, 206, 53, 1, 40, "Section",
  CellTags->"6.6"],
Cell[6883, 209, 226, 6, 38, "Reference",
  CellTags->"6.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7146, 220, 66, 1, 40, "Section",
  CellTags->"6.7"],

Cell[CellGroupData[{
Cell[7237, 225, 67, 1, 40, "Subsection",
  CellTags->"6.7"],
Cell[7307, 228, 1714, 24, 427, "Input",
  CellTags->{"i:18", "6.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9058, 257, 61, 1, 40, "Subsection",
  CellTags->"6.7"],
Cell[9122, 260, 1249, 18, 310, "Input",
  CellTags->{"i:19", "6.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10408, 283, 54, 1, 40, "Subsection",
  CellTags->"6.7"],
Cell[10465, 286, 1877, 26, 492, "Input",
  CellTags->{"i:20", "6.7"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

