(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8645,        183]*)
(*NotebookOutlinePosition[      9858,        220]*)
(*  CellTagsIndexPosition[      9814,        216]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["", "ChapterLine"],

Cell["Foreword", "Title"],

Cell["\<\
Richard Gaylord and Lou D'Andria's book is not a standard \
introduction to computational social sciences filled with long passages on \
the history of economic thought. Instead, this is a book describing how to \
create computer models of complex human interactions. These models stand in \
sharp contrast to the static, \"supply equals demand\" models of introductory \
economics, though that is not to say that standard economic models are not \
informative, just that they are predictable. In contrast, the models \
presented in this book can exhibit perpetually novel behavior.\
\>", "Text"],

Cell[TextData[
"A computational model relies on individual agents (people) who have \
preferences and can take actions. Agents can walk. They can move to new \
neighborhoods if they feel uncomfortable in their present situation. They can \
play games with their friends, or choose to hang with a new crowd. They can \
share gossip. They can chat on the phone. While these agents are reasonably \
smart, they do not always optimize. To borrow Herb Simon's words, they are \
boundedly rational. They go about life much in the same way that we do. They \
rely on heuristics\[LongDash]rules of thumb\[LongDash]in their day to day \
interactions. These rules are not set in stone. In fact, if an agent finds \
that she is using a stupid rule, she may abandon it in favor of something \
better."], "Text"],

Cell["\<\
In watching and analyzing the microlevel and aggregate behavior of \
these artificial agents, we can learn much about our own world. We learn that \
gossip has its good side and that the presence of racial segregation need not \
imply that individual agents are racist. \
\>", "Text"],

Cell[TextData[{
  "This latter finding is due to Thomas Schelling, whose book ",
  StyleBox["Micromotives and Macrobehavior",
    FontSlant->"Italic"],
  " still informs those of us interested in dynamic models. Gaylord and \
D'Andria perform a much needed service by making this model available to all. \
They also extend Schelling's model by allowing agents to relocate based on \
endogenous (acquired) characteristics. For example, I may choose to move to \
another house if my neighbor decides to form a rock band, or I may choose to \
move out of town if my fellow citizens vote to cut public services or raise \
taxes to a level I find objectionable."
}], "Text"],

Cell[TextData[{
  "The Gaylord and D'Andria book carves out an important niche in this \
growing field of complexity, owing to its accessibility. Although many models \
of artificial society make their computer codes available publicly, these \
often consist of thousands of lines of inelegant code. By relying both on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", a high-level language, and on exacting standards, the authors construct \
elaborate models with minimal, often beautiful, code. For example, some of \
their models require less than fifty lines of code. Gaylord and D'Andria also \
deconstruct their code and discuss how to extend it to accommodate richer \
models. Finally, their code produces readable, analyzable output. They reveal \
that with a few simple subroutines, some courage, moderate intelligence, and \
a little heart, anyone can create artificial societies."
}], "Text"],

Cell[TextData[
"This book contains models that are both bottom-up and complex: the \
accumulated behaviors of autonomous agents generate outcomes, and agents \
respond to an environment that they in turn define by their actions. The more \
advanced models in the book include adaptive behavior: agents abandon \
unsuccessful behavioral rules. Herein lies the difference between social \
science models and those from the physical sciences\[LongDash]people can \
change. We can copy strategies of others, alter our own actions, or act out \
of caprice. Carbon atoms never consciously decide to throw caution to the \
wind and act like helium atoms. Yet poor people sometimes act rich, smart \
people sometimes act foolish, and conservative people sometimes take huge \
risks. Although this book only dips its toe into the water on the issue of \
how to construct artificial adaptive agents, it does provide a sufficient \
introduction to get people started."], "Text"],

Cell[TextData[
"The topics addressed in this book\[LongDash]movements, fads, norms, game \
playing, social networks, culture, and conformity\[LongDash]span traditional \
social scientific boundaries. Many of the models take as a fundamental \
assumption that others\[LongDash]friends, family, and \
peers\[LongDash]influence our actions. Recently, several economists, notably \
Steven Durlauf of the Santa Fe Institute and the University of Wisconsin, \
have begun to analyze the role of social influence in explaining persistent \
social problems such as crime, drug use, out-of-wedlock births, and school \
attendance. These problems are difficult to analyze empirically, so \
simulations and other forms of theorizing seem a logical first step in \
organizing our collective thinking."], "Text"],

Cell[TextData[
"This book was not written with the intent of influencing social policy \
directly and, given its intent, it wisely avoids long discussions on patterns \
of drug use, crime, and other \"heavy\" topics. Instead, it provides an \
introduction. It says, \"Here is how to do make your own models.\" The task \
of interpretation is left to the readers. We can attach weight to the \
insights we gather\[LongDash]asking, for example, whether these models say \
anything about why crack became so popular so fast\[LongDash]or we can just \
have fun. "], "Text"],

Cell[TextData[{
  "In sum, this book merits a careful read. For the noneconomist, this book \
should whet your appetite for a deeper look at social science models. For \
social scientists who use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the sole purpose of solving algebraic problems, here's a chance to \
see its awesome power."
}], "Text"],

Cell["\<\
Gaylord and D'Andria have included many exercises and extensions, \
some of which are open research questions. I encourage readers to go beyond \
these and formulate their own models, to think more broadly. Explore. Take \
risks. Construct models of product competition, movie demand, marriage \
markets, political preferences, religious affiliation, tax evading, \
investment strategies, traffic jams, or joke telling. Given the many movie \
quotes contained throughout the text, I close by paraphrasing a certain Mr. \
Gump. This book is \"like a box of chocolates.\" You really never do know \
what you might get. That's the wonder of computational modeling. You define \
the world, then sit back and watch it evolve.\
\>", "Text"],

Cell["\<\
Scott E. Page
Department of Economics
University of Iowa\
\>", "QuoteAttribution"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", "Foreword"}], 
        "Header"], Inherited, Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"IndexEntries" -> {}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@Ocf_000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 23, 0, 92, "ChapterLine"],
Cell[1757, 53, 25, 0, 153, "Title"],
Cell[1785, 55, 606, 9, 122, "Text"],
Cell[2394, 66, 799, 11, 150, "Text"],
Cell[3196, 79, 294, 5, 66, "Text"],
Cell[3493, 86, 669, 11, 126, "Text"],
Cell[4165, 99, 913, 14, 166, "Text"],
Cell[5081, 115, 967, 13, 178, "Text"],
Cell[6051, 130, 798, 11, 136, "Text"],
Cell[6852, 143, 569, 8, 108, "Text"],
Cell[7424, 153, 363, 8, 68, "Text"],
Cell[7790, 163, 744, 11, 136, "Text"],
Cell[8537, 176, 92, 4, 50, "QuoteAttribution"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

