(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49925,        956]*)
(*NotebookOutlinePosition[     55266,       1115]*)
(*  CellTagsIndexPosition[     55053,       1103]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["", "ChapterLine",
  CellTags->"D.0"],

Cell["Program Listing", "Title",
  CellTags->"D.0"],

Cell["\<\
This online-only notebook contains the code for every simulation \
program in this book, but replaces the use of Nest or NestList with the \
NestListEffects function from Appendix C.\
\>", "Text",
  CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],

Cell[CellGroupData[{

Cell["D.0  NestListEffects", "Section",
  CellTags->"D.0"],

Cell[CellGroupData[{

Cell["D.0.1  NestListEffects, ReturnValues, and SideEffects", "Subsection",
  CellTags->"D.0"],

Cell[TextData[
"NestListEffects::usage = \"NestListEffects[f, expr, n, ReturnValues \[Rule] \
{g, k}] returns a list of every kth element of NestList[f, expr, n] after the \
application of g. NestListEffects[f, expr, n, SideEffects \[Rule] {{g1, k1}, \
{g2, k2},...}] applies gi after every ki steps, but does not effect return \
values.\";"], "Input",
  CellTags->"D.0"],

Cell["\<\
ReturnValues::usage = \"ReturnValues is an option to \
NestListEffects that determines what is returned and how often.\";\
\>", 
  "Input",
  CellTags->"D.0"],

Cell["\<\
SideEffects::usage = \"SideEffects is an option to NestListEffects \
that applies functions without effecting return values.\";\
\>", "Input",
  CellTags->"D.0"],

Cell[TextData[
"Options[NestListEffects] =\n                 {ReturnValues \[Rule] {#&, 1}, \
SideEffects\[Rule]{}};"], "Input",
  CellTags->"D.0"],

Cell["\<\
NestListEffects[f_, expr_, n_, opts___] :=
If[({ReturnValues, SideEffects} /. {opts} /. 
         Options[NestListEffects]) === {{#&, 1}, {}},
  NestList[f, expr, n],
  (* else *)
  Module[{c = 0, lis = {}, side, ret},
    {ret, side} = {ReturnValues, SideEffects} /.
                       {opts} /. Options[NestListEffects];
    If[side === {}, side = {{Null, Infinity}}];
    Nest[(
      If[Mod[c, ret[[-1]]] === 0,
         lis = Join[lis, {First[ret][#, c]}]];
      Table[If[Mod[c, side[[i, -1]]] === 0,
               side[[i, 1]][#, c]],
        {i,Length[side]}];
      c++; #)&[f[#]]&, expr, n];
    lis]
];\
\>", "Input",
  CellTags->"D.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.0.2  printCounter and printMemory", "Subsection",
  CellTags->"D.0"],

Cell["\<\
printCounter[lat_, counter_] :=
  WriteString[\"stdout\", counter, \" \"];\
\>", "Input",
  CellTags->"D.0"],

Cell["\<\
printMemory[lat_, counter_] := 
 (Print[];
  Print[\"After \", counter, \" steps:\"];
  Print[\"Date:          \", Date[]];
  Print[\"MemoryInUse:   \", MemoryInUse[]];
  Print[\"MaxMemoryUsed: \", MaxMemoryUsed[]];
  Print[]);\
\>", "Input",
  CellTags->"D.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.1  Chapter 1", "Section",
  CellTags->"D.1"],

Cell[CellGroupData[{

Cell["D.1.1  randomWalkers", "Subsection",
  CellTags->"D.1"],

Cell[TextData[{
  "randomWalkers[n_, p_, g_, m_, s_, r_, t_, opts___] := \nModule[{society, \
RND, k, walk, GN},\n  RND:= Random[Integer, {1, 4}];\n  k = 0;\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \[RuleDelayed] {RND, ++k, \
Floor[g + Random[]], \n       Table[Random[Integer, {1, m}], {s}],\n       \
Random[Integer, {0, r}]};\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := \
{RND,a};\n  walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n ",
  " walk[",
  "0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  GN[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, \
0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk, \
#]&, society, t, opts]]"
}], "Input",
  CellTags->"D.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.2  Chapter 2", "Section",
  CellTags->"D.2"],

Cell[CellGroupData[{

Cell["D.2.1  cultureSpreadingShared", "Subsection",
  CellTags->"D.2"],

Cell[TextData[
"cultureSpreadingShared[n_, p_, s_, m_, t_, opts___] :=\nModule[{society, \
RND, decide, exchange,\n                                    walk, vonNeumann, \
GN},\n  RND:= Random[Integer, {1, 4}];\n  society = Table[Floor[p + \
Random[]], {n}, {n}] /. \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, m}], {s}]};\n  decide[{3, y_}, _, _, {1, y_}, _] := \
{3, y};\n  decide[{2, y_}, _, {4, y_}, _, _] := {2, y};\n  decide[{3, y_}, _, \
_, {1, z_}, _] := Module[\n    {diffs = Flatten[Position[Abs[y - z], \
_?Positive]]},\n    {3, y, Random[Integer, {y[[#]], z[[#]]}], #}&[\n         \
diffs[[Random[Integer, {1, Length[diffs]}]]]] /;\n                 \
Random[Integer, {1,s}] > Length[diffs]];\n  decide[{2, y_}, _, {4, z_}, _, _] \
:= Module[\n    {diffs = Flatten[Position[Abs[y - z], _?Positive]]},\n    {2, \
y, Random[Integer, {y[[#]], z[[#]]}], #}&[\n         diffs[[Random[Integer, \
{1, Length[diffs]}]]]] /;\n                 Random[Integer, {1,s}] > \
Length[diffs]];\n  decide[a_, _, _, _, _] := a;\n  exchange[{3, y_, c_, d_}, \
_, _, _, _] :=\n                               {3, ReplacePart[y, c, d]};\n  \
exchange[{2, y_, c_, d_}, _, _, _, _] :=\n                               {2, \
ReplacePart[y, c, d]};\n  exchange[{1, z_}, {3, y_, c_, d_}, _, _, _] :=\n    \
                           {1, ReplacePart[z, c, d]};\n  exchange[{4, z_}, _, \
_, _, {2, y_, c_, d_}] :=\n                               {4, ReplacePart[z, \
c, d]};\n  exchange[a_, _, _, _, _] := a;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0; \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk, \
vonNeumann[exchange,\n                   vonNeumann[decide, #]]]&, society, \
t, opts]]"], "Input",
  CellTags->"D.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.2.2  cultureSpreadingCloseness", "Subsection",
  CellTags->"D.2"],

Cell[TextData[
"cultureSpreadingCloseness[n_, p_, s_, m_, t_, opts___] :=\nModule[{society, \
RND, decide, exchange,\n                                    walk, vonNeumann, \
GN},\n  RND:= Random[Integer, {1, 4}];\n  society = Table[Floor[p + \
Random[]], {n}, {n}] /. \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, m}], {s}]};\n  decide[{3, y_}, _, _, {1, y_}, _] := \
{3, y};\n  decide[{2, y_}, _, {4, y_}, _, _] := {2, y};\n  decide[{2, y_}, _, \
{4, z_}, _, _] := \n    Module[{r = Random[Integer, {1, s}]},\n          {2, \
y, Random[Integer, {y[[r]], z[[r]]}], r} /;\n          Random[Integer,{1, m}] \
> Abs[y[[r]] - z[[r]]]];\n  decide[{3, y_}, _, _, {1, z_}, _] := \n    \
Module[{r = Random[Integer, {1, s}]},\n          {3, y, Random[Integer, \
{y[[r]], z[[r]]}], r} /;\n          Random[Integer,{1, m}] > Abs[y[[r]] - \
z[[r]]]];\n  decide[a_, _, _, _, _] := a;\n  exchange[{3, y_, c_, d_}, _, _, \
_, _] :=\n                               {3, ReplacePart[y, c, d]};\n  \
exchange[{2, y_, c_, d_}, _, _, _, _] :=\n                               {2, \
ReplacePart[y, c, d]};\n  exchange[{1, z_}, {3, y_, c_, d_}, _, _, _] :=\n    \
                           {1, ReplacePart[z, c, d]};\n  exchange[{4, z_}, _, \
_, _, {2, y_, c_, d_}] :=\n                               {4, ReplacePart[z, \
c, d]};\n  exchange[a_, _, _, _, _] := a;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0; \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk, \
vonNeumann[exchange,\n                 vonNeumann[decide, #]]]&, society, t, \
opts]]"], "Input",
  CellTags->"D.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.2.3  charlesBarkley", "Subsection",
  CellTags->"D.2"],

Cell[TextData[
"charlesBarkley[n_, p_, s_, m_, t_, opts___] :=\nModule[{society, RND, \
exchange, walk, vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  \
society = Table[Floor[p + Random[]], {n}, {n}] /. 1 \[RuleDelayed] \n     \
{RND, Random[], Table[Random[Integer, {1, m}], {s}]};\n  exchange[{1, a_, \
u_}, {3, b_, v_}, _, _, _] := \n    {1, a, ReplacePart[u, v[[#]], #]&[\n      \
                Random[Integer, {1, s}]]} /; a < b;\n  exchange[{2, a_, u_}, \
_, {4, b_, v_}, _, _] :=\n    {2, a, ReplacePart[u, v[[#]], #]&[\n            \
          Random[Integer, {1, s}]]} /; a < b;\n  exchange[{3, a_, u_}, _, _, \
{1, b_, v_}, _] :=\n    {3, a, ReplacePart[u, v[[#]], #]&[\n                  \
    Random[Integer, {1, s}]]} /; a < b;\n  exchange[{4, a_, u_}, _, _, _, {2, \
b_, v_}] :=\n    {4, a, ReplacePart[u, v[[#]], #]&[\n                      \
Random[Integer, {1, s}]]} /; a < b;\n  exchange[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;     \n  vonNeumann[func_, lat_] := \n   \
 MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk, \
vonNeumann[exchange, #]]&,\n                                           \
society, t, opts]]"], "Input",
  CellTags->"D.2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.3  Chapter 3", "Section",
  CellTags->"D.3"],

Cell[CellGroupData[{

Cell["D.3.1  onceBurntTwiceShy", "Subsection",
  CellTags->"D.3"],

Cell[TextData[
"onceBurntTwiceShy[n_, p_, g_,\n                         {P_, R_, S_, T_, \
W_}, t_, opts___] :=\nModule[{RND, k = 0, society, interact, payoff,\n        \
                           walk, vonNeumann, GN},\n  RND := Random[Integer, \
{1, 4}];\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\n               \
1 \[RuleDelayed] {RND, ++k, Floor[g + Random[]], {}, 0};\n  payoff[1, 1] = R;\
\n  payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  \
interact[{1, a1_, x1_, b1_, r_},\n           {3, a3_, x3_, b3_, _}, _, _, _] \
:=\n                {1, a1, x1, b1, r + W} /;\n                     \
MemberQ[b1, a3] || MemberQ[b3, a1];\n  interact[{2, a2_, x2_, b2_, r_}, _,\n  \
         {4, a4_, x4_, b4_, _}, _, _] :=\n                {2, a2, x2, b2, r + \
W} /;\n                     MemberQ[b2, a4] || MemberQ[b4, a2];\n  \
interact[{3, a3_, x3_, b3_, r_}, _, _,\n           {1, a1_, x1_, b1_, _}, _] \
:=\n                {3, a3, x3, b3, r + W} /;\n                     \
MemberQ[b3, a1] || MemberQ[b1, a3];\n  interact[{4, a4_, x4_, b4_, r_}, _, _, \
_,\n           {2, a2_, x2_, b2_, _}] :=\n                {4, a4, x4, b4, r + \
W} /;\n                     MemberQ[b4, a2] || MemberQ[b2, a4];\n  \
interact[{1, a1_, x1_, b1_, r_},\n           {3, a3_, x3_, _, _}, _, _, _] :=\
\n                {1, a1, x1, Union[b1, Drop[{a3}, x3]],\n                    \
                r + payoff[x1, x3]};\n  interact[{2, a2_, x2_ ,b2_, r_}, _,\n \
          {4, a4_, x4_, _, _}, _, _] :=\n                {2, a2, x2, \
Union[b2, Drop[{a4}, x4]],\n                                    r + \
payoff[x2, x4]};\n  interact[{3, a3_, x3_, b3_, r_}, _, _,\n           {1, \
a1_, x1_, _, _}, _] :=\n                {3, a3, x3, Union[b3, Drop[{a1}, \
x1]],\n                                    r + payoff[x3, x1]};\n  \
interact[{4, a4_, x4_, b4_, r_}, _, _, _,\n           {2, a2_, x2_, _, _}] :=\
\n                {4, a4, x4, Union[b4, Drop[{a2}, x2]],\n                    \
                r + payoff[x4, x2]};\n  interact[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[vonNeumann[interact, \
GN[walk, #]]&,\n                                            society, t, \
opts]]"], "Input",
  CellTags->"D.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.3.2  badRep", "Subsection",
  CellTags->"D.3"],

Cell[TextData[
"badRep[n_, p_, g_, {P_, R_, S_, T_, W_}, t_, opts___] := \nModule[{RND, k = \
0, society, interact, payoff,\n                                   walk, \
vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.\n               1 \[RuleDelayed] \
{RND, ++k, Floor[g + Random[]], {}, 0};\n  payoff[1, 1] = R;\n  payoff[0, 1] \
= T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  interact[{1, a1_, x1_, b1_, \
r_},\n           {3, a3_, x3_, b3_, _}, _, _, _] :=\n                {1, a1, \
x1, b1, r + W} /;\n                     MemberQ[b1, a3] || MemberQ[b3, a1];\n \
 interact[{2, a2_, x2_, b2_, r_}, _,\n           {4, a4_, x4_, b4_, _}, _, _] \
:=\n                {2, a2, x2, b2, r + W} /;\n                     \
MemberQ[b2, a4] || MemberQ[b4, a2];\n  interact[{3, a3_, x3_, b3_, r_}, _, _,\
\n           {1, a1_, x1_, b1_, _}, _] :=\n                {3, a3, x3, b3, r \
+ W} /;\n                     MemberQ[b3, a1] || MemberQ[b1, a3];\n  \
interact[{4, a4_, x4_, b4_, r_}, _, _, _,\n           {2, a2_, x2_, b2_, _}] \
:=\n                {4, a4, x4, b4, r + W} /;\n                     \
MemberQ[b4, a2] || MemberQ[b2, a4];\n  interact[{1, a1_, x1_, b1_, r_},\n     \
      {3, a3_, x3_, b3_, _}, _, _, _] :=\n               {1, a1, x1, \
Union[b1, b3, Drop[{a3}, x3]],\n                                      r + \
payoff[x1, x3]};\n  interact[{2, a2_, x2_ ,b2_, r_}, _,\n           {4, a4_, \
x4_, b4_, _}, _, _] :=\n               {2, a2, x2, Union[b2, b4, Drop[{a4}, \
x4]],\n                                      r + payoff[x2, x4]};\n  \
interact[{3, a3_, x3_, b3_, r_}, _, _,\n           {1, a1_, x1_, b1_, _}, _] \
:=\n               {3, a3, x3, Union[b3, b1, Drop[{a1}, x1]],\n               \
                       r + payoff[x3, x1]};\n  interact[{4, a4_, x4_, b4_, \
r_}, _, _, _,\n           {2, a2_, x2_, b2_, _}] :=\n               {4, a4, \
x4, Union[b4, b2, Drop[{a2}, x2]],\n                                      r + \
payoff[x4, x2]};\n  interact[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[vonNeumann[interact, \
GN[walk, #]]&,\n                                           society, t, \
opts]]"], "Input",
  CellTags->"D.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.3.3  vibes", "Subsection",
  CellTags->"D.3"],

Cell[TextData[
"vibes[n_, p_, g_, {P_, R_, S_, T_, W_}, t_, opts___] := \nModule[{RND, \
society, decide, interact, costbenefit,\n                                    \
walk, vonNeumann, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /. \n              1 \[RuleDelayed] \
{RND, Floor[g + Random[]], Random[], 0};\n  decide[{1, a_, x_, b_}, {3, _, \
y_, _}, _, _, _] := \n                        {1, a, x, b, Floor[y + \
Random[]]};\n  decide[{2, a_, x_, b_}, _, {4, _, y_, _}, _, _] :=\n           \
             {2, a, x, b, Floor[y + Random[]]};\n  decide[{3, a_, x_, b_}, _, \
_, {1, _, y_, _}, _] :=\n                        {3, a, x, b, Floor[y + \
Random[]]};\n  decide[{4, a_, x_, b_}, _, _, _, {2, _, y_, _}] :=\n           \
             {4, a, x, b, Floor[y + Random[]]};\n  decide[z_, _, _, _, _] := \
z;\n  costbenefit[1, 1, 1] = R;\n  costbenefit[0, 1, 1] = T;\n  \
costbenefit[1, 0, 1] = S;\n  costbenefit[0, 0, 1] = P;\n  costbenefit[_, _, \
0] = W;\n  interact[{3, a_, x_, b_, k_}, _, _,\n           {1, d_, _, _, h_}, \
_] :=\n                {3, a, x, b + costbenefit[a, d, (k * h)]};\n  \
interact[{2, a_, x_, b_, k_}, _,\n           {4, d_, _, _, h_}, _, _] :=\n    \
            {2, a, x, b + costbenefit[a, d, (k * h)]};\n  interact[{1, a_, \
x_, b_, k_},\n           {3, d_, _, _, h_}, _, _, _] :=\n                {1, \
a, x, b + costbenefit[a, d, (k * h)]};\n  interact[{4, a_, x_, b_, k_}, _, _, \
_,\n           {2, d_, _, _, h_}] :=\n                {4, a, x, b + \
costbenefit[a, d, (k * h)]};\n  interact[z_, _, _, _, _] := z;\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk, \
vonNeumann[interact,\n                  vonNeumann[decide, #]]]&, society, t, \
opts]];"], "Input",
  CellTags->"D.3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.4  Chapter 4", "Section",
  CellTags->"D.4"],

Cell[CellGroupData[{

Cell["D.4.1  pollysociotit4tat", "Subsection",
  CellTags->"D.4"],

Cell[TextData[
"pollysociotit4tat[n_, p_, {s_, t_, u_, v_},\n                          {P_, \
R_, S_, T_}, q_, opts___] := \nModule[{RND, k = 0, society, behave, decide,\n \
                  payoff, act, walk, vonNeumann, GN},\n  RND := \
Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], {n}, {n}]  \
/.\n    1 \[RuleDelayed] {++k, Floor[1 + v + u + Random[]]} /.\n    {{m_, 1} \
\[RuleDelayed] {RND, m, Table[{}, {k}], 0,\n                     Floor[1 + \
t/(s + t) + Random[]]},\n     {m_, 2} \[RuleDelayed] {RND, m, Table[{}, {k}], \
0,\n                     Floor[3 + v/(v + u) + Random[]]}};\n  behave[1, _] = \
1;\n  behave[2, {___, 0}] = 0;\n  behave[2, _] = 1;\n  behave[3, _] = 0;\n  \
behave[4, {___, 1}] = 1;\n  behave[4, _] = 0;\n  decide[{1, name1_, lis1_, \
res1_, strat1_},\n         {3, name3_, _, _, _}, _, _, _] :=\n                \
{1, name1, lis1, res1,\n                  behave[strat1, lis1[[name3]]], \
strat1};\n  decide[{3, name3_, lis3_, res3_, strat3_}, _, _,\n         {1, \
name1_, _, _, _}, _] := \n                {3, name3, lis3, res3,\n            \
      behave[strat3, lis3[[name1]]], strat3};\n  decide[{2, name2_, lis2_, \
res2_, strat2_}, _,\n         {4, name4_, _, _, _}, _, _] := \n               \
 {2, name2, lis2, res2,\n                  behave[strat2, lis2[[name4]]], \
strat2};\n  decide[{4, name4_, lis4_, res4_, strat4_}, _, _, _,\n         {2, \
name2_, _, _, _}] := \n                {4, name4, lis4, res4,\n               \
   behave[strat4, lis4[[name2]]], strat4};\n  decide[z_, _, _, _, _] := z;\n  \
payoff[1, 1] = R;\n  payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = \
P;\n  act[{1, name1_, lis1_, res1_, behave1_, strat1_},\n      {3, name3_, _, \
_, behave3_, _}, _, _, _] := \n             {1, name1, ReplacePart[lis1,\n    \
           Join[lis1[[name3]], {behave3}], name3],\n               res1 + \
payoff[behave1, behave3], strat1};\n\n  act[{3, name3_, lis3_, res3_, \
behave3_, strat3_}, _, _,\n      {1, name1_, _, _, behave1_, _}, _] := \n     \
        {3, name3, ReplacePart[lis3,\n               Join[lis3[[name1]], \
{behave1}], name1],\n               res3 + payoff[behave3, behave1], strat3};\
\n\n  act[{2, name2_, lis2_, res2_, behave2_, strat2_}, _,\n      {4, name4_, \
_, _, behave4_, _}, _, _] := \n             {2, name2, ReplacePart[lis2,\n    \
           Join[lis2[[name4]], {behave4}], name4],\n               res2 + \
payoff[behave2, behave4], strat2};\n\n  act[{4, name4_, lis4_, res4_, \
behave4_, strat4_}, _, _,\n   _, {2, name2_, _, _, behave2_, _}] := \n        \
     {4, name4, ReplacePart[lis4,\n               Join[lis4[[name2]], \
{behave2}], name2],\n               res4 + payoff[behave4, behave2], strat4};\
\n  act[z_, _, _, _, _] := z;\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] \
:= {RND,a};\n  walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;  \n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n         {{0, 0}, {1, 0}, {0, -1}, \
{-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk,\n   \
vonNeumann[act, vonNeumann[decide, #]]]&, society, q, opts]]"], "Input",
  CellTags->"D.4"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.4.2  aspirations", "Subsection",
  CellTags->"D.4"],

Cell[TextData[
"aspirations[n_, p_, g_, {P_, R_, S_, T_}, t_, opts___] := \nModule[{society, \
interact, payoff,  eval, walk, vonNeumann, GN, RND},\n  RND := \
Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\
\n      1 \[RuleDelayed] {RND, Floor[g + Random[]],\n           Random[Real, \
{Min[#], Max[#]}&[{R, S, T, P}]],\n           Random[], {}, 0};\n  payoff[1, \
1] = R;\n  payoff[0, 1] = T;\n  payoff[1, 0] = S;\n  payoff[0, 0] = P;\n  \
interact[{1, b1_, a1_, e1_, p1_, r1_},\n           {3, b3_, _, _, _, _}, _, \
_, _] :=  \n             {1, b1, a1, e1, Join[p1, {payoff[b1, b3]}],\n        \
                             r1 + payoff[b1, b3]};\n  interact[{2, b2_, a2_ \
,e2_, p2_, r2_}, _,\n           {4, b4_, _, _, _, _}, _, _] :=\n             \
{2, b2, a2, e2, Join[p2, {payoff[b2, b4]}],\n                                 \
    r2 + payoff[b2, b4]};\n  interact[{3, b3_, a3_, e3_, p3_, r3_}, _, _,\n   \
        {1, b1_, _, _, _, _}, _] := \n             {3, b3, a3, e3, Join[p3, \
{payoff[b3, b1]}],\n                                     r3 + payoff[b3, \
b1]};\n  interact[{4, b4_, a4_, e4_, p4_, r4_}, _, _, _,\n           {2, b2_, \
_, _, _, _}] :=\n             {4, b4, a4, e4, Join[p4, {payoff[b4, b2]}],\n   \
                                  r4 + payoff[b4, b2]};\n  interact[z_, _, _, \
_, _] := z;\n  eval[{x_, b_, 0, e_, pp_, r_}] :=  {x, b, 0, e, {}, r};\n  \
eval[{x_, b_, a_, e_, {}, r_}] :=  {x, b, a, e, {}, r};\n  eval[{x_, 1, a_, \
e_, pp_, r_}] :=  {x,\n    Sign[Floor[(Apply[Plus, pp]/Length[pp])/a]],\n     \
                  a, e, {}, r} /; (Random[] + e) > 1;\n  eval[{x_, 0, a_, e_, \
pp_, r_}] :=  {x,\n    1 - Sign[Floor[(Apply[Plus, pp]/Length[pp])/a]],\n     \
                  a, e, {}, r} /; (Random[] + e) > 1;\n  eval[z_, _, _, _, _] \
:= z;\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  vonNeumann[func_, lat_] := \n    \
MapThread[func, Map[RotateRight[lat, #]&,\n          {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1}}], 2];\n  GN[func_, lat_] :=\n    MapThread[func, \
Map[RotateRight[lat, #]&,\n            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, \
1},\n             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},\n             \
{0, -2}, {-2, 0}, {0, 2}}], 2];\n  NestListEffects[GN[walk,\n  Map[eval, \
vonNeumann[interact, #], {2}]]&, society, t, opts]]"], "Input",
  CellTags->"D.4"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.5  Chapter 5", "Section",
  CellTags->"D.5"],

Cell[CellGroupData[{

Cell["D.5.1  neighborhood", "Subsection",
  CellTags->"D.5"],

Cell[TextData[
"neighborhood[n_, p_, v_, w_, t_, opts___] := \nModule[{walk, movestay, \
society, RND, Moore, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /. \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, w}], {v}]};\n  movestay[0, __] := 0;\n  \
movestay[{a_, b_}, res__] := \n    {a * Round[1 - Count[Map[Count[b - #[[2]], \
0]&, \n       {res} /. 0 \[Rule] {0, 0}], _?(# >= v / 2 &)] / 8.], b};\n  \
walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestListEffects[GN[walk, Moore[movestay, #]]&,\n                             \
              society, t, opts]]"], "Input",
  CellTags->"D.5"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.5.2  conform", "Subsection",
  CellTags->"D.5"],

Cell[TextData[
"conform[n_, p_, s_, m_, t_, opts___] := \nModule[{change, movestay, walk, \
society, RND, Moore, GN},   \n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /.  \n           1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, m}], {s}]};\n  memeAvg[lis_, r_] := \n    \
(Apply[Plus, Map[#[[2, r]]&, #]]/Length[#])&[\n                               \
      DeleteCases[lis, 0]];\n  change[0, _, _, _, _, _, _, _, _] := 0;\n  \
change[z_, 0, 0, 0, 0, 0, 0, 0, 0] := z;\n  change[{a_, y_}, res__] :=\n    \
Module[{r = Random[Integer, {1, s}]},\n    {a, ReplacePart[y,\n       \
Random[Integer, {y[[r]], memeAvg[{res}, r]}], r]}];\n  movestay[0, __] := 0;\n\
  movestay[{a_, b_}, res__] := \n    {a * Round[1 - Count[Map[Count[b - \
#[[2]], 0]&,\n       {res} /. 0 \[Rule] {0, 0}], _?(# >= s / 2 &)] / 8.], b};\
\n  walk[{1,a___},0,_,_,_,{4,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,{2,___},_,_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,{3,___},_,_,_] := {RND,a};\n  \
walk[{1,a___},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a___},_,0,_,_,{3,___},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,{1,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,{4,___},_,_] := {RND,a};\n  \
walk[{2,a___},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a___},_,_,0,_,_,{4,___},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,{2,___},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,{1,___},_] := {RND,a};\n  \
walk[{3,a___},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a___},_,_,_,0,_,_,{1,___},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,{3,___},_,_,_,_] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,{2,___}] := {RND,a};\n  \
walk[{4,a___},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{_,a___},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,___},{4,___},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,___},_,_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},{1,___},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,___},_,{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,___},{2,___},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a___},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a___},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a___},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a___},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestListEffects[GN[walk,\n        Moore[movestay, Moore[change, #]]]&, \
society, t, opts]]"], "Input",
  CellTags->"D.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D.6  Chapter 6", "Section",
  CellTags->"D.6"],

Cell[CellGroupData[{

Cell["D.6.1  peopleWhoNeedPeople", "Subsection",
  CellTags->"D.6"],

Cell[TextData[
"peopleWhoNeedPeople[n_, p_, s_, m_, f_, t_, opts___] :=\nModule[{k = 0, \
society, decide, exchange, \n                                satellites, \
socialCircle},\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \
\[RuleDelayed] ++k /. x_?Positive \[RuleDelayed] {x, Union[DeleteCases[\n     \
           Table[Random[Integer, {1, k}], {f}], x]],\n                  \
Table[Random[Integer, {1, m}], {s}]};\n  society = society /. {a_, b_, c_} \
\[RuleDelayed] {a, Union[b,\n    Cases[society, {x_, {___, a, ___}, _} \
\[RuleDelayed] x, {2}]], c};\n  decide[{{a_, b_, c_}, res__}] :=\n    {a, b, \
c, {res}[[#2, 1]], #1,\n      Random[Integer, {c[[#1]], {res}[[#2, 3, \
#1]]}]}&[\n               Random[Integer, {1, s}],\n               \
Random[Integer, {1, Length[{res}]}]];\n  decide[{{x_, {}, y_}}] := {x, {}, \
y};\n  decide[0] := 0;\n  exchange[{{a_, b_, c_, aa_, pos_, d_}, ___,\n       \
     {aa_, _, _, a_, _, _}, ___}] := \n                {a, b, ReplacePart[c, \
d, pos]} /; a < aa;\n  exchange[{{a_, b_, c_, aa_, _, _}, ___,\n            \
{aa_, _, _, a_, pos_, d_}, ___}] := \n                {a, b, ReplacePart[c, \
d, pos]};\n  exchange[{{a_, b_, c_, ___}, ___}] := {a, b, c};\n  exchange[0] \
:= 0;\n  socialCircle[func_, lat_] :=\n                Map[func[satellites[#, \
lat]]&, lat, {2}];\n  satellites[0, _] = 0;\n  satellites[{a_, b_, c___}, \
lat_] := Join[{{a, b, c}},\n       Cases[lat, {Apply[Alternatives, b], _, \
___}, {2}]];\n  NestListEffects[socialCircle[exchange,\n                  \
socialCircle[decide, #]]&, society, t, opts]]"], "Input",
  CellTags->"D.6"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.6.2 iWillFollowHim", "Subsection",
  CellTags->"D.6"],

Cell[TextData[
"iWillFollowHim[n_, p_, s_, m_, f_, t_, opts___] :=\nModule[{k = 0, society, \
exchange,\n                             satellites, socialCircle},\n  society \
= Table[Floor[p + Random[]], {n}, {n}] /.\n    1 \[RuleDelayed] ++k /. \
x_?Positive \[RuleDelayed] {x, Union[DeleteCases[\n        \
Table[Random[Integer, {1, k}], {f}], x]],  \n          Random[], \
Table[Random[Integer, {1, m}], {s}]};\n  society = society /.\n    {a_, b_, \
c_, d_} \[RuleDelayed] {a, Union[b, Cases[society,\n            {x_, {___, a, \
___}, _, _} \[RuleDelayed] x, {2}]], c, d};\n  exchange[{{a_, b_, c_, d_}, \
res__}] := {a, b, c,\n    ReplacePart[d,\n         Sort[{res}, #1[[3]] > \
#2[[3]]&][[1, 4, #]], #]}&[\n           Random[Integer, {1, s}]];\n  \
exchange[{{a_,  {}, c_, d_}}] := {a, {}, c, d};\n  exchange[0] := 0;\n  \
socialCircle[func_, lat_] :=\n                Map[func[satellites[#, lat]]&, \
lat, {2}];\n  satellites[0, _] = 0;\n  satellites[{a_, b_, c___}, lat_] := \
Join[{{a, b, c}},\n      Cases[lat, {Apply[Alternatives, b], _, ___}, {2}]];\n\
  NestListEffects[socialCircle[exchange, #]&, society, t, opts]]"], "Input",
  CellTags->"D.6"]
}, Closed]],

Cell[CellGroupData[{

Cell["D.6.3  flight", "Subsection",
  CellTags->"D.6"],

Cell[TextData[
"flight[n_, p_, g_, t_, opts___] := \nModule[{society, decideToFly, flyAway, \
Moore},\n  society = Table[Floor[p + Random[]], {n}, {n}] /.\n                \
           1 \[RuleDelayed] {1 + Floor[g + Random[]]};\n  decideToFly[{1}, \
res__] := {1, 1} /;\n                  Count[{res}, {1}] < Count[{res}, {2}];\
\n  decideToFly[{2}, res__] := {2, 2} /;\n                  Count[{res}, {2}] \
< Count[{res}, {1}];\n  decideToFly[0, res__] := {0, 1} /;\n                  \
Count[{res}, {1}] > Count[{res}, {2}];\n  decideToFly[0, res__] := {0, 2} /;\n\
                  Count[{res}, {2}] > Count[{res}, {1}];\n  decideToFly[x_, \
__] := x;\n  flyAway[lat_] := \n  Module[{a1, a2, e1, e2, randomize, \
multiReplacePart},\n   {a1, a2, e1, e2} = Map[Position[lat, #, {2}]&,\n       \
                 {{1, 1}, {2, 2}, {0, 1}, {0, 2}}];\n   randomize[{}] := {};\n\
   randomize[lis_] :=\n     Transpose[Sort[Map[{Random[], #}&, lis]]][[2]];\n \
  a1 = Take[randomize[a1], Min[Length[a1], Length[e1]]];\n   a2 = \
Take[randomize[a2], Min[Length[a2], Length[e2]]];\n   e1 = Take[e1, \
Length[a1]];\n   e2 = Take[e2, Length[a2]];\n   multiReplacePart[mat_, lis1_, \
lis2_] :=\n    Fold[ReplacePart[#1, Part[#1, Apply[Sequence,\n    \
First[#2]]], Last[#2]]&, mat, Transpose[{lis1, lis2}]];\n   ReplacePart[#, 0, \
Join[a1, a2]]&[\n      multiReplacePart[#, a2, e2]&[\n        \
multiReplacePart[lat, a1, e1]]] /.\n                         {{0, _} \
\[RuleDelayed] 0, {x_, _} \[RuleDelayed] {x}}];\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  NestListEffects[flyAway[Moore[decideToFly, #]]&,\n                          \
                 society, t, opts]]"], "Input",
  CellTags->"D.6"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "Appendix D. Program Listing"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@[cX0000000000064<01T1T00000000000
00000000003oo`@^VN3oo`02DE`00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "D.0"->{
    Cell[1731, 51, 42, 1, 92, "ChapterLine",
      CellTags->"D.0"],
    Cell[1776, 54, 51, 1, 153, "Title",
      CellTags->"D.0"],
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[2124, 66, 58, 1, 40, "Section",
      CellTags->"D.0"],
    Cell[2207, 71, 94, 1, 40, "Subsection",
      CellTags->"D.0"],
    Cell[2304, 74, 371, 6, 102, "Input",
      CellTags->"D.0"],
    Cell[2678, 82, 168, 5, 63, "Input",
      CellTags->"D.0"],
    Cell[2849, 89, 171, 4, 63, "Input",
      CellTags->"D.0"],
    Cell[3023, 95, 147, 3, 50, "Input",
      CellTags->"D.0"],
    Cell[3173, 100, 662, 20, 258, "Input",
      CellTags->"D.0"],
    Cell[3872, 125, 76, 1, 40, "Subsection",
      CellTags->"D.0"],
    Cell[3951, 128, 118, 4, 50, "Input",
      CellTags->"D.0"],
    Cell[4072, 134, 271, 9, 115, "Input",
      CellTags->"D.0"]},
  "D.1"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[4392, 149, 52, 1, 22, "Section",
      CellTags->"D.1"],
    Cell[4469, 154, 61, 1, 40, "Subsection",
      CellTags->"D.1"],
    Cell[4533, 157, 2276, 39, 570, "Input",
      CellTags->"D.1"]},
  "D.2"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[6858, 202, 52, 1, 22, "Section",
      CellTags->"D.2"],
    Cell[6935, 207, 70, 1, 40, "Subsection",
      CellTags->"D.2"],
    Cell[7008, 210, 3632, 56, 882, "Input",
      CellTags->"D.2"],
    Cell[10677, 271, 73, 1, 40, "Subsection",
      CellTags->"D.2"],
    Cell[10753, 274, 3481, 54, 856, "Input",
      CellTags->"D.2"],
    Cell[14271, 333, 62, 1, 40, "Subsection",
      CellTags->"D.2"],
    Cell[14336, 336, 3069, 48, 752, "Input",
      CellTags->"D.2"]},
  "D.3"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[17454, 390, 52, 1, 22, "Section",
      CellTags->"D.3"],
    Cell[17531, 395, 65, 1, 40, "Subsection",
      CellTags->"D.3"],
    Cell[17599, 398, 4190, 63, 1090, "Input",
      CellTags->"D.3"],
    Cell[21826, 466, 54, 1, 40, "Subsection",
      CellTags->"D.3"],
    Cell[21883, 469, 4182, 63, 1077, "Input",
      CellTags->"D.3"],
    Cell[26102, 537, 53, 1, 40, "Subsection",
      CellTags->"D.3"],
    Cell[26158, 540, 3723, 57, 947, "Input",
      CellTags->"D.3"]},
  "D.4"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[29930, 603, 52, 1, 22, "Section",
      CellTags->"D.4"],
    Cell[30007, 608, 65, 1, 40, "Subsection",
      CellTags->"D.4"],
    Cell[30075, 611, 4863, 70, 1324, "Input",
      CellTags->"D.4"],
    Cell[34975, 686, 59, 1, 40, "Subsection",
      CellTags->"D.4"],
    Cell[35037, 689, 3918, 58, 1012, "Input",
      CellTags->"D.4"]},
  "D.5"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[39004, 753, 52, 1, 22, "Section",
      CellTags->"D.5"],
    Cell[39081, 758, 60, 1, 40, "Subsection",
      CellTags->"D.5"],
    Cell[39144, 761, 2627, 42, 648, "Input",
      CellTags->"D.5"],
    Cell[41808, 808, 55, 1, 40, "Subsection",
      CellTags->"D.5"],
    Cell[41866, 811, 3003, 47, 765, "Input",
      CellTags->"D.5"]},
  "D.6"->{
    Cell[1830, 57, 269, 5, 52, "Text",
      CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],
    Cell[44918, 864, 52, 1, 22, "Section",
      CellTags->"D.6"],
    Cell[44995, 869, 67, 1, 40, "Subsection",
      CellTags->"D.6"],
    Cell[45065, 872, 1621, 22, 427, "Input",
      CellTags->"D.6"],
    Cell[46723, 899, 61, 1, 40, "Subsection",
      CellTags->"D.6"],
    Cell[46787, 902, 1161, 16, 323, "Input",
      CellTags->"D.6"],
    Cell[47985, 923, 54, 1, 40, "Subsection",
      CellTags->"D.6"],
    Cell[48042, 926, 1843, 25, 505, "Input",
      CellTags->"D.6"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"D.0", 51070, 986},
  {"D.1", 51979, 1013},
  {"D.2", 52301, 1022},
  {"D.3", 52901, 1039},
  {"D.4", 53506, 1056},
  {"D.5", 53972, 1069},
  {"D.6", 54436, 1082}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 42, 1, 92, "ChapterLine",
  CellTags->"D.0"],
Cell[1776, 54, 51, 1, 153, "Title",
  CellTags->"D.0"],
Cell[1830, 57, 269, 5, 52, "Text",
  CellTags->{"D.0", "D.1", "D.2", "D.3", "D.4", "D.5", "D.6"}],

Cell[CellGroupData[{
Cell[2124, 66, 58, 1, 40, "Section",
  CellTags->"D.0"],

Cell[CellGroupData[{
Cell[2207, 71, 94, 1, 40, "Subsection",
  CellTags->"D.0"],
Cell[2304, 74, 371, 6, 102, "Input",
  CellTags->"D.0"],
Cell[2678, 82, 168, 5, 63, "Input",
  CellTags->"D.0"],
Cell[2849, 89, 171, 4, 63, "Input",
  CellTags->"D.0"],
Cell[3023, 95, 147, 3, 50, "Input",
  CellTags->"D.0"],
Cell[3173, 100, 662, 20, 258, "Input",
  CellTags->"D.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[3872, 125, 76, 1, 40, "Subsection",
  CellTags->"D.0"],
Cell[3951, 128, 118, 4, 50, "Input",
  CellTags->"D.0"],
Cell[4072, 134, 271, 9, 115, "Input",
  CellTags->"D.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4392, 149, 52, 1, 22, "Section",
  CellTags->"D.1"],

Cell[CellGroupData[{
Cell[4469, 154, 61, 1, 40, "Subsection",
  CellTags->"D.1"],
Cell[4533, 157, 2276, 39, 570, "Input",
  CellTags->"D.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6858, 202, 52, 1, 22, "Section",
  CellTags->"D.2"],

Cell[CellGroupData[{
Cell[6935, 207, 70, 1, 40, "Subsection",
  CellTags->"D.2"],
Cell[7008, 210, 3632, 56, 882, "Input",
  CellTags->"D.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[10677, 271, 73, 1, 40, "Subsection",
  CellTags->"D.2"],
Cell[10753, 274, 3481, 54, 856, "Input",
  CellTags->"D.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[14271, 333, 62, 1, 40, "Subsection",
  CellTags->"D.2"],
Cell[14336, 336, 3069, 48, 752, "Input",
  CellTags->"D.2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17454, 390, 52, 1, 22, "Section",
  CellTags->"D.3"],

Cell[CellGroupData[{
Cell[17531, 395, 65, 1, 40, "Subsection",
  CellTags->"D.3"],
Cell[17599, 398, 4190, 63, 1090, "Input",
  CellTags->"D.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[21826, 466, 54, 1, 40, "Subsection",
  CellTags->"D.3"],
Cell[21883, 469, 4182, 63, 1077, "Input",
  CellTags->"D.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[26102, 537, 53, 1, 40, "Subsection",
  CellTags->"D.3"],
Cell[26158, 540, 3723, 57, 947, "Input",
  CellTags->"D.3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29930, 603, 52, 1, 22, "Section",
  CellTags->"D.4"],

Cell[CellGroupData[{
Cell[30007, 608, 65, 1, 40, "Subsection",
  CellTags->"D.4"],
Cell[30075, 611, 4863, 70, 1324, "Input",
  CellTags->"D.4"]
}, Closed]],

Cell[CellGroupData[{
Cell[34975, 686, 59, 1, 40, "Subsection",
  CellTags->"D.4"],
Cell[35037, 689, 3918, 58, 1012, "Input",
  CellTags->"D.4"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39004, 753, 52, 1, 22, "Section",
  CellTags->"D.5"],

Cell[CellGroupData[{
Cell[39081, 758, 60, 1, 40, "Subsection",
  CellTags->"D.5"],
Cell[39144, 761, 2627, 42, 648, "Input",
  CellTags->"D.5"]
}, Closed]],

Cell[CellGroupData[{
Cell[41808, 808, 55, 1, 40, "Subsection",
  CellTags->"D.5"],
Cell[41866, 811, 3003, 47, 765, "Input",
  CellTags->"D.5"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44918, 864, 52, 1, 22, "Section",
  CellTags->"D.6"],

Cell[CellGroupData[{
Cell[44995, 869, 67, 1, 40, "Subsection",
  CellTags->"D.6"],
Cell[45065, 872, 1621, 22, 427, "Input",
  CellTags->"D.6"]
}, Closed]],

Cell[CellGroupData[{
Cell[46723, 899, 61, 1, 40, "Subsection",
  CellTags->"D.6"],
Cell[46787, 902, 1161, 16, 323, "Input",
  CellTags->"D.6"]
}, Closed]],

Cell[CellGroupData[{
Cell[47985, 923, 54, 1, 40, "Subsection",
  CellTags->"D.6"],
Cell[48042, 926, 1843, 25, 505, "Input",
  CellTags->"D.6"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

