(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18740,        498]*)
(*NotebookOutlinePosition[     20359,        548]*)
(*  CellTagsIndexPosition[     20267,        541]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["", "ChapterLine"],

Cell["What This Book Is About", "Title"],

Cell[TextData[{
  "Our purpose in writing ",
  StyleBox[
  "Simulating Society: A Mathematica Toolkit for Modeling Socioeconomic \
Behavior",
    FontSlant->"Italic"],
  " is two-fold:"
}], "Text"],

Cell["\<\
To demonstrate the ability of computers to create simulations of \
the behavior of people in social and socioeconomic situations, to people \
interested in human social behavior, including professionals working in the \
fields of social science, economics, and political science; graduate and \
undergraduate students (and even high school students) studying these \
subjects; and amateur science enthusiasts for whom the study of human society \
is an avocation; and\
\>", "BulletListItem"],

Cell["\<\
To provide people with computer-based tools that will allow them to \
carry out their own computer simulation studies of whatever socioeconomic \
phenomena interest them.\
\>", "BulletListItem"],

Cell["\<\
Computer simulation studies are widely used in the physical \
sciences as an adjunct to theoretical studies. In the social sciences where \
the inherent complexity of human socioeconomic behavior limits the use of \
traditional mathematical analysis, simulation studies can provide an \
alternative theoretical tool for exploring specific aspects of human \
behavior. \
\>", "Text"],

Cell[TextData[{
  "In this book, we focus on cultural exchanges and socioeconomic \
transactions that occur as a result of interactions between individuals, \
rather than on behavior imposed by a central authority. This approach is \
called ",
  StyleBox["bottom-up",
    FontSlant->"Italic"],
  " or ",
  StyleBox["agent-based",
    FontSlant->"Italic"],
  " modeling."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{"modeling", 
    "agent-based", ""}, {"modeling", "bottom-up", ""}}},
  CellTags->"i:1"],

Cell["\<\
Several general features distinguish agent-based models from \
traditional models of socioeconomic behavior.\
\>", "Text"],

Cell["\<\
The characteristics of agents can be heterogeneous, each one having \
its own characteristics (identities, traits, preferences, tastes, \
memories).\
\>", "BulletListItem"],

Cell["\<\
The reasoning of agents can be rational or irrational, intelligent \
or naive.\
\>", "BulletListItem"],

Cell["The interactions between agents can be direct.", "BulletListItem"],

Cell["The behaviors of agents can change over time.", "BulletListItem"],

Cell["\<\
The location of agents can shift as they move around the \
system.\
\>", "BulletListItem"],

Cell["\<\
In addition to these general features, the models discussed in this \
book have these specific characteristics:\
\>", "Text"],

Cell["\<\
the movement of agents can occur simultaneously or \
asynchronously;\
\>", "BulletListItem"],

Cell["the interaction of agents can be unilateral or multilateral;", 
  "BulletListItem"],

Cell["\<\
the behaviors of agents can change within a single generation as \
they learn from experience and adapt accordingly.\
\>", "BulletListItem"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Mechanisms of change occurring over a number of generations of agents \
involving the use of processes that eliminate and/or create agents by \
allowing them to die and to give birth or genetic algorithms to mimic the \
evolution of the agent population, would not be difficult to incorporate into \
our models."
}], "Note"],

Cell["\<\
One of the major features of this book is that the code in our \
simulation programs is developed and explained in detail in the text. This is \
done for two reasons.\
\>", "Text"],

Cell["\<\
We feel that the main purpose of scientific research is the \
creation of public knowledge, hence, published experimental, theoretical, and \
simulation results must be presented in such a way as to permit other \
researchers to attempt to duplicate the results. In the case of simulation \
studies, we are especially concerned with the GIGO (garbage in, garbage out) \
effect, particularly when long, often difficult to trace, computer programs \
are involved. It is therefore essential in our view, that a complete \
description of a program, as well as the program itself, be presented and \
discussed along with any results it produces.\
\>", "BulletListItem"],

Cell[TextData[{
  "This book is intended, as the subtitle indicates, to be a practical guide \
that will enable the reader to carry out his or her own socioeconomic \
simulation studies, rather than to deal with so-called ",
  StyleBox["deep",
    FontSlant->"Italic"],
  " issues related to the principles of socioeconomic modeling. Therefore, \
the details of the programs need to be explicitly explained so that the \
programs can be understood and if desired, modified by the users for their \
own work."
}], "BulletListItem"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " The results of the particular model simulations runs that are presented \
here are NOT meant to be used to evaluate the usefulness of the models \
themselves; that would require an in-depth study of the robustness of the \
results, such as their sensitivity to the program parameter values, which we \
do not undertake here."
}], "Note"],

Cell["\<\
Intimately related to the issue of presenting and explaining code \
is the choice of programming language. Because our book is meant to serve as \
a toolkit that readers can use to explore their own ideas of social behavior \
by computer simulation, we needed to choose a programming language that is \
powerful in its capabilities, yet simple in its use, and able to be run on a \
large number of computing platforms.\
\>", "Text"],

Cell[TextData[{
  "We have found that for writing, running, and analyzing computer \
simulations, the integrated computing environment provided by ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "has a number of features that make it uniquely qualified for this task, \
including the following."
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming language is very simple in principle, employing a \
pattern-matching, term-rewriting style that allows programs to be written \
directly and easily. Moreover, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is an interpreted language, and therefore the code that makes up a \
program can be created and debugged in a piecemeal fashion, greatly \
decreasing the time needed to create a new program. Just as important, an \
existing program can be modified and extended, both easily and rapidly, to \
incorporate more complications. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is also a very easy language to learn, requiring no prior programming \
experience."
}], "BulletListItem"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can manipulate data structures (e.g., lists and matrices) in their \
entirety (e.g., shifting the positions of all of the elements of a matrix or \
performing arithmetic operations on all of the corresponding elements of \
several matrices at once). In addition, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has extensive built-in functions for performing list manipulations such \
as adding, dropping, and replacing list elements, rearranging the elements, \
and extracting elements from the list, which allows us to work with groups of \
nested list structures. These allow us to write programs that are both quite \
concise and very readable. "
}], "BulletListItem"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " To enable readers who are unfamiliar with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to understand the code in the book, and also to write their own \
simulation programs, there are appendices explaining how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s programming language works, and demonstrating its list manipulation \
capabilities. In fact, we ",
  StyleBox["STRONGLY",
    FontWeight->"Bold"],
  " recommend that the reader, regardless of prior experience with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", read through the appendices before turning to the chapters in the book, \
as much of the code used in the chapters is explained and illustrated in the \
appendices."
}], "Note"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has extensive graphics which are quite easy to use. As a result, many \
different types of graphical representation can be made to find the most \
informative graphical format to use for a particular simulation model."
}], "BulletListItem"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Some of the features that have been introduced in version 3.0 of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allow one to create and display an animation while the program is running \
which is particularly useful for simulation work."
}], "Note"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has extensive numeric capabilities that allow statistical analysis to be \
used to assign various quantitative measures (i.e., numerical values) to the \
simulation results."
}], "BulletListItem"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " Although we do not carry out any substantial statistical analysis here, \
focusing instead on the creation of the simulation programs that can be run \
to generate data, there are statistical packages available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that can be used to analyze these data."
}], "Note"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs are executable on a very great number of computing platforms, \
essentially any platform that runs ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "BulletListItem"],

Cell[TextData[{
  "All of these features are available in an integrated computing \
environment, in which simulation programs can be written, debugged, run, \
visualized, analyzed, and even written up for publication or presentation in \
a single document, known as a notebook, which is very convenient. In fact, \
this book has been written entirely as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks. Readers interested in viewing these notebooks or using them as \
a starting point from which to develop their own simulation programs should \
visit the TELOS web site, http://www.telospub.com."
}], "Text"],

Cell[TextData[{
  "Based on all of these factors, we have found that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a nearly ideal computing environment for carrying out our \
investigations."
}], "Text"],

Cell["Each chapter in this book is organized as follows.", "Text"],

Cell[TextData[{
  "We begin with an introductory discussion of the socioeconomic behavior(s) \
being modeled. Since we do not claim to be professional social scientists \
(our expertise resides in simulation modeling techniques and in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming), we keep our discussion of background rather brief. A short \
list of useful, readable references to both the popular and technical \
literature is given at the end of the chapter. Although the references are \
limited to those sources that were directly relevant to the development of \
the models in this book, the references that these sources contain can, in \
turn, be used by the interested reader to delve more deeply into the subject. \
"
}], "BulletListItem"],

Cell["\<\
We develop programs for simulating these behaviors in a \
step-by-step manner with each step explained. This exposition constitutes the \
main body of the chapter. By first describing a model and then implementing \
it in a computer program while providing a detailed discussion of the program \
code, we prepare the reader for the final part of the chapter, where he or \
she can participate.\
\>", "BulletListItem"],

Cell["\<\
We suggest a number of simulation projects that modify and/or \
extend the models in the chapter. These projects can be launchpads for \
readers to start their own explorations of whatever ideas they might have on \
human socioeconomic behavior.\
\>", "BulletListItem"],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
  "Our selection of the social and socioeconomic phenomena that are modeled \
in this book, which include ",
  StyleBox["social learning",
    FontSlant->"Italic"],
  " via cultural or meme transmission, and ",
  StyleBox["social capital",
    FontSlant->"Italic"],
  " via various versions of the prisoner's dilemma, neighborhood formation, \
conformism, and social networking, has been intentionally eclectic so that \
each reader can find at least one, and perhaps several, topics of personal \
interest. "
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:2", "IndexEntries" -> {{
    "social capital", "", ""}, {"social learning", "", ""}}},
  CellTags->"i:2"],

Cell["\<\
Our own starting point for learning about a number of these topics \
came from reading a popularized science book (and then the references given \
therein) which provides an excellent introduction for the layperson,\
\>", 
  "Text"],

Cell[TextData[{
  "Ridley, Matt. 1997. ",
  StyleBox[
  "The Origins of Virtue: Human Instincts and the Evolution of Cooperation",
    FontSlant->"Italic"],
  ",",
  " ",
  "Bergenfield, NJ: Viking."
}], "Reference"],

Cell["\<\
An interesting collection of technical academic studies of some of \
the same sorts of socioeconomic phenomena that we discuss here can be found \
in\
\>", "Text"],

Cell[TextData[{
  "Arthur, Brian, Steven Durlauf and David Lane. 1997. ",
  StyleBox["The Economy as an Evolving Complex System II",
    FontSlant->"Italic"],
  ". SFI Studies in the Sciences of Complexity, vol. XXVII, Reading, MA: \
Addison-Wesley."
}], "Reference"],

Cell["\<\
Two other texts using the agent-based approach to socioeconomic \
modeling have been published while this book was in preparation:\
\>", "Text"],

Cell[TextData[{
  "Axelrod, Robert. 1997. ",
  StyleBox[
  "The Complexity of Cooperation: Agent-Based Models of Competition and \
Cooperation",
    FontSlant->"Italic"],
  ". Princeton, NJ: Princeton University Press.\nEpstein, Joshua M. and \
Robert Axtell. 1996. ",
  StyleBox["Growing Artifical Societies: Social Science from the Bottom Up",
    FontSlant->"Italic"],
  ". Cambridge, MA: Brookings Institute Press/MIT Press."
}], "Reference"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acknowledgements", "Section"],

Cell["\<\
We would like to express our appreciation to Allan M. Wylde who was \
our publisher at TELOS from the inception of this project until it entered \
the production stage. His recognition of the potential importance of this \
book and his unflagging support and enthusiasm for it were essential. RJG \
would like to thank Allan personally for working on his behalf over the \
course of the years on this and three previous books. The work of the \
always-friendly and ever-efficient Keisha Sherbecoe at TELOS is also much \
appreciated. \
\>", "Text"],

Cell[TextData[{
  "Jerry Lyons and Steven Pisano at Springer-Verlag became directly involved \
with the authors during the production process, and by facilitating the \
creation of the final book, helped bring it into the world. Other helpful \
people at Springer-Verlag include Fred Bartlett who helped with the \
production of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics, and Karen Phillips who worked with us and an illustrator to \
make an outstanding cover illustration. John Bonadies of Wolfram Research \
took the illustration and created a fine-looking front cover which we really \
appreciate."
}], "Text"],

Cell["\<\
The reviewers made a number of very good comments and suggestions \
that improved the presentation in the book and we thank them for that. We \
would also like to thank the numerous people from many different fields \
including physics, economics, political science, social science, film \
criticism, and cardiology who expressed their belief in the value of this \
project. Barry Kirchgessner deserves special thanks for providing an \
invaluable service, meticulously checking for errors in the text, code, and \
figures in the book. Any errors that remain are not the fault of anyone \
mentioned in these acknowledgements, including the authors.\
\>", "Text"],

Cell["\<\
We would especially like to thank Scott Page for providing \
encouragement to TELOS to support this book and for suggesting several of the \
computer simulation projects at the end of various chapters. We also greatly \
appreciate his writing a foreword for the book.\
\>", "Text"],

Cell["Richard J. Gaylord and Louis J. D'Andria", "QuoteAttribution"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "What This Book Is About"}], "Header"], Inherited, Inherited}, {
    Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 3, "IndexEntries" -> {{"i:1", 
  "modeling", "agent-based", ""}, {"i:1", "modeling", "bottom-up", ""}, {
  "i:2", "social capital", "", ""}, {"i:2", "social learning", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@=_`X0000000000064<01T1T00000000000
00000000003oo`=_a93oo`000iL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:1"->{
    Cell[3106, 89, 536, 14, 68, "Text",
      CellTags->"i:1"]},
  "i:2"->{
    Cell[14193, 379, 684, 15, 98, "Text",
      CellTags->"i:2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:1", 20099, 531},
  {"i:2", 20175, 534}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 23, 0, 92, "ChapterLine"],
Cell[1757, 53, 40, 0, 153, "Title"],
Cell[1800, 55, 197, 7, 42, "Text"],
Cell[2000, 64, 501, 8, 90, "BulletListItem"],
Cell[2504, 74, 204, 4, 48, "BulletListItem"],
Cell[2711, 80, 392, 7, 80, "Text"],
Cell[3106, 89, 536, 14, 68, "Text",
  CellTags->"i:1"],
Cell[3645, 105, 132, 3, 38, "Text"],
Cell[3780, 110, 182, 4, 34, "BulletListItem"],
Cell[3965, 116, 112, 3, 20, "BulletListItem"],
Cell[4080, 121, 72, 0, 20, "BulletListItem"],
Cell[4155, 123, 71, 0, 20, "BulletListItem"],
Cell[4229, 125, 100, 3, 20, "BulletListItem"],
Cell[4332, 130, 135, 3, 38, "Text"],
Cell[4470, 135, 102, 3, 20, "BulletListItem"],
Cell[4575, 140, 89, 1, 20, "BulletListItem"],
Cell[4667, 143, 150, 3, 34, "BulletListItem"],
Cell[4820, 148, 389, 8, 68, "Note"],
Cell[5212, 158, 190, 4, 38, "Text"],
Cell[5405, 164, 674, 10, 118, "BulletListItem"],
Cell[6082, 176, 530, 10, 92, "BulletListItem"],
Cell[6615, 188, 402, 8, 68, "Note"],
Cell[7020, 198, 442, 7, 94, "Text"],
Cell[7465, 207, 317, 7, 54, "Text"],
Cell[7785, 216, 801, 18, 140, "BulletListItem"],
Cell[8589, 236, 755, 14, 122, "BulletListItem"],
Cell[9347, 252, 801, 20, 116, "Note"],
Cell[10151, 274, 312, 6, 50, "BulletListItem"],
Cell[10466, 282, 327, 8, 56, "Note"],
Cell[10796, 292, 268, 6, 50, "BulletListItem"],
Cell[11067, 300, 390, 9, 70, "Note"],
Cell[11460, 311, 262, 8, 38, "BulletListItem"],
Cell[11725, 321, 630, 11, 110, "Text"],
Cell[12358, 334, 219, 6, 40, "Text"],
Cell[12580, 342, 66, 0, 24, "Text"],
Cell[12649, 344, 775, 13, 134, "BulletListItem"],
Cell[13427, 359, 427, 7, 90, "BulletListItem"],
Cell[13857, 368, 279, 5, 62, "BulletListItem"],

Cell[CellGroupData[{
Cell[14161, 377, 29, 0, 40, "Section"],
Cell[14193, 379, 684, 15, 98, "Text",
  CellTags->"i:2"],
Cell[14880, 396, 242, 5, 52, "Text"],
Cell[15125, 403, 216, 8, 40, "Reference"],
Cell[15344, 413, 173, 4, 38, "Text"],
Cell[15520, 419, 267, 6, 54, "Reference"],
Cell[15790, 427, 154, 3, 38, "Text"],
Cell[15947, 432, 446, 11, 100, "Reference"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16430, 448, 35, 0, 40, "Section"],
Cell[16468, 450, 558, 9, 108, "Text"],
Cell[17029, 461, 643, 12, 126, "Text"],
Cell[17675, 475, 672, 10, 136, "Text"],
Cell[18350, 487, 291, 5, 66, "Text"],
Cell[18644, 494, 68, 0, 22, "QuoteAttribution"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

